@@ -110,6 +110,16 @@ else $res_year = "";
 else $res_year = "";
 } # fine if ($res_year)
 
+$anno_esist = 1;
+# Se ci troviamo dopo il periodo di creazione dell'anno ma questo non è stato ancora creato
+if (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) {
+$anno_prec = $anno - 1;
+if (@is_file(C_DATI_PATH."/selectperiodi$anno_prec.1.php")) $anno = $anno_prec;
+else $anno_esist = 0;
+} # fine if (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php"))
+if ($anno_esist) {
+
+
 if ($id_utente != 1) {
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
@@ -514,6 +524,7 @@ if ($foothtm) echo $foothtm;
 
 $pag = $pag_orig;
 } # fine if ($anno_utente_attivato == "SI")
+} # fine if ($anno_esist)
 } # fine else if ($raggiunto_limite)
 } # fine if ($pass == $pass_api)
 else {
@@ -570,10 +581,10 @@ $num_lock++;
 } # fine if ($anni[$num1] >= $anno_corr)
 } # fine for $num1
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
-if ($anni[$num1] >= $anno_corr) {
+if ($anni[$num1] >= $anno_corr and (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99)) {
 $altre_tab_lock[$num_lock] = $PHPR_TAB_PRE."prenotacanc".$anni[$num1];
 $num_lock++;
-} # fine if ($anni[$num1] >= $anno_corr)
+} # fine if ($anni[$num1] >= $anno_corr and (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99))
 } # fine for $num1
 for ($num1 = 0 ; $num1 < $num_anni ; $num1++) {
 if ($anni[$num1] >= $anno_corr) {
@@ -729,6 +740,7 @@ $idprenota = risul_query($prenota,$num2,'idprenota');
 $ospiti = esegui_query("select idclienti from $tablerclientiprenota_mostra where idprenota = '$idprenota' ");
 for ($num3 = 0 ; $num3 < numlin_query($ospiti) ; $num3++) $cliente_attivo[risul_query($ospiti,$num3,'idclienti')] = 1;
 } # fine for $num2
+if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99) {
 $tableprenotacanc_mostra = $PHPR_TAB_PRE."prenotacanc".$anno_mostra;
 if ($anno_mostra == $anno_corr) $prenotacanc = esegui_query("select idprenota,idclienti from $tableprenotacanc_mostra where iddatafine > '".($idperiodocorrente - 2)."' ");
 else  $prenotacanc = esegui_query("select idprenota,idclienti from $tableprenotacanc_mostra");
@@ -739,7 +751,8 @@ $idprenota = risul_query($prenotacanc,$num2,'idprenota');
 $ospiti = esegui_query("select idclienti from $tablerclientiprenota_mostra where idprenota = '$idprenota' ");
 for ($num3 = 0 ; $num3 < numlin_query($ospiti) ; $num3++) $cliente_attivo[risul_query($ospiti,$num3,'idclienti')] = 1;
 } # fine for $num2
-} # fine ($anno_mostra >= $anno_corr)
+} # fine if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99)
+} # fine if ($anno_mostra >= $anno_corr)
 } # fine for $num1
 if ($cli_pass) {
 $clienti = esegui_query("select * from $tableclienti $condizione_utente_canc");
