@@ -295,7 +295,8 @@ for (n1 = 0 ; n1 < righe.length ; n1++) {
 if (righe[n1].className == 'rd_r') {
 caselle = righe[n1].getElementsByTagName('td');
 for (n2 = 0 ; n2 < caselle.length ; n2++) {
-if (caselle[n2].className == 'rd_'+c_ini) {
+var cas_ini = 'rd_'+c_ini+' ';
+if (caselle[n2].className == 'rd_'+c_ini || caselle[n2].className.substr(0,cas_ini.length) == cas_ini) {
 for (n3 = 0 ; n3 <= (c_fine - c_ini) ; n3++) {
 if (ArCoOr[(c_ini + n3)] == null) ArCoOr[(c_ini + n3)] = caselle[(n2 + n3)].style.backgroundColor;
 if (colore == colore_date_norm) caselle[(n2 + n3)].style.backgroundColor = ArCoOr[(c_ini + n3)];
@@ -318,7 +319,7 @@ ArCoOr.length = 0;
 var caselle = '';
 var tabelle = document.getElementsByTagName('table');
 for (n0 = 0 ; n0 < tabelle.length ; n0++) {
-if (tabelle[n0].className == 'm1') {
+if (tabelle[n0].className == 'm1' || tabelle[n0].className.substr(0,3) == 'm1 ') {
 var righe = tabelle[n0].childNodes[0].childNodes;
 for (n1 = 0 ; n1 < righe.length ; n1++) {
 if (righe[n1].className != 'rd_r') {
@@ -556,15 +557,22 @@ var link_elem = document.getElementById(id_prn).getElementsByTagName('a')[0];
 if (!ArTiOr[id_prn]) ArTiOr[id_prn] = link_elem.getAttribute('title');
 if (!ArTiPr[id_prn]) {
 var xmlhttp = new XMLHttpRequest();
-xmlhttp.open('GET','tabella.php?id_sessione='+id_sessione+'&dati_prn='+id_prn,false);
-xmlhttp.send();
+xmlhttp.onload = function (e) {
+if (xmlhttp.readyState === 4) {
+if (xmlhttp.status === 200) {
 var dati_prn = xmlhttp.responseXML.getElementsByTagName('txt');
 if (dati_prn.length) {
 ArTiPr[id_prn] = dati_prn[0].childNodes[0].nodeValue;
-}
-}
 if (ArTiPr[id_prn]) link_elem.setAttribute('title',ArTiPr[id_prn]);
 }
+}
+}
+};
+xmlhttp.open('GET','tabella.php?id_sessione='+id_sessione+'&dati_prn='+id_prn,true);
+xmlhttp.send();
+}
+else link_elem.setAttribute('title',ArTiPr[id_prn]);
+}
 
 
 
@@ -652,7 +660,7 @@ var caselle = '';
 var caselle_prn = '';
 var tabelle = document.getElementsByTagName('TABLE');
 for (n0 = 0 ; n0 < tabelle.length ; n0++) {
-if (tabelle[n0].className == 'm1') {
+if (tabelle[n0].className == 'm1' || tabelle[n0].className.substr(0,3) == 'm1 ') {
 var righe = tabelle[n0].childNodes[0].childNodes;
 for (n1 = 0 ; n1 < righe.length ; n1++) {
   
@@ -819,7 +827,7 @@ if (Ap_IF[n0].getElementsByTagName('cki').length) CkIF[idapp] = 1;
 
 var tabelle = document.getElementsByTagName('table');
 for (n0 = 0 ; n0 < tabelle.length ; n0++) {
-if (tabelle[n0].className == 'm1') {
+if (tabelle[n0].className == 'm1' || tabelle[n0].className.substr(0,3) == 'm1 ') {
 
 var djs = g_agg_xml[ncol].getElementsByTagName('djs')[0].childNodes[0].nodeValue;
 var gjs = djs.substr(8,2);
@@ -978,7 +986,8 @@ if (righe[n1].className == 'rd_r') {
 caselle = righe[n1].getElementsByTagName('td');
 var colore1 = caselle[1].style.backgroundColor;
 for (n2 = 1 ; n2 < (caselle.length - 1) ; n2++) {
-caselle[n2].className = 'rd_'+(n2 - 1);
+if (n1 == 0) caselle[n2].className = 'rd_'+(n2 - 1)+' t1top';
+else caselle[n2].className = 'rd_'+(n2 - 1);
 if (gjs == '16' && direz == 'dx') {
 if (caselle[n2].style.backgroundColor == colore1) caselle[n2].style.backgroundColor = colore_date_altre;
 else caselle[n2].style.backgroundColor = colore_date_norm;
@@ -1065,7 +1074,7 @@ document.getElementById('dfine_contr').value = ArDaCo[(ArDaCo.length - 1)];
 var lpren_contr = '';
 var tabelle = document.getElementsByTagName('table');
 for (var n0 = 0 ; n0 < tabelle.length ; n0++) {
-if (tabelle[n0].className == 'm1') {
+if (tabelle[n0].className == 'm1' || tabelle[n0].className.substr(0,3) == 'm1 ') {
 var righe = tabelle[n0].childNodes[0].childNodes;
 for (var n1 = 0 ; n1 < righe.length ; n1++) {
 if (righe[n1].className != 'rd_r') {
