@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -80,12 +80,15 @@ $priv_ins_entrate = "n";
 if ($anno_utente_attivato == "SI") {
 
 
+$titolo = "HotelDruid: ".mex("Costi Gestione",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
 
 
 $Euro = nome_valuta();
+$altre_valute = altre_valute();
+$stile_soldi = stile_soldi();
 
 
 if ($priv_ins_entrate != "s") $inserisci_entrata = "";
@@ -98,10 +101,10 @@ $tabelle_lock = array($tablecosti);
 $altre_tab_lock = array($tablepersonalizza,$tablecasse);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
-if (get_magic_quotes_gpc()) $nome_costo = stripslashes($nome_costo);
+if (@get_magic_quotes_gpc()) $nome_costo = stripslashes($nome_costo);
 $nome_costo = htmlspecialchars($nome_costo);
 $nome_costo = aggslashdb($nome_costo);
-if (get_magic_quotes_gpc()) $persona_costo = stripslashes($persona_costo);
+if (@get_magic_quotes_gpc()) $persona_costo = stripslashes($persona_costo);
 $persona_costo = htmlspecialchars($persona_costo);
 $persona_costo = aggslashdb($persona_costo);
 if (!$nome_costo) {
@@ -135,7 +138,7 @@ elseif ($id_cassa != 1) $nome_cassa = risul_query($cassa_esistente,0,'nome_cassa
 } # fine else if ($attiva_casse_consentite != "n" and $casse_consentite_vett[$id_cassa] != "SI")
 } # fine else if (!$id_cassa or controlla_num_pos($id_cassa) != "SI")
 
-if (get_magic_quotes_gpc()) $metodo_pagamento = stripslashes($metodo_pagamento);
+if (@get_magic_quotes_gpc()) $metodo_pagamento = stripslashes($metodo_pagamento);
 $metodo_pagamento = htmlspecialchars($metodo_pagamento);
 if (strcmp($metodo_pagamento,"")) {
 $metodi_pagamento = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'metodi_pagamento' and idutente = '$id_utente'");
@@ -143,6 +146,23 @@ $metodi_pagamento = risul_query($metodi_pagamento,0,'valpersonalizza');
 if (str_replace(",$metodo_pagamento,",",",",$metodi_pagamento,") == ",$metodi_pagamento,") $inserire = "NO";
 } # fine if (strcmp($metodo_pagamento,""))
 
+if (strcmp($valuta,"")) {
+$n_valuta = "-1";
+for ($num1 = 0 ; $num1 < $altre_valute['num'] ; $num1++) if ($valuta == $altre_valute[$num1]['nome']) $n_valuta = $num1;
+if ($n_valuta == "-1") $inserire = "NO";
+else {
+$costo_valuta = $val_costo;
+$arrotond_tasse = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'arrotond_tasse' and idutente = '$id_utente'");
+$arrotond_tasse = risul_query($arrotond_tasse,0,'valpersonalizza');
+$val_costo = (double) $val_costo / (double) $altre_valute[$n_valuta]['cambio'];
+$val_costo = $val_costo / (double) $arrotond_tasse;
+$val_costo = round($val_costo);
+$val_costo = $val_costo * (double) $arrotond_tasse;
+$valuta = $altre_valute[$n_valuta]['nome'].">".$altre_valute[$n_valuta]['cambio'].">".$altre_valute[$n_valuta]['arrotond'];
+} # fine else if ($n_valuta == "-1")
+} # fine if (strcmp($valuta,""))
+else $costo_valuta = "";
+
 if ($inserire != "NO") {
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 if ($priv_persona_ins_costi != "c") unset($persona_costo);
@@ -164,8 +184,12 @@ $idcosti = risul_query($idcosti,0,0) + 1;
 $tipo_costo = "e";
 if ($inserisci_spesa) $tipo_costo = "s";
 esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,tipo_costo,nome_cassa,persona_costo,provenienza_costo,metodo_pagamento,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti','$nome_costo','$val_costo','$tipo_costo','".aggslashdb($nome_cassa)."','$persona_costo','$provenienza_costo','$metodo_pagamento','$datainserimento','$HOSTNAME','$id_utente') ");
-if ($inserisci_entrata) echo mex("L'entrata è stata inserita",$pag).".<br>";
-if ($inserisci_spesa) echo mex("La spesa è stata inserita",$pag).".<br>";
+if ($valuta) esegui_query("update $tablecosti set valuta = '".aggslashdb($valuta)."', costo_valuta = '".aggslashdb($costo_valuta)."' where idcosti = '$idcosti' ");
+if ($inserisci_entrata) echo mex("L'entrata è stata inserita",$pag);
+if ($inserisci_spesa) echo mex("La spesa è stata inserita",$pag);
+echo " (".punti_in_num($val_costo,$stile_soldi)." $Euro";
+if ($valuta) echo " = ".punti_in_num($costo_valuta,$stile_soldi)." ".$altre_valute[$n_valuta]['nome'];
+echo ").<br>";
 } # fine if ($inserire != "NO")
 
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"costi.php\"><div>
@@ -214,6 +238,14 @@ for ($num1 = 0 ; $num1 < count($metodi_pagamento) ; $num1++) $metodo_pagamento_t
 $metodo_pagamento_txt .= "</select>&nbsp;(".mex("opzionale",$pag).").</td></tr>";
 } # fine if ($metodi_pagamento)
 
+if ($altre_valute['num']) {
+$valute_txt = "<select name=\"valuta\">
+<option value=\"\" selected>$Euro</option>";
+for ($num1 = 0 ; $num1 < $altre_valute['num'] ; $num1++) $valute_txt .= "<option value=\"".htmlspecialchars($altre_valute[$num1]['nome'])."\">".$altre_valute[$num1]['nome']."</option>";
+$valute_txt .= "</select>";
+} # fine if ($altre_valute['num'])
+else $valute_txt = $Euro;
+
 if ($priv_ins_entrate == "s") {
 echo "<h3 id=\"h_iinc\"><span>".mex("Inserisci le entrate in cassa per l'anno",$pag)." $anno.</span></h3>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"costi.php\"><div>
@@ -230,7 +262,7 @@ echo "".mex("Natura entrata",$pag).":&nbsp;
 </td></tr>
 <tr><td>
 ".mex("Importo",$pag).":&nbsp;
-<input type=\"text\" name=\"val_costo\" size=\"10\" value=\"\">&nbsp;$Euro.
+<input type=\"text\" name=\"val_costo\" size=\"10\" value=\"\">&nbsp;$valute_txt.
 </td></tr>
 $metodo_pagamento_txt";
 if ($priv_persona_ins_costi == "c") {
@@ -266,7 +298,7 @@ echo "".mex("Natura spesa",$pag).":&nbsp;
 </td></tr>
 <tr><td>
 ".mex("Importo",$pag).":&nbsp;
-<input type=\"text\" name=\"val_costo\" size=\"10\" value=\"\">&nbsp;$Euro.
+<input type=\"text\" name=\"val_costo\" size=\"10\" value=\"\">&nbsp;$valute_txt.
 </td></tr>
 $metodo_pagamento_txt";
 if ($priv_persona_ins_costi == "c") {
