@@ -38,8 +38,7 @@ $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $tablecache = $PHPR_TAB_PRE."cache";
 
-
-if (defined("C_UTENTE_BACKUP_ESTERNO") and C_UTENTE_BACKUP_ESTERNO != "" and $utente_backup == C_UTENTE_BACKUP_ESTERNO) $id_utente = "b";
+if (defined("C_UTENTE_BACKUP_ESTERNO") and C_UTENTE_BACKUP_ESTERNO != "" and $utente_backup == C_UTENTE_BACKUP_ESTERNO and (!defined('C_VERSIONE_ATTUALE') or !defined('C_PHPR_VERSIONE_NUM') or (double) C_VERSIONE_ATTUALE == (double) C_PHPR_VERSIONE_NUM)) $id_utente = "b";
 else $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
 if ($id_utente) {
 
@@ -60,13 +59,6 @@ $anno_utente_attivato = "SI";
 
 if ($priv_crea_backup == "s") {
 
-if ($mostra_header != "NO") {
-$titolo = "HotelDruid: ".mex("Backup",$pag);
-if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
-else include("./includes/head.php");
-} # fine if ($mostra_header != "NO")
-
-
 if ($id_utente == "b") {
 $azione = "SI";
 $upload_backup = "";
@@ -76,6 +68,13 @@ $lingua_mex = "ita";
 } # fine if ($id_utente == "b")
 
 
+if ($mostra_header != "NO") {
+$titolo = "HotelDruid: ".mex("Backup",$pag);
+if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
+else include("./includes/head.php");
+} # fine if ($mostra_header != "NO")
+
+
 
 if ($azione == "SI") {
 
@@ -314,6 +313,13 @@ fwrite($file,"</database>
 echo "<br>";
 
 if ($includi_modelli == "SI") {
+$lingua_orig = $lingua_mex;
+if ($id_utente != 1) {
+include(C_DATI_PATH."/lingua.php");
+$lingua_mex_1 = $lingua[1];
+} # fine if ($id_utente != 1)
+else $lingua_mex_1 = $lingua_mex;
+$lingua_mex = $lingua_mex_1;
 include("./includes/templates/funzioni_modelli.php");
 for ($num_cart = 0 ; $num_cart < $num_perc_cart_mod_vett ; $num_cart++) {
 $percorso_cartella_modello = $perc_cart_mod_vett[$num_cart];
@@ -346,6 +352,7 @@ closedir($lang_dir);
 } # fine while ($modello_ext = readdir($templates_dir))
 closedir($templates_dir);
 } # fine for $num_cart
+$lingua_mex = $lingua_orig;
 } # fine if ($includi_modelli == "SI")
 
 fwrite($file,"</backup>");
