@@ -138,8 +138,12 @@ $encoding = "";
 if ($tipo_db == "mysqli") {
 if ($carica_estensione == "SI") dl("mysqli.so");
 $numconnessione = mysqli_connect($host_phprdb,$user_phprdb,$password_phprdb,"",$port_phprdb);
-@mysqli_query($numconnessione,"SET NAMES 'utf8'");
+@mysqli_query($numconnessione,"SET NAMES 'utf8mb4'");
+$risul = @mysqli_query($numconnessione,"SET default_storage_engine=MYISAM");
+if (!$risul) {
+sleep(1);
 @mysqli_query($numconnessione,"SET default_storage_engine=MYISAM");
+} # fine if (!$risul)
 if ($numconnessione and $database_esistente == "SI") {
 $query_db = mysqli_select_db($numconnessione,$database_phprdb);
 if (!$query_db) $numconnessione = $query_db;
@@ -165,6 +169,8 @@ else $query = "SI";
 disconnetti_db($numconnessione);
 
 if ($query) {
+$character_set_db_orig = "";
+$collation_db_orig = "";
 $character_set_db = "";
 $collation_db = "";
 if ($tipo_db == "postgresql") {
@@ -176,19 +182,32 @@ $numconnessione = mysql_connect("$host_phprdb:$port_phprdb", "$user_phprdb", "$p
 @mysql_query("SET NAMES 'utf8'");
 @mysql_query("SET default_storage_engine=MYISAM");
 mysql_select_db($database_phprdb);
+$character_set_db = "utf8";
+$collation_db = "utf8_general_ci";
 } # fine if ($tipo_db == "mysql")
 if ($tipo_db == "mysqli") {
 $numconnessione = mysqli_connect($host_phprdb,$user_phprdb,$password_phprdb,$database_phprdb,$port_phprdb);
 $link_mysqli = $numconnessione;
-@mysqli_query($numconnessione,"SET NAMES 'utf8'");
+@mysqli_query($numconnessione,"SET NAMES 'utf8mb4'");
+$risul = @mysqli_query($numconnessione,"SET default_storage_engine=MYISAM");
+if (!$risul) {
+sleep(1);
 @mysqli_query($numconnessione,"SET default_storage_engine=MYISAM");
+} # fine if (!$risul)
+$character_set_db = "utf8mb4";
+$collation_db = "utf8mb4_unicode_520_ci";
 } # fine if ($tipo_db == "mysqli")
 $character_set = esegui_query("SHOW VARIABLES LIKE 'character_set_database'");
 $collation = esegui_query("SHOW VARIABLES LIKE 'collation_database'");
 if (numlin_query($character_set) == 1 and numlin_query($collation) == 1) {
-$character_set_db = risul_query($character_set,0,"Value");
-$collation_db = risul_query($collation,0,"Value");
-if ($character_set_db != "utf8" or $collation_db != "utf8_general_ci") esegui_query("alter database $database_phprdb default character set 'utf8' collate 'utf8_general_ci'");
+$character_set_db_orig = risul_query($character_set,0,"Value");
+$collation_db_orig = risul_query($collation,0,"Value");
+if ($character_set_db != $character_set_db_orig or $collation_db != $collation_db_orig) {
+$disp_err_orig = ini_get('display_errors');
+if ($disp_err_orig) ini_set('display_errors','0');
+esegui_query("alter database $database_phprdb default character set '$character_set_db' collate '$collation_db'");
+if ($disp_err_orig) ini_set('display_errors',$disp_err_orig);
+} # fine if ($character_set_db != $character_set_db_orig or $collation_db != $collation_db_orig)
 } # fine if (numlin_query($character_set) == 1 and...
 } # fine if ($tipo_db == "mysql" or $tipo_db == "mysqli")
 if ($tipo_db == "sqlite") {
@@ -561,7 +580,7 @@ $permessi_scrittura_controllati = "SI";
 $torna_indietro = "SI";
 } # fine else if ($fileaperto = @fopen(C_DATI_PATH."/dati_connessione.php","a+"))
 
-if ($database_esistente != "NO" and $character_set_db and ($character_set_db != "utf8" or $collation_db != "utf8_general_ci")) esegui_query("alter database $database_phprdb default character set '$character_set_db' collate '$collation_db'");
+if ($database_esistente != "NO" and $character_set_db_orig and ($character_set_db != $character_set_db_orig or $collation_db != $collation_db_orig)) @esegui_query("alter database $database_phprdb default character set '$character_set_db_orig' collate '$collation_db_orig'");
 } # fine if ($query)
 
 else {
