@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -63,14 +63,14 @@ define('C_CAMBIA_TIPO_PERIODI',"SI");
 define('C_DISABILITA_PASS_ADMIN',"SI");
 define('C_MOSTRA_COPYRIGHT',"SI"); # You are not authorized to remove the copyright notice. Ask info@digitaldruid.net
 # 0 per nessuna limitazione
-define('C_MASSIMO_NUM_UTENTI',50);
-define('C_MASSIMO_NUM_CLIENTI',90000);
-define('C_MASSIMO_NUM_TARIFFE',120);
-define('C_MASSIMO_NUM_CONTRATTI',70);
+define('C_MASSIMO_NUM_UTENTI',80);
+define('C_MASSIMO_NUM_CLIENTI',120000);
+define('C_MASSIMO_NUM_TARIFFE',180);
+define('C_MASSIMO_NUM_CONTRATTI',90);
 define('C_MASSIMO_NUM_COSTI_AGG',1500);
-define('C_MASSIMO_NUM_COSTI_AGG_IN_PRENOTA',240);
-define('C_MASSIMO_NUM_STORIA_SOLDI',120000);
-define('C_MASSIMO_NUM_COSTI',80000);
+define('C_MASSIMO_NUM_COSTI_AGG_IN_PRENOTA',250);
+define('C_MASSIMO_NUM_STORIA_SOLDI',140000);
+define('C_MASSIMO_NUM_COSTI',90000);
 define('C_MASSIMO_NUM_APP',0);
 define('C_MASSIMO_NUM_BYTE_UPLOAD',12582912);
 define('C_CREA_ULTIMO_ACCESSO',"SI");
@@ -107,7 +107,7 @@ define('C_UTENTE_CANC_CC',"");
 define('C_FILE_TITOLO_PERS',"");
 define('C_FILE_CSS_PERS',"");
 define('C_FILE_MOB_CSS_PERS',"");
-define('C_FILE_DOMINIO',"");
+define('C_FILE_DOMINIO',""); # secure domains file will be searched as C_FILE_DOMINIO.'_https'
 define('C_DOMINIO_ADMIN_DIR',"");
 
 # Restrizioni per la demo amministratore
