@@ -72,6 +72,8 @@ if (strcmp(risul_query($dati_cliente,0,'telefono2'),"")) ${"telefono2_".$num_c}
 if (strcmp(risul_query($dati_cliente,0,'telefono3'),"")) ${"telefono3_".$num_c} = risul_query($dati_cliente,0,'telefono3');
 if (strcmp(risul_query($dati_cliente,0,'fax'),"")) ${"fax_".$num_c} = risul_query($dati_cliente,0,'fax');
 if (strcmp(risul_query($dati_cliente,0,'email'),"")) ${"email_".$num_c} = risul_query($dati_cliente,0,'email');
+if (strcmp(risul_query($dati_cliente,0,'email2'),"")) ${"email2_".$num_c} = risul_query($dati_cliente,0,'email2');
+if (strcmp(risul_query($dati_cliente,0,'email3'),"")) ${"email_certificata_".$num_c} = risul_query($dati_cliente,0,'email3');
 } # fine if ($priv_vedi_telefoni == "s")
 if (strcmp(risul_query($dati_cliente,0,'cod_fiscale'),"")) ${"codice_fiscale_".$num_c} = risul_query($dati_cliente,0,'cod_fiscale');
 if (strcmp(risul_query($dati_cliente,0,'partita_iva'),"")) ${"partita_iva_".$num_c} = risul_query($dati_cliente,0,'partita_iva');
