@@ -190,7 +190,7 @@ $costo_agg_tot = (double) 0;
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prenota,$dati_cat_pers);
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$id_data_inizio,$id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","");
-$costo_agg_parziale = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$id_data_inizio,$id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$costo_tariffa,$tariffesettimanali,($costo_tariffa + $costo_agg_tot - $sconto),$caparra,$numpersone,0,1);
+$costo_agg_parziale = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$id_data_inizio,$id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$costo_tariffa,$tariffesettimanali,($costo_tariffa + $costo_agg_tot - $sconto),$caparra,$numpersone,$dati_cap[$numca]['cat_pers'],0,0,1);
 $costo_agg_tot = (double) $costo_agg_tot + $costo_agg_parziale;
 if ($priv_mod_costi_agg != "n") {
 ${"nome_costo_agg".$numca."_".$num_r} = $dati_cap[$numca]['nome'];
@@ -240,13 +240,15 @@ for ($num2 = 1 ; $num2 < (count($id_anni_prec_vett) - 1) ; $num2++) {
 $id_anno_prec = explode(",",$id_anni_prec_vett[$num2]);
 $anno_prec_esistente = esegui_query("select idanni from $tableanni where idanni = '".aggslashdb($id_anno_prec[0])."'");
 if (numlin_query($anno_prec_esistente)) {
-$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,valuta,data_inserimento,utente_inserimento from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
+if (defined('C_VERSIONE_ATTUALE') and C_VERSIONE_ATTUALE < 3.00) $pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento,utente_inserimento from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
+else $pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,valuta,data_inserimento,utente_inserimento from $PHPR_TAB_PRE"."soldi".$id_anno_prec[0]." where saldo_prenota is not NULL and motivazione $LIKE '%;".$id_anno_prec[1]."' order by data_inserimento");
 $num_pagamenti2 = numlin_query($pagamenti);
 for ($num3 = 0 ; $num3 < $num_pagamenti2 ; $num3++) {
 ${"data_paga".$num_pagamenti."_".$num_r} = substr(risul_query($pagamenti,$num3,'data_inserimento'),0,10);
 ${"utente_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'utente_inserimento');
 if (strcmp(risul_query($pagamenti,$num3,'metodo_pagamento'),"")) ${"metodo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'metodo_pagamento');
 ${"saldo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num3,'saldo_prenota');
+if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99) {
 $valuta_paga = risul_query($pagamenti,$num3,'valuta');
 if ($valuta_paga) {
 $valuta_paga = explode(">",$valuta_paga);
@@ -254,18 +256,21 @@ ${"valuta_paga".$num_pagamenti."_".$num_r} = $valuta_paga[0];
 ${"tasso_cambio_paga".$num_pagamenti."_".$num_r} = $valuta_paga[1];
 ${"valore_valuta_paga".$num_pagamenti."_".$num_r} = converti_valuta(${"saldo_paga".$num_pagamenti."_".$num_r},$valuta_paga[1],$valuta_paga[2]);
 } # fine if ($valuta_paga)
+} # fine if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99)
 $num_pagamenti++;
 } # fine for $num3
 } # fine (numlin_query($anno_prec_esistente))
 } # fine for $num2
 } # fine if (${"id_anni_prec_".$num_r})
-$pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,valuta,data_inserimento,utente_inserimento from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
+if (defined('C_VERSIONE_ATTUALE') and C_VERSIONE_ATTUALE < 3.00) $pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,data_inserimento,utente_inserimento from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
+else $pagamenti = esegui_query("select metodo_pagamento,saldo_prenota,valuta,data_inserimento,utente_inserimento from $tablesoldi where saldo_prenota is not NULL and motivazione $LIKE '%;$id_prenota' order by data_inserimento");
 $num_pagamenti2 = numlin_query($pagamenti);
 for ($num2 = 0 ; $num2 < $num_pagamenti2 ; $num2++) {
 ${"data_paga".$num_pagamenti."_".$num_r} = substr(risul_query($pagamenti,$num2,'data_inserimento'),0,10);
 ${"utente_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num2,'utente_inserimento');
 if (strcmp(risul_query($pagamenti,$num2,'metodo_pagamento'),"")) ${"metodo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num2,'metodo_pagamento');
 ${"saldo_paga".$num_pagamenti."_".$num_r} = risul_query($pagamenti,$num2,'saldo_prenota');
+if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99) {
 $valuta_paga = risul_query($pagamenti,$num2,'valuta');
 if ($valuta_paga) {
 $valuta_paga = explode(">",$valuta_paga);
@@ -273,6 +278,7 @@ ${"valuta_paga".$num_pagamenti."_".$num_r} = $valuta_paga[0];
 ${"tasso_cambio_paga".$num_pagamenti."_".$num_r} = $valuta_paga[1];
 ${"valore_valuta_paga".$num_pagamenti."_".$num_r} = converti_valuta(${"saldo_paga".$num_pagamenti."_".$num_r},$valuta_paga[1],$valuta_paga[2]);
 } # fine if ($valuta_paga)
+} # fine if (!defined('C_VERSIONE_ATTUALE') or C_VERSIONE_ATTUALE > 2.99)
 $num_pagamenti++;
 } # fine for $num2
 ${"num_pagamenti_".$num_r} = $num_pagamenti;
