@@ -97,8 +97,9 @@ $files_sorgente = array(
 'includes/',
 'includes/costanti.php',
 'includes/dati_form_prenotazione.php',
-'includes/dati_lista_prenota.php',
+'includes/dati_lista_cassa.php',
 'includes/dati_lista_clienti.php',
+'includes/dati_lista_prenota.php',
 'includes/files_sorgente.php',
 'includes/foot.php',
 'includes/funzioni_aggiorna.php',
@@ -126,6 +127,7 @@ $files_sorgente = array(
 'includes/funzioni_sqlite.php',
 'includes/funzioni_tariffe.php',
 'includes/funzioni_testo.php',
+'includes/funzioni_web.php',
 'includes/head.php',
 'includes/.htaccess',
 'includes/liberasettimane.php',
