@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -21,20 +21,22 @@
 ##################################################################################
 
 
-error_reporting(E_ALL ^ E_NOTICE);
+#error_reporting(E_ALL ^ E_NOTICE);
+error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED);
+#error_reporting(E_ALL);
 if (function_exists('mb_internal_encoding')) mb_internal_encoding('UTF-8');
 if (function_exists('date_default_timezone_set')) if (!ini_get('date.timezone')) date_default_timezone_set('UTC');
 
 
 # nel caso fosse settato register_globals = Off
 if (@is_array($_POST)) reset($_POST);
-for($num1 = 0 ; $num1 < count($_POST); $num1++) {
+for ($num1 = 0 ; $num1 < count($_POST); $num1++) {
 $var_POST = key($_POST);
 if (!isset($$var_POST)) $$var_POST = $_POST[$var_POST];
 next($_POST);
 } # fine for $num1
 if (@is_array($_GET)) reset($_GET);
-for($num1 = 0 ; $num1 < count($_GET); $num1++) {
+for ($num1 = 0 ; $num1 < count($_GET); $num1++) {
 $var_GET = key($_GET);
 if (!isset($$var_GET)) $$var_GET = $_GET[$var_GET];
 next($_GET);
@@ -49,12 +51,17 @@ $trad_ui = 0;
 
 #$pag = explode("/", $SCRIPT_NAME);
 #$pag = end($pag);
-$tablepersonalizza = $PHPR_TAB_PRE."personalizza";
+if (isset($PHPR_TAB_PRE)) $tablepersonalizza = $PHPR_TAB_PRE.'personalizza';
+else $tablepersonalizza = 'personalizza';
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',3.00);
-define('C_PHPR_VERSIONE_TXT',"3.0.0");
+define('C_PHPR_VERSIONE_NUM',3.01);
+define('C_PHPR_VERSIONE_TXT',"3.0.1");
+
+if (!isset($nome_utente_phpr)) $nome_utente_phpr = "";;
+if (!isset($password_phpr)) $password_phpr = "";;
+if (!isset($id_sessione)) $id_sessione = "";;
 
 if (!function_exists('utf8_encode')) {
 function utf8_encode ($testo) { return ($testo); }
@@ -67,10 +74,12 @@ function get_magic_quotes_gpc () { return 0; }
 $id_sessione = htmlspecialchars($id_sessione);
 
 # Se non si specifica nessun anno uso l'attuale
-if (@is_file(C_DATI_PATH."/versione.php") and !defined('C_DIFF_ORE')) include(C_DATI_PATH."/versione.php");
-elseif (!defined('C_DIFF_ORE')) define('C_DIFF_ORE',0);
+if (!defined('C_DIFF_ORE')) {
+if (@is_file(C_DATI_PATH."/versione.php")) include(C_DATI_PATH."/versione.php");
+else define('C_DIFF_ORE',0);
+} # fine if (!defined('C_DIFF_ORE'))
 $anno_corrente = date("Y",(time() + (C_DIFF_ORE * 3600)));
-if (!$anno) {
+if (!isset($anno) or !$anno) {
 if ($id_sessione) $anno = substr($id_sessione,0,4);
 else {
 if (!defined('C_GIORNI_NUOVO_ANNO')) include("./costanti.php");
@@ -80,15 +89,17 @@ if ($anno_corrente != $anno) {
 if (@is_file(C_DATI_PATH."/selectperiodi$anno_corrente.1.php") or !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $anno = $anno_corrente;
 } # fine if ($anno_corrente != $anno)
 } # fine else if ($id_sessione)
-} # fine if (!$anno)
+} # fine if (!isset($anno) or !$anno)
+if ($id_sessione and $pag != "inizio.php" and $pag != "api.php" and $pag != "aggiorna.php" and !is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $id_sessione = "";
 
-if ($vers_hinc) $vers_hinc = "?v=".C_PHPR_VERSIONE_NUM;
+
+if (isset($vers_hinc)) $vers_hinc = "?v=".C_PHPR_VERSIONE_NUM;
 
 if ($_SERVER['SERVER_NAME']) $HOSTNAME = $_SERVER['SERVER_NAME'];
 elseif ($SERVER_NAME) $HOSTNAME = $SERVER_NAME;
 $HOSTNAME = htmlspecialchars($HOSTNAME);
 
-if (strstr($_SERVER['HTTP_USER_AGENT'],'(iP') or strstr($_SERVER['HTTP_USER_AGENT'],'Android') or strstr($_SERVER['HTTP_USER_AGENT'],'webOS') or strstr($_SERVER['HTTP_USER_AGENT'],'BlackBerry') or strstr($_SERVER['HTTP_USER_AGENT'],'Mobile') or strstr($_SERVER['HTTP_USER_AGENT'],'Opera Mobi')) $mobile_device = 1;
+if (strstr($_SERVER['HTTP_USER_AGENT'],'(iP') or strstr($_SERVER['HTTP_USER_AGENT'],'Android') or strstr($_SERVER['HTTP_USER_AGENT'],'webOS') or strstr($_SERVER['HTTP_USER_AGENT'],'BlackBerry') or strstr($_SERVER['HTTP_USER_AGENT'],'Mobile') or strstr($_SERVER['HTTP_USER_AGENT'],'Opera Mini')) $mobile_device = 1;
 else $mobile_device = 0;
 
 
@@ -137,6 +148,16 @@ return $messaggio;
 
 
 
+function fixset (&$var) {
+
+if (isset($var)) $ris = $var;
+else $ris = null;
+return $ris;
+
+} # fine function fixset
+
+
+
 function controlla_anno ($anno) {
 
 $verificato = "SI";
@@ -408,12 +429,14 @@ $id_utente = "";
 
 function controlla_login (&$numconnessione,&$PHPR_TAB_PRE,&$id_sessione,$nome_utente_phpr,$password_phpr,$anno) {
 
+$id_utente = "";
+$messaggio_errore = "";
 $avviso_giorni_scadenza = 0;
 if (defined('C_FILE_SCADENZA_ACCOUNT') and C_FILE_SCADENZA_ACCOUNT != "") {
 $scadenza = trim(@implode("",@file("./".C_FILE_SCADENZA_ACCOUNT)));
 $adesso = date("YmdHis");
 if (!$scadenza or $scadenza < $adesso) {
-$disattivato = "SI";
+$disattivato = 1;
 if (defined("C_HTML_PRE_LOGIN") and C_HTML_PRE_LOGIN != "") echo C_HTML_PRE_LOGIN;
 echo "Expired account.<br>";
 if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "") echo C_HTML_POST_LOGIN;
@@ -424,7 +447,7 @@ $limite_giorni_avviso = date("YmdHis",(time() + ($giorni_avviso * 86400)));
 if ($scadenza < $limite_giorni_avviso) $avviso_giorni_scadenza = 1;
 } # fine elseif (defined('C_HTML_POST_LOGIN') and C_HTML_POST_LOGIN != "")
 } # fine (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "")
-if (!$disattivato) {
+if (!isset($disattivato)) {
 
 global $lingua_mex,$tema,$pag,$ILIKE,$LIKE,$DATETIME,$nome_utente_login,$PHPR_LOG;
 @include(C_DATI_PATH."/lingua.php");
@@ -461,7 +484,7 @@ $sec_log_sbagliati = 5;
 $limite_login_sbagliati = date("Y-m-d H:i:s",(time() - $sec_log_sbagliati + (C_DIFF_ORE * 3600)));
 $ultimo_login_sbagliato = esegui_query("select ultimo_accesso from $tabletransazioni where tipo_transazione = 'err_l' and dati_transazione1 = '".aggslashdb($nome_utente_phpr)."' and ultimo_accesso >= '$limite_login_sbagliati'");
 if (numlin_query($ultimo_login_sbagliato) > 0) {
-$mostra_form_login = "SI";
+$mostra_form_login = 1;
 $messaggio_errore .= mex("Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere","funzioni.php")." $sec_log_sbagliati ".mex("secondi","funzioni.php").".<br><br>";
 } # fine if (numlin_query($ultimo_login_sbagliato) > 0)
 else {
@@ -496,7 +519,7 @@ echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
 exit();
 } # fine if ($_SERVER['REQUEST_METHOD'] == "GET")
 else {
-$mostra_form_login = "SI";
+$mostra_form_login = 1;
 $pag = "inizio.php";
 } # fine else if ($_SERVER['REQUEST_METHOD'] == "GET")
 } # fine if ($pag != "inizio.php" and !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php"))
@@ -540,11 +563,11 @@ if (C_VERSIONE_ATTUALE >= 2.1) esegui_query("insert into $tablesessioni (idsessi
 else esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente','$REMOTE_ADDR','$HTTP_USER_AGENT','$ultimo_accesso')","",$id_utente);
 } # fine if ($password == $password_phpr and $tipo_pass != "n")
 
-else $login_fallito = "SI";
+else $login_fallito = 1;
 } # fine if (numlin_query($utente) == 1)
-else $login_fallito = "SI";
-if ($login_fallito == "SI") {
-$mostra_form_login = "SI";
+else $login_fallito = 1;
+if (isset($login_fallito)) {
+$mostra_form_login = 1;
 $messaggio_errore .= mex("Nome utente o password <div style=\"display: inline; color: red;\">errati</div>","funzioni.php").".<br>";
 if ($login_sbagliati >= ($num_log_sbagliati - $num_log_avviso - 1)) {
 if (($num_log_sbagliati - $login_sbagliati - 1) > 1) $messaggio_errore .= mex("Mancano solo","funzioni.php")." <span class=\"colred\"><b>".($num_log_sbagliati - $login_sbagliati - 1)."</b></span> ".mex("tentativi prima del blocco dei login","funzioni.php").".<br>";
@@ -562,14 +585,14 @@ if ($_SERVER['REMOTE_ADDR']) $REMOTE_ADDR = $_SERVER['REMOTE_ADDR'];
 $REMOTE_ADDR = aggslashdb($REMOTE_ADDR);
 $id_transazione = $adesso.$val_casuale.$versione_transazione;
 esegui_query("insert into $tabletransazioni (idtransazioni,tipo_transazione,dati_transazione1,dati_transazione2,ultimo_accesso) values ('$id_transazione','err_l','$nome_utente_phpr','$REMOTE_ADDR','$ultimo_accesso')");
-} # fine if ($login_fallito == "SI")
+} # fine if (isset($login_fallito))
 
 } # fine else if ($pag != "inizio.php" and !@is_file(C_DATI_PATH."/selectperiodi$anno.1.php")
 } # fine else if ($login_sbagliati >= $num_log_sbagliati)
 } # fine else if (numlin_query($ultimo_login_sbagliato) > 0)
 unlock_tabelle($tabelle_lock);
 } # fine if ($nome_utente and $password)
-else $mostra_form_login = "SI";
+else $mostra_form_login = 1;
 } # fine if (!$id_sessione)
 
 else {
@@ -609,27 +632,28 @@ $nome_utente_login = risul_query($utente_presente,0,'nome_utente');
 $id_utente = $id_utente_presunto;
 esegui_query("update $tablesessioni set ultimo_accesso = '$ultimo_accesso' where idsessioni = '$id_sessione'");
 } # fine if (numlin_query($utente_presente) == 1)
-else $sessione_scaduta = "SI";
+else $sessione_scaduta = 1;
 } # fine if (($indirizzo_ip == $REMOTE_ADDR and $user_agent == $HTTP_USER_AGENT) or...
-else $sessione_scaduta = "SI";
+else $sessione_scaduta = 1;
 } # fine if (numlin_query($sessione) == 1)
-else $sessione_scaduta = "SI";
+else $sessione_scaduta = 1;
 unlock_tabelle($tabelle_lock);
-if ($sessione_scaduta == "SI") {
-$mostra_form_login = "SI";
+if (isset($sessione_scaduta)) {
+$mostra_form_login = 1;
 $messaggio_errore .= "".mex("Sessione <div style=\"display: inline; color: red;\">scaduta</div>","funzioni.php").".<br><br>";
-} # fine if ($sessione_scaduta == "SI")
+} # fine if (isset($sessione_scaduta))
 } # fine else if (!$id_sessione)
 
-if ($messaggio_errore or $mostra_form_login == "SI") {
+if ($messaggio_errore or isset($mostra_form_login)) {
+$input_var_passate = "";
 if ($pag == "aggiorna.php") $action = "aggiorna.php";
 else {
-if (!$_SERVER['HTTP_REFERER'] or !$_SERVER['SERVER_NAME']) $pag = "";
+if (!isset($_SERVER['HTTP_REFERER']) or !isset($_SERVER['SERVER_NAME'])) $pag = "";
 else {
 if (($_SERVER['HTTPS'] and $_SERVER['HTTPS'] != 'off') or $_SERVER['SERVER_PORT'] == "443") $url_dom = "https://".$_SERVER['SERVER_NAME']."/";
 else $url_dom = "http://".$_SERVER['SERVER_NAME']."/";
 if (substr($_SERVER['HTTP_REFERER'],0,strlen($url_dom)) != $url_dom) $pag = "";
-} # fine else if (!$_SERVER['HTTP_REFERER'] or !$_SERVER['SERVER_NAME'])
+} # fine else if (!isset($_SERVER['HTTP_REFERER']) or !isset($_SERVER['SERVER_NAME']))
 if ((@is_array($_POST) or @is_array($_GET)) and $pag) {
 $action = $pag;
 if (@is_array($_POST)) {
@@ -661,12 +685,12 @@ else include("./includes/head.php");
 if (!defined('C_URL_LOGO') or C_URL_LOGO == "") echo "<div id=\"flogin\">";
 else echo "<div style=\"background: url(".C_URL_LOGO.") no-repeat right top; padding: 5px; line-height: 1.6;\">";
 echo $messaggio_errore;
-} # fine if ($messaggio_errore or $mostra_form_login == "SI")
-if ($mostra_form_login == "SI") {
+} # fine if ($messaggio_errore or isset($mostra_form_login))
+if (isset($mostra_form_login)) {
 if (@is_file(C_DATI_PATH."/dati_subordinazione.php")) include(C_DATI_PATH."/dati_subordinazione.php");
 if (defined("C_HTML_PRE_LOGIN") and C_HTML_PRE_LOGIN != "") echo C_HTML_PRE_LOGIN;
 $mess = $titolo;
-if ($commento_subordinazione) $mess .= " ($commento_subordinazione)";
+if (isset($commento_subordinazione)) $mess .= " ($commento_subordinazione)";
 echo "<big><big>$mess:</big></big><br><div style=\"height: 6px\"></div>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$action\"><div>
 <input type=\"hidden\" name=\"vers_hinc\" value=\"1\">
@@ -683,8 +707,8 @@ $scadenza_vedi = "<span class=\"colred\">".substr($scadenza,0,4)."-".substr($sca
 echo "<br><span class=\"colred\">".mex("Avviso","funzioni.php")."</span>:".mex("Mancano meno di","funzioni.php")." $giorni_avviso ".mex("giorni alla scadenza dell'account","funzioni.php")." ($scadenza_vedi).<br>";
 } # fine if ($avviso_giorni_scadenza)
 } # fine if (defined("C_HTML_POST_LOGIN") and C_HTML_POST_LOGIN != "")
-} # fine if ($mostra_form_login == "SI")
-if ($messaggio_errore or $mostra_form_login == "SI") {
+} # fine if (isset($mostra_form_login))
+if ($messaggio_errore or isset($mostra_form_login)) {
 
 # You are not authorized to remove the following copyright notice. Ask for permission info@digitaldruid.net
 if (!defined('C_MOSTRA_COPYRIGHT') or C_MOSTRA_COPYRIGHT != "NO") {
@@ -696,7 +720,7 @@ echo "<div>";
 
 if ($tema[1] and $tema[1] != "base" and @is_dir("./themes/".$tema[1]."/php")) include("./themes/".$tema[1]."/php/foot.php");
 else include("./includes/foot.php");
-} # fine if ($messaggio_errore or $mostra_form_login == "SI")
+} # fine if ($messaggio_errore or isset($mostra_form_login))
 
 if ($id_utente and ($lingua[$id_utente] == "ita" or @is_dir("./includes/lang/".$lingua[$id_utente]))) $lingua_mex = $lingua[$id_utente];
 } # fine else if (!is_file(C_DATI_PATH."/abilita_login"))
@@ -734,7 +758,7 @@ unset($id_utente);
 
 return $id_utente;
 
-} # fine if (!$disattivato)
+} # fine if (!isset($disattivato))
 
 } # fine function controlla_login
 
@@ -948,6 +972,7 @@ else echo "$js += '".str_replace("\n","\\\n",$out)."';
 else unset($dates_options_list);
 
 if (substr($file,0,(strlen(C_DATI_PATH) + 15)) == C_DATI_PATH."/selperiodimenu" and floor($current_dates_menu / 2) != (($current_dates_menu - 1) / 2) and $mos_tut_dat != "SI" and $modifica_pers != "NO" and $partial_dates) {
+$lista_var = "";
 if (@is_array($_POST)) reset($_POST);
 for($num1 = 0 ; $num1 < count($_POST); $num1++) {
 if (key($_POST) != "mos_tut_dat" and substr(key($_POST),0,8) != "modifica") $lista_var .= "&amp;".htmlspecialchars(key($_POST))."=".htmlspecialchars(strip_magic_slashs($_POST[key($_POST)]));
@@ -959,6 +984,7 @@ if (key($_GET) != "mos_tut_dat" and substr(key($_GET),0,8) != "modifica") $lista
 next($_GET);
 } # fine for $num1
 if ($lista_var) {
+global $pag;
 $lista_var = "?mos_tut_dat=SI".$lista_var;
 $out = "<a href=\"$pag$lista_var\" style=\"text-decoration: none;\" title=\"".mex("mostra tutte le date","inizio.php")."\"><b style=\"font-weight: normal; color: #666666;\">&prime;</b></a>";
 if (!$js) echo $out;
@@ -970,7 +996,7 @@ else echo "$js += '".str_replace("\n","\\\n",$out)."';
 $last_dates_menu = $file;
 
 } # fine function mostra_menu_date
-if ($mos_tut_dat) $mos_tut_dat = "SI";
+if (isset($mos_tut_dat)) $mos_tut_dat = "SI";
 
 
 
