@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -26,7 +26,7 @@
 function crea_nuovo_anno ($anno,$PHPR_TAB_PRE,$DATETIME,$tipo_periodi,$giorno_ini_fine,$mese_ini,$mese_fine,$importa_anno_prec,$silenzio,$pag) {
 
 allunga_tempo_limite();
-global $lingua_mex,$LIKE,$ILIKE,$PHPR_DB_TYPE;
+global $lingua_mex,$LIKE,$ILIKE,$PHPR_DB_TYPE,$PHPR_DB_NAME;
 $lingua_mex_orig = $lingua_mex;
 include_once("./includes/funzioni_menu.php");
 include(C_DATI_PATH."/lingua.php");
@@ -45,7 +45,37 @@ $tableutenti = $PHPR_TAB_PRE."utenti";
 $tablerelclienti = $PHPR_TAB_PRE."relclienti";
 
 
-if ($PHPR_DB_TYPE == "mysql" or $PHPR_DB_TYPE == "mysqli") @esegui_query("SET default_storage_engine=MYISAM",1);
+$character_set_db_orig = "";
+$collation_db_orig = "";
+$character_set_db = "";
+$collation_db = "";
+if ($PHPR_DB_TYPE == "mysql" or $PHPR_DB_TYPE == "mysqli") {
+$risul = @esegui_query("SET default_storage_engine=MYISAM",1);
+if (!$risul) {
+sleep(1);
+@esegui_query("SET default_storage_engine=MYISAM",1);
+} # fine if (!$risul)
+if ($PHPR_DB_TYPE == "mysql") {
+$character_set_db = "utf8";
+$collation_db = "utf8_general_ci";
+} # fine if ($PHPR_DB_TYPE == "mysql")
+if ($PHPR_DB_TYPE == "mysqli") {
+$character_set_db = "utf8mb4";
+$collation_db = "utf8mb4_unicode_520_ci";
+} # fine if ($PHPR_DB_TYPE == "mysqli")
+$character_set = esegui_query("SHOW VARIABLES LIKE 'character_set_database'");
+$collation = esegui_query("SHOW VARIABLES LIKE 'collation_database'");
+if (numlin_query($character_set) == 1 and numlin_query($collation) == 1) {
+$character_set_db_orig = risul_query($character_set,0,"Value");
+$collation_db_orig = risul_query($collation,0,"Value");
+if ($character_set_db != $character_set_db_orig or $collation_db != $collation_db_orig) {
+$disp_err_orig = ini_get('display_errors');
+if ($disp_err_orig) ini_set('display_errors','0');
+esegui_query("alter database $PHPR_DB_NAME default character set '$character_set_db' collate '$collation_db'");
+if ($disp_err_orig) ini_set('display_errors',$disp_err_orig);
+} # fine if ($character_set_db != $character_set_db_orig or $collation_db != $collation_db_orig)
+} # fine if (numlin_query($character_set) == 1 and...
+} # fine if ($PHPR_DB_TYPE == "mysql" or $PHPR_DB_TYPE == "mysqli")
 
 $filelock = fopen(C_DATI_PATH."/anni.lock","w+");
 if ($filelock) {
@@ -347,6 +377,9 @@ $idprenota_corr = 0;
 $nuovo_idprenota_iniziata = array();
 $max_idprenota_prec = esegui_query("select max(idprenota) from $tableprenota_prec");
 $max_idprenota_prec = risul_query($max_idprenota_prec,0,0) + 1;
+$max_idprenotacanc_prec = esegui_query("select max(idprenota) from $tableprenotacanc_prec");
+$max_idprenotacanc_prec = risul_query($max_idprenotacanc_prec,0,0) + 1;
+if ($max_idprenotacanc_prec > $max_idprenota_prec) $max_idprenota_prec = $max_idprenotacanc_prec;
 $max_idcostiprenota_prec = esegui_query("select max(idcostiprenota) from $tablecostiprenota_prec");
 $max_idcostiprenota_prec = risul_query($max_idcostiprenota_prec,0,0) + 1;
 $prenota_gia_iniziate = esegui_query("select * from $tableprenota_prec where iddatainizio < $id_data_ini_periodi_prec and iddatafine >= $id_data_ini_periodi_prec and iddatafine <= $id_data_fine_periodi_prec ");
@@ -366,10 +399,14 @@ $utente_inserimento = risul_query($prenota_gia_iniziate,$num1,'utente_inseriment
 $checkin = risul_query($prenota_gia_iniziate,$num1,'checkin');
 $checkout = risul_query($prenota_gia_iniziate,$num1,'checkout');
 $codice = risul_query($prenota_gia_iniziate,$num1,'codice');
+$pagato = risul_query($prenota_gia_iniziate,$num1,'pagato');
+$tariffa_tot = risul_query($prenota_gia_iniziate,$num1,'tariffa_tot');
 $idprenota_corr++;
 esegui_query("insert into $tableprenota (idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,commento,codice,datainserimento,hostinserimento,utente_inserimento) values ('$idprenota_corr','$idclienti','$idappartamenti','0',$iddatafine,'k','$idprenota','$codice','$datainserimento','$hostinserimento','$utente_inserimento') ");
 if ($checkin) esegui_query("update $tableprenota set checkin = '".aggslashdb($checkin)."' where idprenota = '$idprenota_corr'");
 if ($checkout) esegui_query("update $tableprenota set checkout = '".aggslashdb($checkout)."' where idprenota = '$idprenota_corr'");
+if ($pagato) esegui_query("update $tableprenota set pagato = '".aggslashdb($pagato)."' where idprenota = '$idprenota_corr'");
+if ($tariffa_tot) esegui_query("update $tableprenota set tariffa_tot = '".aggslashdb($tariffa_tot)."' where idprenota = '$idprenota_corr'");
 esegui_query("update $tablecostiprenota_prec set idprenota = '$max_idprenota_prec' where idprenota = '$idprenota'");
 esegui_query("insert into $tablecostiprenota select $col_tablecostiprenota from $tablecostiprenota_prec where idprenota = '$max_idprenota_prec' ");
 esegui_query("update $tablecostiprenota set idprenota = '$idprenota_corr' where idprenota = '$max_idprenota_prec'");
@@ -786,6 +823,7 @@ if ($periodipermessi) {
 $pp_nuovi = substr($periodipermessi,0,1);
 $periodipermessi = explode(",",substr($periodipermessi,1));
 for ($num2 = 0 ; $num2 < count($periodipermessi) ; $num2++) {
+if ($periodipermessi[$num2]) {
 $id_data_fine_pp = explode("-",$periodipermessi[$num2]);
 $id_data_inizio_pp = $id_data_fine_pp[0];
 $id_data_fine_pp = $id_data_fine_pp[1];
@@ -796,6 +834,7 @@ $id_data_inizio_pp = $id_data_inizio_pp - $id_data_ini_periodi_prec + 1;
 $id_data_fine_pp = $id_data_fine_pp - $id_data_ini_periodi_prec + 1;
 $pp_nuovi .= $id_data_inizio_pp."-".$id_data_fine_pp.",";
 } # fine if ($id_data_fine_pp >= $id_data_ini_periodi_prec and...
+} # fine if ($periodipermessi[$num2])
 } # fine for $num2
 if (strlen($pp_nuovi) > 1) $pp_nuovi = substr($pp_nuovi,0,-1);
 esegui_query("update $tablenometariffe set periodipermessi_ca = '$pp_nuovi' where idntariffe = '$idntariffe'");
@@ -968,6 +1007,7 @@ if ($silenzio != "SI") echo "<br>";
 } # fine if ($crea_tab)
 else if ($silenzio != "SI") echo mex("Non ho i permessi per creare nuove tabelle nel database",$pag).".<br>";
 
+if ($character_set_db_orig and ($character_set_db != $character_set_db_orig or $collation_db != $collation_db_orig)) @esegui_query("alter database $PHPR_DB_NAME default character set '$character_set_db_orig' collate '$collation_db_orig'");
 
 } # fine if (numlin_query($anno_esistente) == 0)
 else if ($silenzio != "SI") echo mex("Anno già creato",$pag).".<br>";
