@@ -106,20 +106,17 @@ $idclienti = risul_query($idclienti,0,0) + 1;
 $cognome_maius = trim(ucwords($cognome));
 if ($attiva_prefisso_clienti == "p") $cognome_maius = $prefisso_clienti.$cognome_maius;
 if ($attiva_prefisso_clienti == "s") $cognome_maius = $cognome_maius.$prefisso_clienti;
-$cognome_maius = aggslashdb($cognome_maius);
-esegui_query("insert into $tableclienti (idclienti,cognome,idclienti_compagni,datainserimento,hostinserimento,utente_inserimento) values ('$idclienti','$cognome_maius',',','$datainserimento','$HOSTNAME','$id_utente_ins')");
+esegui_query("insert into $tableclienti (idclienti,cognome,idclienti_compagni,datainserimento,hostinserimento,utente_inserimento) values ('$idclienti','".aggslashdb(substr($cognome_maius,0,70))."',',','$datainserimento','$HOSTNAME','$id_utente_ins')");
 } # fine if (!$idclienti)
 elseif ($cognome) {
 $cognome_maius = trim(ucwords($cognome));
 if ($attiva_prefisso_clienti == "p") $cognome_maius = $prefisso_clienti.$cognome_maius;
 if ($attiva_prefisso_clienti == "s") $cognome_maius = $cognome_maius.$prefisso_clienti;
-$cognome_maius = aggslashdb($cognome_maius);
-esegui_query("update $tableclienti set cognome = '$cognome_maius' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set cognome = '".aggslashdb(substr($cognome_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine elseif ($cognome)
 if ($nome) {
 $nome_maius = trim(ucwords($nome));
-$nome_maius = aggslashdb($nome_maius);
-esegui_query("update $tableclienti set nome = '$nome_maius' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set nome = '".aggslashdb(substr($nome_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nome)
 if ($soprannome) {
 esegui_query("update $tableclienti set soprannome = '".aggslashdb($soprannome)."' where idclienti = '$idclienti' ");
@@ -209,18 +206,15 @@ else $lingua_cli = "";
 } # fine if ($lingua_cli)
 if ($nazione) {
 $nazione_maius = trim(ucwords($nazione));
-$nazione_maius = aggslashdb($nazione_maius);
-esegui_query("update $tableclienti set nazione = '$nazione_maius' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set nazione = '".aggslashdb(substr($nazione_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nazione)
 if ($citta) {
 $citta_maius = trim(ucwords($citta));
-$citta_maius = aggslashdb($citta_maius);
-esegui_query("update $tableclienti set citta = '$citta_maius' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set citta = '".aggslashdb(substr($citta_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($citta)
 if ($regione) {
 $regione_maius = trim(ucwords($regione));
-$regione_maius = aggslashdb($regione_maius);
-esegui_query("update $tableclienti set regione = '$regione_maius' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set regione = '".aggslashdb(substr($regione_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($regione)
 if ($nomevia) {
 if (strcmp($via,"")) {
@@ -230,21 +224,14 @@ else $via = $via." ".$nomevia;
 } # fine if (strcmp($via,""))
 else $via = $nomevia;
 $via_maius = trim(ucwords($via));
-$via_maius = aggslashdb($via_maius);
-esegui_query("update $tableclienti set via = '$via_maius' where idclienti = '$idclienti' ");
+esegui_query("update $tableclienti set via = '".aggslashdb(substr($via_maius,0,70))."' where idclienti = '$idclienti' ");
 } # fine if ($nomevia)
-$numcivico = aggslashdb($numcivico);
-if ($numcivico) esegui_query("update $tableclienti set numcivico = '$numcivico' where idclienti = '$idclienti' ");
-$cap = aggslashdb($cap);
-if ($cap) esegui_query("update $tableclienti set cap = '$cap' where idclienti = '$idclienti' ");
-$telefono = aggslashdb($telefono);
-if ($telefono) esegui_query("update $tableclienti set telefono = '$telefono' where idclienti = '$idclienti' ");
-$telefono2 = aggslashdb($telefono2);
-if ($telefono2) esegui_query("update $tableclienti set telefono2 = '$telefono2' where idclienti = '$idclienti' ");
-$telefono3 = aggslashdb($telefono3);
-if ($telefono3) esegui_query("update $tableclienti set telefono3 = '$telefono3' where idclienti = '$idclienti' ");
-$fax = aggslashdb($fax);
-if ($fax) esegui_query("update $tableclienti set fax = '$fax' where idclienti = '$idclienti' ");
+if ($numcivico) esegui_query("update $tableclienti set numcivico = '".aggslashdb(substr($numcivico,0,30))."' where idclienti = '$idclienti' ");
+if ($cap) esegui_query("update $tableclienti set cap = '".aggslashdb(substr($cap,0,30))."' where idclienti = '$idclienti' ");
+if ($telefono) esegui_query("update $tableclienti set telefono = '".aggslashdb(substr($telefono,0,50))."' where idclienti = '$idclienti' ");
+if ($telefono2) esegui_query("update $tableclienti set telefono2 = '".aggslashdb(substr($telefono2,0,50))."' where idclienti = '$idclienti' ");
+if ($telefono3) esegui_query("update $tableclienti set telefono3 = '".aggslashdb(substr($telefono3,0,50))."' where idclienti = '$idclienti' ");
+if ($fax) esegui_query("update $tableclienti set fax = '".aggslashdb(substr($fax,0,50))."' where idclienti = '$idclienti' ");
 $email = aggslashdb($email);
 if ($email) esegui_query("update $tableclienti set email = '$email' where idclienti = '$idclienti' ");
 $email2 = aggslashdb($email2);
