@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,7 @@
 
 
 
-function dati_costi_agg_ntariffe ($tablenometariffe,$num_tariffe,$solo_visibili="NO",$ordine_imposto="",$tableappartamenti="") {
+function dati_costi_agg_ntariffe ($tablenometariffe,$num_tariffe,$solo_visibili="NO",$ordine_imposto="",$tableappartamenti="",$dati_cat_pers=array()) {
 global $LIKE;
 
 if ($num_tariffe == "NO") $num_tariffe = 0;
@@ -33,7 +33,8 @@ $num_tariffe = esegui_query("select nomecostoagg from $tablenometariffe where id
 $num_tariffe = risul_query($num_tariffe,0,'nomecostoagg');
 } # fine if (!$num_tariffe)
 } # fine else if ($num_tariffe == "NO")
-if ($solo_visibili == "SI") $cond_visibili = " and mostra_ca $LIKE 's%'";
+if ($solo_visibili == "SI") $cond_visibili = " and (mostra_ca $LIKE 's%' or mostra_ca $LIKE 'p%')";
+else $cond_visibili = "";
 $ordine = "tipo_ca, idntariffe";
 if ($ordine_imposto) $ordine = $ordine_imposto;
 $costi = esegui_query("select * from $tablenometariffe where idntariffe > 10  and nomecostoagg != ''$cond_visibili order by $ordine");
@@ -78,13 +79,43 @@ $dati_ca[$num1]['raggruppa'] = substr($dati_ca[$num1]['mostra'],1,1);
 $dati_ca[$num1]['combina'] = substr($dati_ca[$num1]['mostra'],2,1);
 $dati_ca[$num1]['escludi_tot_perc'] = substr($dati_ca[$num1]['mostra'],3,1);
 $dati_ca[$num1]['mostra'] = substr($dati_ca[$num1]['mostra'],0,1);
+if ($dati_ca[$num1]['mostra'] == "p") {
+$dati_ca[$num1]['mostra'] = "s";
+$dati_ca[$num1]['mostra_numpers'] = "s";
+} # fine ($dati_ca[$num1]['mostra'] == "p")
+else $dati_ca[$num1]['mostra_numpers'] = "n";
 $dati_ca[$num1]['moltiplica'] = risul_query($costi,$num1,'moltiplica_ca');
+$dati_ca[$num1]['cp_molt_int'] = strstr($dati_ca[$num1]['moltiplica'],"<");
+if ($dati_ca[$num1]['cp_molt_int']) {
+$catpers_molt = explode("<",$dati_ca[$num1]['moltiplica']);
+$dati_ca[$num1]['moltiplica'] = $catpers_molt[0];
+$dati_ca[$num1]['modo_cp_molt'] = $catpers_molt[1];
+$dati_ca[$num1]['cp_molt']['num'] = (count($catpers_molt) - 2);
+for ($num2 = 0 ; $num2 < $dati_ca[$num1]['cp_molt']['num'] ; $num2++) {
+if ((string) $catpers_molt[($num2 + 2)] == "0") {
+$dati_ca[$num1]['cp_molt']['ord'][$num2] = "0";
+$dati_ca[$num1]['cp_molt'][0]['esist'] = ($num2 + 1);
+} # fine if ((string) $catpers_molt[($num2 + 2)] == "0")
+else {
+$catpers_corr = explode(">",$catpers_molt[($num2 + 2)]);
+$dati_ca[$num1]['cp_molt']['ord'][$num2] = $catpers_corr[0];
+$dati_ca[$num1]['cp_molt'][$num2]['lang'] = $catpers_corr[1];
+$dati_ca[$num1]['cp_molt'][$num2]['n_plur'] = $catpers_corr[2];
+if ($dati_cat_pers['num'] and $dati_cat_pers[$catpers_corr[0]]['langs'][$catpers_corr[1]]['n_p'] == $catpers_corr[2]) $dati_ca[$num1]['cp_molt'][$catpers_corr[0]]['esist'] = ($num2 + 1);
+} # fine else if ((string) $catpers_molt[($num2 + 2)] == "0")
+} # fine for $num2
+} # fine if ($dati_ca[$num1]['cp_molt_int'])
 $dati_ca[$num1]['molt_max'] = substr($dati_ca[$num1]['moltiplica'],1,1);
 $molt_agg = explode(",",substr($dati_ca[$num1]['moltiplica'],2));
 $dati_ca[$num1]['molt_agg'] = $molt_agg[0];
 $dati_ca[$num1]['molt_max_num'] = $molt_agg[1];
 $dati_ca[$num1]['moltiplica'] = substr($dati_ca[$num1]['moltiplica'],0,1);
 $dati_ca[$num1]['letto'] = risul_query($costi,$num1,'letto_ca');
+if ($dati_ca[$num1]['letto'] == "p") {
+$dati_ca[$num1]['letto'] = "s";
+$dati_ca[$num1]['perc_catpers'] = "s";
+} # fine ($dati_ca[$num1]['letto'] == "p")
+else $dati_ca[$num1]['perc_catpers'] = "n";
 $dati_ca[$num1]['var_periodip'] = risul_query($costi,$num1,'variazione_ca');
 $dati_ca[$num1]['var_percentuale'] = substr($dati_ca[$num1]['var_periodip'],0,1);
 $dati_ca[$num1]['var_numsett'] = substr($dati_ca[$num1]['var_periodip'],1,1);
@@ -110,15 +141,20 @@ $dati_ca[$num1]['molt_beneinv'][$num2] = $bene_inv[1];
 $dati_ca[$num1]['periodipermessi_orig'] = risul_query($costi,$num1,'periodipermessi_ca');
 $dati_ca[$num1]['periodipermessi'] = substr($dati_ca[$num1]['periodipermessi_orig'],0,1);
 if ($dati_ca[$num1]['periodipermessi']) {
-$sett_periodipermessi = explode(",",substr($dati_ca[$num1]['periodipermessi_orig'],1));
-$num_sett_periodipermessi = count($sett_periodipermessi);
 $dati_ca[$num1]['sett_periodipermessi_ini'] = array();
 $dati_ca[$num1]['sett_periodipermessi_fine'] = array();
+$sett_periodipermessi = substr($dati_ca[$num1]['periodipermessi_orig'],1);
+if ($sett_periodipermessi) {
+$sett_periodipermessi = explode(",",$sett_periodipermessi);
+$num_sett_periodipermessi = count($sett_periodipermessi);
 for ($num2 = 0 ; $num2 < $num_sett_periodipermessi ; $num2++) {
+if ($sett_periodipermessi[$num2]) {
 $sett_periodipermesso = explode("-",$sett_periodipermessi[$num2]);
 $dati_ca[$num1]['sett_periodipermessi_ini'][$num2] = $sett_periodipermesso[0];
 $dati_ca[$num1]['sett_periodipermessi_fine'][$num2] = $sett_periodipermesso[1];
+} # fine if ($sett_periodipermessi[$num2])
 } # fine for $num2
+} # fine if ($sett_periodipermessi)
 } # fine if ($dati_ca[$num1][periodipermessi])
 $dati_ca[$num1]['appincompatibili'] = risul_query($costi,$num1,'appincompatibili_ca');
 if ($dati_ca[$num1]['letto'] == "s" and $tableappartamenti) {
@@ -226,7 +262,7 @@ return $periodo_costo_trovato;
 
 
 
-function calcola_prezzo_totale_costo ($dati_ca,$num_costo,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica,$costo_tariffa,$lista_tariffe,$costo_prenota_tot,$caparra,$numpersone,$costo_escludi_perc=0,$prezzi_giorn=0) {
+function calcola_prezzo_totale_costo ($dati_ca,$num_costo,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica,$costo_tariffa,$lista_tariffe,$costo_prenota_tot,$caparra,$numpersone,$dati_cat_pers,$catpers_ca,$costo_escludi_perc=0,$prezzi_giorn=0) {
 
 $prezzo_costo_fisso = (double) $dati_ca[$num_costo]['valore'];
 if ($dati_ca[$num_costo]['tipo_val'] != "f") $prezzo_costo_perc = (double) $dati_ca[$num_costo]['valore_perc'];
@@ -271,6 +307,7 @@ $num_lista_tariffe = 0;
 $num_sett = 1;
 for ($num1 = $idinizioperiodo ; $num1 <= $idfineperiodo ; $num1++) {
 if (str_replace(",".$num1.",","",$settimane_costo) != $settimane_costo) {
+if (!$moltiplica[$num_sett]) $moltiplica[$num_sett] = 0;
 $prezzo_costo_fisso_tot = $prezzo_costo_fisso_tot + ($prezzo_costo_fisso * $moltiplica[$num_sett]);
 if ($dati_ca[$num_costo]['tipo_val'] == "p") $prezzo_costo_sett = ($lista_tariffe[$num_lista_tariffe] * $prezzo_costo_perc) / 100;
 if ($dati_ca[$num_costo]['tipo_val'] == "q") $prezzo_costo_sett = (($lista_tariffe[$num_lista_tariffe] - $lista_tariffep[$num_lista_tariffe]) * $prezzo_costo_perc) / 100;
@@ -326,6 +363,10 @@ $prezzo_costo_perc = $prezzo_costo_perc * $moltiplica;
 if ($dati_ca[$num_costo]['tipo_val'] != "f") $prezzo_costo_perc = floor($prezzo_costo_perc / $dati_ca[$num_costo]['arrotonda']) * $dati_ca[$num_costo]['arrotonda'];
 $prezzo_costo = $prezzo_costo_fisso + $prezzo_costo_perc;
 
+if ($dati_ca[$num_costo]['perc_catpers'] == "s" and strcmp($catpers_ca,"") and strcmp($dati_cat_pers[$catpers_ca]['perc'],"") and $dati_cat_pers[$catpers_ca]['perc'] != 100) {
+$prezzo_costo = round((((double) $prezzo_costo * (double)$dati_cat_pers[$catpers_ca]['perc']) / 100) / $dati_cat_pers['arrotond']) * $dati_cat_pers['arrotond'];
+} # fine if ($dati_ca[$num_costo]['perc_catpers'] == "s" and strcmp($catpers_ca,"") and...
+
 return $prezzo_costo;
 
 } # fine function calcola_prezzo_totale_costo
@@ -379,16 +420,46 @@ return $settimane_costo;
 
 
 
-function calcola_moltiplica_costo ($dati_ca,$num_costo,&$moltiplica,$idinizioperiodo,$idfineperiodo,$settimane_costo,$nummoltiplica_ca,$numpersone,$num_letti_agg) {
+function calcola_moltiplica_costo ($dati_ca,$num_costo,&$moltiplica,$idinizioperiodo,$idfineperiodo,$settimane_costo,$nummoltiplica_ca,$numpersone,$cat_persone,$num_letti_agg) {
 
 $moltiplica = "";
 if (!strcmp($numpersone,"")) $numpersone = 0;
+if ($dati_ca[$num_costo]['modo_cp_molt']) {
+if (empty($cat_persone)) {
+$cat_persone = array(0 => array());
+$cat_persone[0]['molt'] = $numpersone;
+$cat_persone[0]['ord'] = 0;
+$cat_persone['ord'][0] = 0;
+$cat_persone['num'] = 1;
+} # fine if (empty($cat_persone))
+if ($dati_ca[$num_costo]['modo_cp_molt'] == "i") $numpersone = 0;
+for ($num1 = 0 ; $num1 < $dati_ca[$num_costo]['cp_molt']['num'] ; $num1++) {
+$cp = $dati_ca[$num_costo]['cp_molt']['ord'][$num1];
+if ($dati_ca[$num_costo]['cp_molt'][$cp]['esist'] and $cat_persone[$cat_persone['ord'][$cp]]['molt']) {
+if ($dati_ca[$num_costo]['modo_cp_molt'] == "i") $numpersone += $cat_persone[$cat_persone['ord'][$cp]]['molt'];
+else $numpersone = $numpersone - $cat_persone[$cat_persone['ord'][$cp]]['molt'];
+} # fine if ($dati_ca[$num_costo]['cp_molt'][$cp]['esist'] and $cat_persone[$cat_persone['ord'][$cp]]['molt'])
+} # fine for $num1
+} # fine if ($dati_ca[$num_costo]['modo_cp_molt'])
 if (!$dati_ca[$num_costo]['molt_agg']) $dati_ca[$num_costo]['molt_agg'] = 0;
+
 if ($dati_ca[$num_costo]['moltiplica'] == "1") $moltiplica = 1;
 if ($dati_ca[$num_costo]['moltiplica'] == "c") $moltiplica = $nummoltiplica_ca;
 if ($dati_ca[$num_costo]['moltiplica'] == "p") $moltiplica = $numpersone;
 if ($dati_ca[$num_costo]['moltiplica'] == "t") {
 $letti_agg_max = 0;
+if ($dati_ca[$num_costo]['modo_cp_molt']) {
+for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
+if ($dati_ca[$num_costo]['modo_cp_molt'] == "i") $num_letti_agg[$num1] = 0;
+for ($num2 = 0 ; $num2 < $dati_ca[$num_costo]['cp_molt']['num'] ; $num2++) {
+$cp = $dati_ca[$num_costo]['cp_molt']['ord'][$num2];
+if ($dati_ca[$num_costo]['cp_molt'][$cp]['esist'] and $num_letti_agg['catp_tot'][$num1][$cp]) {
+if ($dati_ca[$num_costo]['modo_cp_molt'] == "i") $num_letti_agg[$num1] += $num_letti_agg['catp_tot'][$num1][$cp];
+else $num_letti_agg[$num1] = $num_letti_agg[$num1] - $num_letti_agg['catp_tot'][$num1][$cp];
+} # fine if ($dati_ca[$num_costo]['cp_molt'][$cp]['esist'] and $num_letti_agg['catp_tot'][$num1][$cp])
+} # fine for $num2
+} # fine for $num1
+} # fine if ($dati_ca[$num_costo]['modo_cp_molt'])
 if ($dati_ca[$num_costo]['tipo'] == "s" and $dati_ca[$num_costo]['associasett'] == "s") {
 for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
 if (!strcmp($num_letti_agg[$num1],"")) $num_letti_agg[$num1] = 0;
@@ -422,11 +493,11 @@ return $moltiplica_max;
 
 
 
-function aggiorna_letti_agg_in_periodi ($dati_ca,$num_costo,&$num_letti_agg,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica,$nummoltiplica_ca,$numpersone,$dati_cat_pers=array()) {
+function aggiorna_letti_agg_in_periodi ($dati_ca,$num_costo,&$num_letti_agg,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica,$nummoltiplica_ca,$numpersone,$dati_cat_pers=array(),$catpers_ca="") {
 
 if ($num_letti_agg['max'] == "") $num_letti_agg['max'] = 0;
 if ($dati_ca[$num_costo]['letto'] == "s") {
-if (!$moltiplica) calcola_moltiplica_costo($dati_ca,$num_costo,$moltiplica,$idinizioperiodo,$idfineperiodo,$settimane_costo,$nummoltiplica_ca,$numpersone,"");
+if (!$moltiplica) calcola_moltiplica_costo($dati_ca,$num_costo,$moltiplica,$idinizioperiodo,$idfineperiodo,$settimane_costo,$nummoltiplica_ca,$numpersone,"","");
 for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
 if (!$num_letti_agg[$num1]) $num_letti_agg[$num1] = 0;
 if ($dati_ca[$num_costo]['associasett'] == "s") {
@@ -440,11 +511,14 @@ else $moltiplica_corr = $moltiplica;
 $num_letti_agg[$num1] = $num_letti_agg[$num1] + $moltiplica_corr;
 
 if ($dati_cat_pers['num']) {
+if (strcmp($catpers_ca,"")) $dati_ca[$num_costo]['cat_pers']['esist'][0] = 1;
+else $catpers_ca = $dati_ca[$num_costo]['cat_pers']['ord'][0];
 $num_letti_agg['catp'][$num1] .= " + $moltiplica_corr ";
 if ($dati_ca[$num_costo]['cat_pers']['esist'][0]) {
-if ($moltiplica_corr > 1) $num_letti_agg['catp'][$num1] .= $dati_cat_pers[$dati_ca[$num_costo]['cat_pers']['ord'][0]]['n_plur'];
-else $num_letti_agg['catp'][$num1] .= $dati_cat_pers[$dati_ca[$num_costo]['cat_pers']['ord'][0]]['n_sing'];
-$num_letti_agg['catp_tot'][$num1][$dati_ca[$num_costo]['cat_pers']['ord'][0]] += $moltiplica_corr;
+if ($moltiplica_corr > 1) $num_letti_agg['catp'][$num1] .= $dati_cat_pers[$catpers_ca]['n_plur'];
+else $num_letti_agg['catp'][$num1] .= $dati_cat_pers[$catpers_ca]['n_sing'];
+$num_letti_agg['catp_tot'][$num1][$catpers_ca] += $moltiplica_corr;
+if (!$num_letti_agg['catp_tot_max'][$catpers_ca] or $num_letti_agg['catp_tot'][$num1][$catpers_ca] > $num_letti_agg['catp_tot_max'][$catpers_ca]) $num_letti_agg['catp_tot_max'][$catpers_ca] = $num_letti_agg['catp_tot'][$num1][$catpers_ca];
 } # fine if ($dati_ca[$num_costo]['cat_pers']['esist'][0])
 else {
 if (!$num_letti_agg['catp_solo_esist']) {
@@ -530,12 +604,37 @@ $dati_cap[$numca]['num_sett_seconde'] = $sett_prime_seconde[1];
 } # fine if ($dati_cap[$numca]['numsett'] == "n" or $dati_cap[$numca]['numsett'] == "s")
 if ($dati_cap[$numca]['numsett'] == "g") $dati_cap[$numca]['giornisett'] = substr($numsett,1);
 $dati_cap[$numca]['moltiplica'] = risul_query($costi,$numca,'varmoltiplica');
+$dati_cap[$numca]['cp_molt_int'] = strstr($dati_cap[$numca]['moltiplica'],"<");
+if ($dati_cap[$numca]['cp_molt_int']) {
+$catpers_molt = explode("<",$dati_cap[$numca]['moltiplica']);
+$dati_cap[$numca]['moltiplica'] = $catpers_molt[0];
+$dati_cap[$numca]['modo_cp_molt'] = $catpers_molt[1];
+$dati_cap[$numca]['cp_molt']['num'] = (count($catpers_molt) - 2);
+for ($num2 = 0 ; $num2 < $dati_cap[$numca]['cp_molt']['num'] ; $num2++) {
+if ((string) $catpers_molt[($num2 + 2)] == "0") {
+$dati_cap[$numca]['cp_molt']['ord'][$num2] = "0";
+$dati_cap[$numca]['cp_molt'][0]['esist'] = ($num2 + 1);
+} # fine if ((string) $catpers_molt[($num2 + 2)] == "0")
+else {
+$catpers_corr = explode(">",$catpers_molt[($num2 + 2)]);
+$dati_cap[$numca]['cp_molt']['ord'][$num2] = $catpers_corr[0];
+$dati_cap[$numca]['cp_molt'][$num2]['lang'] = $catpers_corr[1];
+$dati_cap[$numca]['cp_molt'][$num2]['n_plur'] = $catpers_corr[2];
+if ($dati_cat_pers['num'] and $dati_cat_pers[$catpers_corr[0]]['langs'][$catpers_corr[1]]['n_p'] == $catpers_corr[2]) $dati_cap[$numca]['cp_molt'][$catpers_corr[0]]['esist'] = ($num2 + 1);
+} # fine else if ((string) $catpers_molt[($num2 + 2)] == "0")
+} # fine for $num2
+} # fine if ($dati_cap[$numca]['cp_molt_int'])
 $dati_cap[$numca]['molt_max'] = substr($dati_cap[$numca]['moltiplica'],1,1);
 $molt_agg = explode(",",substr($dati_cap[$numca]['moltiplica'],2));
 $dati_cap[$numca]['molt_agg'] = $molt_agg[0];
 $dati_cap[$numca]['molt_max_num'] = $molt_agg[1];
 $dati_cap[$numca]['moltiplica'] = substr($dati_cap[$numca]['moltiplica'],0,1);
 $dati_cap[$numca]['letto'] = risul_query($costi,$numca,'letto');
+if ($dati_cap[$numca]['letto'] == "p") {
+$dati_cap[$numca]['letto'] = "s";
+$dati_cap[$numca]['perc_catpers'] = "s";
+} # fine ($dati_cap[$numca]['letto'] == "p")
+else $dati_cap[$numca]['perc_catpers'] = "n";
 if ($dati_cap[$numca]['letto'] == "s" and $dati_cat_pers['num']) {
 $cat_pers = risul_query($costi,$numca,'cat_persone');
 $dati_cap[$numca]['cat_pers'] = dati_cat_pers_p($cat_pers,-1,$dati_cat_pers,1);
@@ -556,12 +655,19 @@ $dati_cap[$numca]['molt_beneinv'][$num1] = $bene_inv[1];
 $dati_cap[$numca]['periodipermessi_orig'] = risul_query($costi,$numca,'varperiodipermessi');
 $dati_cap[$numca]['periodipermessi'] = substr($dati_cap[$numca]['periodipermessi_orig'],0,1);
 if ($dati_cap[$numca]['periodipermessi']) {
-$sett_periodipermessi = explode(",",substr($dati_cap[$numca]['periodipermessi_orig'],1));
+$dati_cap[$numca]['sett_periodipermessi_ini'] = array();
+$dati_cap[$numca]['sett_periodipermessi_fine'] = array();
+$sett_periodipermessi = substr($dati_cap[$numca]['periodipermessi_orig'],1);
+if ($sett_periodipermessi) {
+$sett_periodipermessi = explode(",",$sett_periodipermessi);
 for ($num1 = 0 ; $num1 < count($sett_periodipermessi) ; $num1++) {
+if ($sett_periodipermessi[$num1]) {
 $sett_periodipermesso = explode("-",$sett_periodipermessi[$num1]);
 $dati_cap[$numca]['sett_periodipermessi_ini'][$num1] = $sett_periodipermesso[0];
 $dati_cap[$numca]['sett_periodipermessi_fine'][$num1] = $sett_periodipermesso[1];
+} # fine if ($sett_periodipermessi[$num1])
 } # fine for $num1
+} # fine if ($sett_periodipermessi)
 } # fine if ($dati_cap[$numca]['periodipermessi'])
 $dati_cap[$numca]['settimane'] = risul_query($costi,$numca,'settimane');
 $dati_cap[$numca]['moltiplica_costo'] = risul_query($costi,$numca,'moltiplica');
