@@ -246,7 +246,7 @@ $id_app_richiesti++;
 $app_richiesti[$id_app_richiesti] = $lista_app_richiesti;
 $idinizioperiodo_vett[$id_app_richiesti] = $idinizioperiodo;
 $idfineperiodo_vett[$id_app_richiesti] = $idfineperiodo;
-$app_richiesti[",numero,"] = $id_app_richiesti;
+$app_richiesti[',numero,'] = $id_app_richiesti;
 if ($num_tipologie > 1) {
 if (@is_array($prenota_vicine)) {
 $app_richiesti[',vicini,'] = "SI";
@@ -352,6 +352,7 @@ $appartamento = $app_liberato;
 # se ci sono app_agenzia e non si può non occuparli
 else {
 $occupare_app_agenzia = "SI";
+global $sec_limite_libsett;
 $limiti_var['t_limite'] = (time() + $sec_limite_libsett);
 $app_liberato = "";
 $app_orig_prenota_id = $app_prenota_id;
@@ -452,7 +453,7 @@ unset($app_assegnabili_id_);
 unset($prenota_in_app_sett_);
 unset($dati_app_);
 unset($app_liberato);
-$limiti_var["lim_prenota_temp"] = $lim_prenota_temp;
+$limiti_var['lim_prenota_temp'] = $lim_prenota_temp;
 
 liberasettimane($idinizioperiodo_vett,$idfineperiodo_vett,$limiti_var,$anno,$fatto_libera,$app_liberato,$profondita_,$app_richiesti,$app_prenota_id_,$app_orig_prenota_id_,$inizio_prenota_id_,$fine_prenota_id_,$app_assegnabili_id_,$prenota_in_app_sett_,$dati_app_,$PHPR_TAB_PRE."prenota");
 
@@ -606,7 +607,7 @@ $nummoltiplica_ca = $costo_letto_imposto[$n_t]['molt'];
 if ($associa_costo == "SI") {
 #if ($dati_ca[$num_costo][tipo_val] == "q" and $costo_totale_presente = "SI") $associa_costo = "NO";
 $settimane_costo = calcola_settimane_costo($tableperiodi,$dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],"","");
-calcola_moltiplica_costo($dati_ca,$num_costo,$moltiplica,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$nummoltiplica_ca,$numpersone[$n_t],$num_letti_agg);
+calcola_moltiplica_costo($dati_ca,$num_costo,$moltiplica,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$nummoltiplica_ca,$numpersone[$n_t],"",$num_letti_agg);
 $num_costi_presenti_copia = $num_costi_presenti;
 $periodo_costo_trovato = trova_periodo_permesso_costo($dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo);
 if ($periodo_costo_trovato == "NO") $associa_costo = "NO";
@@ -619,7 +620,7 @@ $idcostiprenota = risul_query($idcostiprenota,0,0) + 1;
 $tipo_ca = $dati_ca[$num_costo]['tipo'].$dati_ca[$num_costo]['tipo_val'];
 $valore_ca = $dati_ca[$num_costo]['valore'];
 $valore_perc_ca = $dati_ca[$num_costo]['valore_perc'];
-$prezzo_costo_tot = calcola_prezzo_totale_costo($dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$moltiplica,$costo_tariffa,$lista_tariffe_sett,$costo_tariffa_tot,$caparra,$numpersone[$n_t]);
+$prezzo_costo_tot = calcola_prezzo_totale_costo($dati_ca,$num_costo,$inizioperiodo[$n_t],$fineperiodo[$n_t],$settimane_costo,$moltiplica,$costo_tariffa,$lista_tariffe_sett,$costo_tariffa_tot,$caparra,$numpersone[$n_t],"","");
 $associasett_ca = $dati_ca[$num_costo]['associasett'];
 if ($dati_ca[$num_costo]['var_percentuale'] != "s" and $dati_ca[$num_costo]['tipo_val'] != "f") {
 $tipo_ca = $dati_ca[$num_costo]['tipo']."f";
