@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -54,6 +54,7 @@ $dati_tariffe['tariffa'.$num1]['periodo_importa_f'][$num2] = $per_imp[1];
 if (!strstr(",".$dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'],",$num1,")) $dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'] .= "$num1,";
 } # fine for $num2
 } # fine if ($dati_tariffe['tariffa'.$num1]['imp_prezzi_int'])
+else $dati_tariffe['tariffa'.$num1]['importa_prezzi'] = array();
 } # fine if (!$tariffa_sel or $tariffa_sel == $num1)
 } # fine for $num1
 
@@ -109,7 +110,7 @@ return $dati_tariffe;
 function dati_regole2 (&$dati_r2,&$app_regola2_predef,$tipotariffa,$idinizioperiodo,$idfineperiodo,&$id_periodo_corrente,$tipo_periodi,$anno,$tableregole) {
 
 if (!is_array($dati_r2)) {
-$dati_r2 = array();
+$dati_r2 = array('napp' => array());
 $regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
 $dati_r2['num'] = numlin_query($regole2);
 
@@ -275,7 +276,7 @@ return $caparra;
 
 
 function aggiorna_tariffe_esporta ($dati_tariffe,$tariffa_da,$idperiodo,$prezzoperiodo,$prezzoperiodop,$tableperiodi,&$agg_vett,&$num_agg) {
-if ($dati_tariffe[$tariffa_da]['esporta_prezzi']) {
+if (isset($dati_tariffe[$tariffa_da]['esporta_prezzi'])) {
 
 if (str_replace("-","",$idperiodo) != $idperiodo) {
 $fine_per = explode("-",$idperiodo);
@@ -378,8 +379,8 @@ $num_ord_prec = $num_ord;
 } # fine for $num1
 } # fine else if ($idperiodo == "opztariffa")
 } # fine for $num_tar
-} # fine if ($dati_tariffe[$tipotariffa]['esporta_prezzi'])
 
+} # fine if (isset($dati_tariffe[$tipotariffa]['esporta_prezzi']))
 } # fine function aggiorna_tariffe_esporta
 
 
