@@ -56,8 +56,8 @@ if ($lunghezza == "NO") $testo = substr($testo,$n_ini);
 else {
 $n_lun = 0;
 if ($lunghezza < 0) {
-while ($lunghezza < 0) $lunghezza = $num_caratteri + $lunghezza;
-$lunghezza = $lunghezza - $inizio;
+$lunghezza = $num_caratteri + $lunghezza - $inizio;
+if ($lunghezza < 0) $lunghezza = 0;
 } # fine if ($lunghezza < 0)
 for ($num1 = ($inizio + 1) ; $num1 <= ($inizio + $lunghezza) ; $num1++) $n_lun = $n_lun + $num_byte_car[$num1];
 $testo = substr($testo,$n_ini,$n_lun);
@@ -69,11 +69,12 @@ return $testo;
 
 
 
-function trova_prima_data ($testo,$stile_data,$lingua) {
+function trova_prima_data ($testo,$stile_data,$lingua,&$lung_resto) {
 global $lingua_mex;
 
 $prima_data = "";
 $lung_prima_data = strlen($testo);
+$lung_resto = "";
 
 if (preg_match("|[^0-9][0-9]{1,2}[-/ ][0-9]{1,2}[-/ ][0-9]{4,4}[^0-9]|",$testo)) {
 $prima_data_vett = preg_split("|[0-9]{1,2}[-/ ][0-9]{1,2}[-/ ][0-9]{4,4}|",$testo);
@@ -85,6 +86,7 @@ if ($prima_data_vett[1]) {
 $prima_data = explode($prima_data_vett[1],$prima_data);
 $prima_data = $prima_data[0];
 } # fine if ($prima_data_vett[1])
+$lung_resto = (int) $lung_prima_data + strlen($prima_data);
 $prima_data_corr = preg_split("|[-/ ]|",$prima_data);
 if (strlen($prima_data_corr[0]) < 2) $prima_data_corr[0] = "0".$prima_data_corr[0];
 if (strlen($prima_data_corr[1]) < 2) $prima_data_corr[1] = "0".$prima_data_corr[1];
@@ -109,6 +111,7 @@ if ($prima_data_vett[1]) {
 $prima_data = explode($prima_data_vett[1],$prima_data);
 $prima_data = $prima_data[0];
 } # fine if ($prima_data_vett[1])
+$lung_resto = (int) $lung_prima_data + strlen($prima_data);
 $prima_data_corr = preg_split("|[-/ ]|",$prima_data);
 if (strlen($prima_data_corr[1]) < 2) $prima_data_corr[1] = "0".$prima_data_corr[1];
 if (strlen($prima_data_corr[2]) < 2) $prima_data_corr[2] = "0".$prima_data_corr[2];
@@ -118,30 +121,31 @@ $prima_data = $prima_data_corr[0]."-".$prima_data_corr[1]."-".$prima_data_corr[2
 
 $lingua_orig = $lingua_mex;
 $lingua_mex = $lingua;
-$Gen = mex("Gen",'giorni_mesi.php');
-$Feb = mex("Feb",'giorni_mesi.php');
-$Mar = mex("Mar",'giorni_mesi.php');
-$Apr = mex("Apr",'giorni_mesi.php');
-$Mag = mex("Mag",'giorni_mesi.php');
-$Giu = mex("Giu",'giorni_mesi.php');
-$Lug = mex("Lug",'giorni_mesi.php');
-$Ago = mex("Ago",'giorni_mesi.php');
-$Set = mex("Set",'giorni_mesi.php');
-$Ott = mex("Ott",'giorni_mesi.php');
-$Nov = mex("Nov",'giorni_mesi.php');
-$Dic = mex("Dic",'giorni_mesi.php');
-$Gennaio = mex("Gennaio",'giorni_mesi.php');
-$Febbraio = mex("Febbraio",'giorni_mesi.php');
-$Marzo = mex("Marzo",'giorni_mesi.php');
-$Aprile = mex("Aprile",'giorni_mesi.php');
-$Maggio = mex("Maggio",'giorni_mesi.php');
-$Giugno = mex("Giugno",'giorni_mesi.php');
-$Luglio = mex("Luglio",'giorni_mesi.php');
-$Agosto = mex("Agosto",'giorni_mesi.php');
-$Settembre = mex("Settembre",'giorni_mesi.php');
-$Ottobre = mex("Ottobre",'giorni_mesi.php');
-$Novembre = mex("Novembre",'giorni_mesi.php');
-$Dicembre = mex("Dicembre",'giorni_mesi.php');
+$Gen = strtolower(mex("Gen",'giorni_mesi.php'));
+$Feb = strtolower(mex("Feb",'giorni_mesi.php'));
+$Mar = strtolower(mex("Mar",'giorni_mesi.php'));
+$Apr = strtolower(mex("Apr",'giorni_mesi.php'));
+$Mag = strtolower(mex("Mag",'giorni_mesi.php'));
+$Giu = strtolower(mex("Giu",'giorni_mesi.php'));
+$Lug = strtolower(mex("Lug",'giorni_mesi.php'));
+$Ago = strtolower(mex("Ago",'giorni_mesi.php'));
+$Set = strtolower(mex("Set",'giorni_mesi.php'));
+$Ott = strtolower(mex("Ott",'giorni_mesi.php'));
+$Nov = strtolower(mex("Nov",'giorni_mesi.php'));
+$Dic = strtolower(mex("Dic",'giorni_mesi.php'));
+$Gennaio = strtolower(mex("Gennaio",'giorni_mesi.php'));
+$Febbraio = strtolower(mex("Febbraio",'giorni_mesi.php'));
+$Marzo = strtolower(mex("Marzo",'giorni_mesi.php'));
+$Aprile = strtolower(mex("Aprile",'giorni_mesi.php'));
+$Maggio = strtolower(mex("Maggio",'giorni_mesi.php'));
+$Giugno = strtolower(mex("Giugno",'giorni_mesi.php'));
+$Luglio = strtolower(mex("Luglio",'giorni_mesi.php'));
+$Agosto = strtolower(mex("Agosto",'giorni_mesi.php'));
+$Settembre = strtolower(mex("Settembre",'giorni_mesi.php'));
+$Ottobre = strtolower(mex("Ottobre",'giorni_mesi.php'));
+$Novembre = strtolower(mex("Novembre",'giorni_mesi.php'));
+$Dicembre = strtolower(mex("Dicembre",'giorni_mesi.php'));
+$al = strtolower(mex("al",'prenota.php'));
 $lingua_mex = $lingua_orig;
 $mesi_alternativi = "$Gen|$Feb|$Mar|$Apr|$Mag|$Giu|$Lug|$Ago|$Set|$Ott|$Nov|$Dic|$Gennaio|$Febbraio|$Marzo|$Aprile|$Maggio|$Giugno|$Luglio|$Agosto|$Settembre|$Ottobre|$Novembre|$Dicembre";
 
@@ -155,27 +159,29 @@ if ($prima_data_vett[1]) {
 $prima_data = explode($prima_data_vett[1],$prima_data);
 $prima_data = $prima_data[0];
 } # fine if ($prima_data_vett[1])
+$lung_resto = (int) $lung_prima_data + strlen($prima_data);
 $prima_data_corr = preg_split("|[, -/]+|",$prima_data);
-if ($prima_data_corr[0] == $Gen or $prima_data_corr[0] == $Gennaio) $mese = "01";
-if ($prima_data_corr[0] == $Feb or $prima_data_corr[0] == $Febbraio) $mese = "02";
-if ($prima_data_corr[0] == $Mar or $prima_data_corr[0] == $Marzo) $mese = "03";
-if ($prima_data_corr[0] == $Apr or $prima_data_corr[0] == $Aprile) $mese = "04";
-if ($prima_data_corr[0] == $Mag or $prima_data_corr[0] == $Maggio) $mese = "05";
-if ($prima_data_corr[0] == $Giu or $prima_data_corr[0] == $Giugno) $mese = "06";
-if ($prima_data_corr[0] == $Lug or $prima_data_corr[0] == $Luglio) $mese = "07";
-if ($prima_data_corr[0] == $Ago or $prima_data_corr[0] == $Agosto) $mese = "08";
-if ($prima_data_corr[0] == $Set or $prima_data_corr[0] == $Settembre) $mese = "09";
-if ($prima_data_corr[0] == $Ott or $prima_data_corr[0] == $Ottobre) $mese = "10";
-if ($prima_data_corr[0] == $Nov or $prima_data_corr[0] == $Novembre) $mese = "11";
-if ($prima_data_corr[0] == $Dic or $prima_data_corr[0] == $Dicembre) $mese = "12";
+$mese_corr = strtolower($prima_data_corr[0]);
+if ($mese_corr == $Gen or $mese_corr == $Gennaio) $mese = "01";
+if ($mese_corr == $Feb or $mese_corr == $Febbraio) $mese = "02";
+if ($mese_corr == $Mar or $mese_corr == $Marzo) $mese = "03";
+if ($mese_corr == $Apr or $mese_corr == $Aprile) $mese = "04";
+if ($mese_corr == $Mag or $mese_corr == $Maggio) $mese = "05";
+if ($mese_corr == $Giu or $mese_corr == $Giugno) $mese = "06";
+if ($mese_corr == $Lug or $mese_corr == $Luglio) $mese = "07";
+if ($mese_corr == $Ago or $mese_corr == $Agosto) $mese = "08";
+if ($mese_corr == $Set or $mese_corr == $Settembre) $mese = "09";
+if ($mese_corr == $Ott or $mese_corr == $Ottobre) $mese = "10";
+if ($mese_corr == $Nov or $mese_corr == $Novembre) $mese = "11";
+if ($mese_corr == $Dic or $mese_corr == $Dicembre) $mese = "12";
 if (strlen($prima_data_corr[1]) < 2) $prima_data_corr[1] = "0".$prima_data_corr[1];
 $prima_data = $prima_data_corr[2]."-".$mese."-".$prima_data_corr[1];
 } # fine if ($lung_prima_data_corr < $lung_prima_data)
 } # fine if (preg_match("=[^0-9a-z]($mesi_alternativi)[, -/]+[0-9]{1,2}[, -/]+[0-9]{4,4}[^0-9a-z]=i",$testo))
 
 if (preg_match("=[^0-9a-z][0-9]{1,2}[, -/]+($mesi_alternativi)[, -/]+[0-9]{4,4}[^0-9a-z]=i",$testo)) {
-$prima_data_vett = preg_split("=[0-9]{1,2}[, -/]+($mesi_alternativi)[, -/]+[0-9]{4,4}=i",$testo);
-$lung_prima_data_corr = strlen($prima_data_vett[0]);
+$prima_data_vett = preg_split("=[^0-9a-z]{1,1}[0-9]{1,2}[, -/]+($mesi_alternativi)[, -/]+[0-9]{4,4}=i",$testo);
+$lung_prima_data_corr = (strlen($prima_data_vett[0]) + 1);
 if ($lung_prima_data_corr < $lung_prima_data) {
 $lung_prima_data = $lung_prima_data_corr;
 $prima_data = substr($testo,$lung_prima_data);
@@ -183,19 +189,45 @@ if ($prima_data_vett[1]) {
 $prima_data = explode($prima_data_vett[1],$prima_data);
 $prima_data = $prima_data[0];
 } # fine if ($prima_data_vett[1])
+$lung_resto = (int) $lung_prima_data + strlen($prima_data);
 $prima_data_corr = preg_split("|[, -/]+|",$prima_data);
-if ($prima_data_corr[1] == $Gen or $prima_data_corr[1] == $Gennaio) $mese = "01";
-if ($prima_data_corr[1] == $Feb or $prima_data_corr[1] == $Febbraio) $mese = "02";
-if ($prima_data_corr[1] == $Mar or $prima_data_corr[1] == $Marzo) $mese = "03";
-if ($prima_data_corr[1] == $Apr or $prima_data_corr[1] == $Aprile) $mese = "04";
-if ($prima_data_corr[1] == $Mag or $prima_data_corr[1] == $Maggio) $mese = "05";
-if ($prima_data_corr[1] == $Giu or $prima_data_corr[1] == $Giugno) $mese = "06";
-if ($prima_data_corr[1] == $Lug or $prima_data_corr[1] == $Luglio) $mese = "07";
-if ($prima_data_corr[1] == $Ago or $prima_data_corr[1] == $Agosto) $mese = "08";
-if ($prima_data_corr[1] == $Set or $prima_data_corr[1] == $Settembre) $mese = "09";
-if ($prima_data_corr[1] == $Ott or $prima_data_corr[1] == $Ottobre) $mese = "10";
-if ($prima_data_corr[1] == $Nov or $prima_data_corr[1] == $Novembre) $mese = "11";
-if ($prima_data_corr[1] == $Dic or $prima_data_corr[1] == $Dicembre) $mese = "12";
+# Se le date sono nel formato 19-26 Agosto 2017 o simili
+$prima_parte = str_replace("\n","",str_replace("\r","",$prima_data_vett[0]));
+$prima_parte_no_data = preg_replace("= [0-9]{1,2} *(-|$al|/) *$=i"," ",$prima_parte);
+if ($prima_parte != $prima_parte_no_data) {
+$lung_prima_data = strlen($prima_parte_no_data);
+$nuova_data = substr($prima_parte,$lung_prima_data);
+if (preg_match("/[0-9]{2,2}/",substr($nuova_data,0,2))) $prima_data_corr[0] = substr($nuova_data,0,2);
+else $prima_data_corr[0] = substr($nuova_data,0,1);
+$lung_resto = strlen($prima_data_vett[0]);
+} # fine if ($prima_parte != $prima_parte_no_data)
+else {
+# Se le date sono nel formato 26 Agosto - 2 Settempre 2017 o simili
+$prima_parte_no_data = preg_replace("= [0-9]{1,2} *($mesi_alternativi) *(-|$al|/) *$=i"," ",$prima_parte);
+if ($prima_parte != $prima_parte_no_data) {
+$lung_prima_data = strlen($prima_parte_no_data);
+$nuova_data = substr($prima_parte,$lung_prima_data);
+if (preg_match("/[0-9]{2,2}/",substr($nuova_data,0,2))) $prima_data_corr[0] = substr($nuova_data,0,2);
+else $prima_data_corr[0] = substr($nuova_data,0,1);
+$nuova_data = preg_replace("=^[0-9]{1,2} *=i","",$nuova_data);
+$prima_parte_no_data = preg_replace("=($mesi_alternativi)=i","",$nuova_data);
+$prima_data_corr[1] = substr($nuova_data,0,(strlen($prima_parte_no_data) * -1));
+$lung_resto = strlen($prima_data_vett[0]);
+} # fine if ($prima_parte != $prima_parte_no_data)
+} # fine else if ($prima_parte != $prima_parte_no_data)
+$mese_corr = strtolower($prima_data_corr[1]);
+if ($mese_corr == $Gen or $mese_corr == $Gennaio) $mese = "01";
+if ($mese_corr == $Feb or $mese_corr == $Febbraio) $mese = "02";
+if ($mese_corr == $Mar or $mese_corr == $Marzo) $mese = "03";
+if ($mese_corr == $Apr or $mese_corr == $Aprile) $mese = "04";
+if ($mese_corr == $Mag or $mese_corr == $Maggio) $mese = "05";
+if ($mese_corr == $Giu or $mese_corr == $Giugno) $mese = "06";
+if ($mese_corr == $Lug or $mese_corr == $Luglio) $mese = "07";
+if ($mese_corr == $Ago or $mese_corr == $Agosto) $mese = "08";
+if ($mese_corr == $Set or $mese_corr == $Settembre) $mese = "09";
+if ($mese_corr == $Ott or $mese_corr == $Ottobre) $mese = "10";
+if ($mese_corr == $Nov or $mese_corr == $Novembre) $mese = "11";
+if ($mese_corr == $Dic or $mese_corr == $Dicembre) $mese = "12";
 if (strlen($prima_data_corr[0]) < 2) $prima_data_corr[0] = "0".$prima_data_corr[0];
 $prima_data = $prima_data_corr[2]."-".$mese."-".$prima_data_corr[0];
 } # fine if ($lung_prima_data_corr < $lung_prima_data)
