@@ -51,7 +51,11 @@ if (defined('C_URL_FAVICON') and C_URL_FAVICON != "" and @is_file(C_URL_FAVICON)
 ";
 elseif (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI") echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
 ";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\">
+echo "<style type=\"text/css\">
+:root { --t1color: $t1color; }
+.t1color { background-color: $t1color; }
+</style>
+<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\">
 ";
 if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
 </script>
