@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Clienti":  				$messaggio = "Clients"; break;
 case "Le date sono sbagliate":  		$messaggio = "The dates are wrong"; break;
 case "Si deve inserire il tipo di tariffa":  	$messaggio = "You must insert the rate type"; break;
 case "tariffa":  				$messaggio = "rate"; break;
@@ -130,6 +131,12 @@ case "Commento":  				$messaggio = "Comment"; break;
 case "Si deve inserire almeno una persona che possa essere ospite principale":	$messaggio = "You must insert at least one person that can be main guest"; break;
 case "non si sono potuti usare":  		$messaggio = "It was not possible to use"; break;
 case "letti aggiuntivi perchè non c'era nessuna tipologia di persone con quel numero":	$messaggio = "extra beds as there was no people type with that number"; break;
+case "E-mail":  				$messaggio = "E-mail"; break;
+case "Seconda e-mail":  			$messaggio = "Second e-mail"; break;
+case "E-mail certificata (PEC) o codice destinatario":	$messaggio = "Certified e-mail"; break;
+case "email":  					$messaggio = "email"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC/codice":  				$messaggio = "certified email"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
