@@ -6,6 +6,7 @@ switch ($messaggio) {
 # translate YES and NO in upper case
 case "SI":  					$messaggio = "YES"; break;
 case "NO":  					$messaggio = "NO"; break;
+case "Crea Pagine Web":  			$messaggio = "Create Web Pages"; break;
 case "Torna indietro":  			$messaggio = "Go back"; break;
 case "Crea pagine per il sito web":  		$messaggio = "Create website pages"; break;
 case "Dati comuni":  				$messaggio = "Common data"; break;
@@ -100,6 +101,8 @@ case "di":  					$messaggio = "of"; break;
 case "Nuovo controllo":  			$messaggio = "New check"; break;
 case "Nome":  					$messaggio = "Name"; break;
 case "Email":  					$messaggio = "Email"; break;
+case "Email alternativa":  			$messaggio = "Alternative email"; break;
+case "Email certificata (PEC) o codice destinatario":	$messaggio = "Certified email"; break;
 case "Commento":  				$messaggio = "Comment"; break;
 case "Invia la richiesta di prenotazione":  	$messaggio = "Send the request for reservation"; break;
 case "Richiesta di prenotazione inviata": 	$messaggio = "Request for reservation sent"; break;
@@ -273,7 +276,7 @@ case "Data di partenza":  			$messaggio = "Departure date"; break;
 case "Tipologia":  				$messaggio = "Type"; break;
 case "default - frame orizzontale":  		$messaggio = "default - horizontal frame"; break;
 case "Condizioni da accettare nella form":  	$messaggio = "Agreements to be accepted in the form"; break;
-case "nomi dall'utente delle liste":		$messaggio = "names from lists user"; break;
+case "nomi dall'utente delle personalizzazioni":	$messaggio = "names from customizations user"; break;
 case "Accetto":  				$messaggio = "I accept"; break;
 case "documento":  				$messaggio = "document"; break;
 case "larghezza":  				$messaggio = "width"; break;
@@ -321,6 +324,12 @@ case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
 case "titolo html":  				$messaggio = "html title"; break;
 case "titolo":  				$messaggio = "title"; break;
 case "Si deve inserire almeno una persona che possa essere legalmente responsabile":	$messaggio = "You must include at least one person who can be legally responsible"; break;
+case "Solo quando non c'è disponibilità":  	$messaggio = "Only when there is no availability"; break;
+case "Sempre":  				$messaggio = "Always"; break;
+case "Raggruppamento":  			$messaggio = "Grouping"; break;
+case "Valuta della caparra":  			$messaggio = "Deposit currency"; break;
+case "Seconda email":  				$messaggio = "Second email"; break;
+case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -428,12 +437,16 @@ case "var_fr_di":  				$messaggio = "var_phr_of"; break;
 case "var_fr_Nuovo_controllo":  		$messaggio = "var_phr_New_check"; break;
 case "var_fr_Nome":  				$messaggio = "var_phr_Name"; break;
 case "var_fr_Email":  				$messaggio = "var_phr_Email"; break;
+case "var_fr_Email_alternativa":  		$messaggio = "var_phr_Alternative_email"; break;
+case "var_fr_Email_certificata_o_codice_destinatario":	$messaggio = "var_phr_Certified_email"; break;
 case "var_fr_Commento":  			$messaggio = "var_phr_Comment"; break;
 case "var_fr_Invia_la_richiesta_di_prenotazione":	$messaggio = "var_phr_Send_the_request_for_reservation"; break;
 case "var_fr_Richiesta_di_prenotazione_inviata":	$messaggio = "var_phr_Request_for_reservation_sent"; break;
 case "var_fr_Non_e_stato_possibile_inviare_la_richiesta":	$messaggio = "var_phr_It_was_not_possible_to_send_the_request"; break;
 case "var_fr_da":  				$messaggio = "var_phr_from2"; break;
 case "var_fre_Email":  				$messaggio = "var_phre_Email"; break;
+case "var_fre_Email_alternativa":  		$messaggio = "var_phre_Alternative_email"; break;
+case "var_fre_Email_certificata_o_codice_destinatario":	$messaggio = "var_phre_Certified_email"; break;
 case "var_fre_Nome":  				$messaggio = "var_phre_Name"; break;
 case "var_fre_Commento":  			$messaggio = "var_phre_Comment"; break;
 case "var_fre_Periodo":  			$messaggio = "var_phre_Period"; break;
@@ -446,6 +459,7 @@ case "var_fre_Prezzo_totale":  			$messaggio = "var_phre_Total_price"; break;
 case "var_fre_Riferimento":  			$messaggio = "var_phre_Reference"; break;
 case "var_fre_Caparra":  			$messaggio = "var_phre_Deposit"; break;
 case "var_fre_Richesta_prenotazione":  		$messaggio = "var_phre_Reservation_request"; break;
+case "var_fre_Valuta_della_caparra":  		$messaggio = "var_phre_Deposit_currency"; break;
 case "var_fr_Richesta_prenotazione":  		$messaggio = "var_phr_Reservation_request"; break;
 case "var_periodi_menu":  			$messaggio = "var_menu_periods"; break;
 case "var_fr_appartamenti":  			$messaggio = "var_phr_apartments"; break;
@@ -509,6 +523,8 @@ case "var_utente_messaggio":  			$messaggio = "var_message_user"; break;
 case "var_chiedi_cognome":  			$messaggio = "var_ask_surname"; break;
 case "var_chiedi_nome":  			$messaggio = "var_ask_name"; break;
 case "var_chiedi_email":  			$messaggio = "var_ask_email"; break;
+case "var_chiedi_email2":  			$messaggio = "var_ask_email2"; break;
+case "var_chiedi_email_cert":  			$messaggio = "var_ask_cert_email"; break;
 case "var_chiedi_sesso":  			$messaggio = "var_ask_sex"; break;
 case "var_chiedi_datanascita":  		$messaggio = "var_ask_birthdate"; break;
 case "var_chiedi_documento":  			$messaggio = "var_ask_document"; break;
@@ -526,6 +542,7 @@ case "var_chiedi_codfiscale":  			$messaggio = "var_ask_fiscalcode"; break;
 case "var_chiedi_partitaiva":  			$messaggio = "var_ask_vatnumber"; break;
 case "var_chiedi_commento":  			$messaggio = "var_ask_comment"; break;
 case "var_chiedi_oracheckin":  			$messaggio = "var_ask_checkintime"; break;
+case "var_chiedi_valutapagamento":  		$messaggio = "var_ask_paymentcurrency"; break;
 case "var_chiedi_metodopagamento":  		$messaggio = "var_ask_paymentmethod"; break;
 case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_payment_methods_to_ask"; break;
 case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_imposed_payment_methods_names"; break;
@@ -551,6 +568,7 @@ case "var_fr_Fax":  				$messaggio = "var_phr_Fax"; break;
 case "var_fr_Codice_fiscale":  			$messaggio = "var_phr_Fiscal_code"; break;
 case "var_fr_Partita_iva":  			$messaggio = "var_phr_VAT_number"; break;
 case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_phr_Estimated_arrival_time"; break;
+case "var_fr_Valuta_della_caparra":		$messaggio = "var_phr_Deposit_currency"; break;
 case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phr_Deposit_payment_method"; break;
 case "var_fre_Cognome":  			$messaggio = "var_phre_Surname"; break;
 case "var_fre_Genere":  			$messaggio = "var_phre_Gender"; break;
