@@ -314,6 +314,12 @@ case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè import
 case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limit not considered for additional people in interconnections"; break;
 case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Select now this cost also for all the users that don't have privileges to use all the costs"; break;
 case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Add now this cost to all existing website pages"; break;
+case "Se si moltiplica per il numero di persone":	$messaggio = "When multiplying by the number of people"; break;
+case "escludi":  				$messaggio = "exclude"; break;
+case "includi solo":  				$messaggio = "include only"; break;
+case "questi tipi":  				$messaggio = "these types"; break;
+case "Mostrare come tipo di persona":  		$messaggio = "Display as person type"; break;
+case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
