@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Crea Regole":  				$messaggio = "Create Rules"; break;
 case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Insert the assignment rules for reservations of year"; break;
 case "Regola di assegnazione":  		$messaggio = "Assignment rule"; break;
 case "nel periodo dal":  			$messaggio = "in the period from"; break;
@@ -61,6 +62,11 @@ case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rul
 case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
 case "persone":  				$messaggio = "people"; break;
 case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
+case "Regole esistenti":  			$messaggio = "Existing rules"; break;
+case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale down these rules"; break;
+case "Cancella":  				$messaggio = "Delete"; break;
+case "Ridimensiona":  				$messaggio = "Scale down"; break;
+case "Modifica la regola":  			$messaggio = "Modify rule"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
