@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Modifica Cliente":  			$messaggio = "Modify Client"; break;
 case "Il cognome verrà cambiato da":  		$messaggio = "The surname will be changed from"; break;
 case "a":  					$messaggio = "to"; break;
 case "Il nome verrà cambiato da":  		$messaggio = "The name will be changed from"; break;
@@ -155,6 +156,12 @@ case "questo valore è gia stato cancellato, questa è l'ultima volta che viene
 case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
 case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
 case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC o codice destinatario":  		$messaggio = "Certified email"; break;
+case "La seconda email verrà cambiata da":  	$messaggio = "The second email will be changed from"; break;
+case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "The certified email will be changed from"; break;
+case "La <b>seconda email</b> verrà cancellata":	$messaggio = "The <b>second email</b> will be deleted"; break;
+case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "The <b>certified email</b> will be deleted"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
