@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Modifica Documento":  			$messaggio = "Modify Document"; break;
 case "Torna indietro":  			$messaggio = "Go back"; break;
 case "documento":  				$messaggio = "document"; break;
 case "Modifica il documento":  			$messaggio = "Edit document"; break;
@@ -111,6 +112,14 @@ case "Tutti le partenze del":  			$messaggio = "All departures on"; break;
 case "Tutti i clienti":  			$messaggio = "All the clients"; break;
 case "escludendo gli ospiti":  			$messaggio = "excluding guests"; break;
 case "inclusi gli ospiti":  			$messaggio = "including guests"; break;
+case "ripetizione documenti salvati":  		$messaggio = "saved documents repetition"; break;
+case "formato dell'utente":  			$messaggio = "format from user"; break;
+case "Formato dei soldi":  			$messaggio = "Money format"; break;
+case "Formato delle date":  			$messaggio = "Dates format"; break;
+case "Formati predefiniti del documento cambiati":	$messaggio = "Default formats for the document changed"; break;
+case "i documenti esistenti non verranno mai sovrascritti, ogni volta che si chiama la API verrà salvato un nuovo documento":	$messaggio = "existing documents will never be overwritten, each time the API is called a new document will be saved"; break;
+case "Tutti i pagamenti nella cassa":  		$messaggio = "All payments in cashbox"; break;
+case "nome_cassa":  				$messaggio = "cashbox_name"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
