@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Modifica Prenotazioni":  			$messaggio = "Modify reservations"; break;
 case "Modifica o cancella la prenotazione":	$messaggio = "Modify or delete reservation"; break;
 case "Prenotazione a nome di":  		$messaggio = "Reservation for"; break;
 case "nato il":  				$messaggio = "born the"; break;
@@ -255,6 +256,16 @@ case "Il commento":  				$messaggio = "Comment"; break;
 case "verrà cambiato":  			$messaggio = "will be changed"; break;
 case "per ":  					$messaggio = "for "; break;
 case "Il numero di":  				$messaggio = "The number of"; break;
+case "Valuta":  				$messaggio = "Currency"; break;
+case "Valuta caparra":  			$messaggio = "Deposit currency"; break;
+case "Al cambio attuale":  			$messaggio = "At current exchange rate"; break;
+case "email":  					$messaggio = "email"; break;
+case "2ª email":  				$messaggio = "2nd email"; break;
+case "PEC/codice":  				$messaggio = "certified email"; break;
+case "cancella in modo permanente":  		$messaggio = "delete permanently"; break;
+case "in modo permanente":  			$messaggio = "permanently"; break;
+case "Prenotazione cancellata":  		$messaggio = "Deleted reservation"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
