@@ -437,6 +437,10 @@ case "La nuova valuta secondaria è stata aggiunta":	$messaggio = "The new secun
 case "La valuta secondaria":  			$messaggio = "The secundary currency"; break;
 case "è stata modificata":  			$messaggio = "has been modified"; break;
 case "è stata eliminata":  			$messaggio = "has been deleted"; break;
+case "La cartella":  				$messaggio = "The directory"; break;
+case "è un duplicato":  			$messaggio = "is a duplicate"; break;
+case "le seguenti pagine web verranno cancellate":	$messaggio = "the following web pages will be deleted"; break;
+case "le tipologie di persone rimosse erano presenti in alcuni costi aggiuntivi, questi costi vanno aggiornati manualmente se necessario":	$messaggio = "removed person types were present in some extra costs, eventually these costs must be updated manually"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
