@@ -32,6 +32,8 @@ $trad_var['telefono2'] = 'telephone2';
 $trad_var['telefono3'] = 'telephone3';
 $trad_var['fax'] = 'fax';
 $trad_var['email'] = 'email';
+$trad_var['email2'] = 'email2';
+$trad_var['email_certificata'] = 'certified_email';
 $trad_var['codice_fiscale'] = 'fiscal_code';
 $trad_var['partita_iva'] = 'vat_number';
 $trad_var['num_persone'] = 'people_num';
@@ -51,6 +53,15 @@ $trad_var['costo_tariffa_p'] = 'rate_price_p';
 $trad_var['costo_tariffa_giorno_array'] = 'rate_price_of_array_day';
 $trad_var['costo_tariffa_giorno_array_p'] = 'rate_price_of_array_day_p';
 $trad_var['sconto'] = 'discount';
+$trad_var['valuta_tariffa'] = 'rate_currency';
+$trad_var['tasso_cambio_tariffa'] = 'rate_exchange_rate';
+$trad_var['costo_valuta_tariffa'] = 'rate_currency_price';
+$trad_var['costo_valuta_tot'] = 'price_currency_tot';
+$trad_var['valore_valuta_sconto'] = 'discount_currency_value';
+$trad_var['valuta_caparra'] = 'deposit_currency';
+$trad_var['valore_valuta_caparra'] = 'deposit_currency_value';
+$trad_var['tasso_cambio_caparra'] = 'deposit_exchange_rate';
+$trad_var['metodo_pagamento_caparra'] = 'deposit_payment_method';
 $trad_var['commento'] = 'comment';
 $trad_var['promemoria_entrata'] = 'checkin_reminder';
 $trad_var['promemoria_uscita'] = 'checkout_reminder';
@@ -110,6 +121,9 @@ $trad_var['sconto_p'] = 'discount_p';
 $trad_var['num_costi_aggiuntivi'] = 'extra_costs_number';
 $trad_var['valore_pagamento'] = 'payment_value';
 $trad_var['valore_pagamento_p'] = 'payment_value_p';
+$trad_var['valuta_pagamento'] = 'payment_currency';
+$trad_var['valore_valuta_pagamento'] = 'payment_currency_value';
+$trad_var['tasso_cambio_pagamento'] = 'payment_exchange_rate';
 $trad_var['data_pagamento'] = 'payment_date';
 $trad_var['utente_pagamento'] = 'payment_user';
 $trad_var['metodo_pagamento'] = 'payment_method';
@@ -193,6 +207,8 @@ $trad_var['telefono2_ospite'] = 'telephone2_guest';
 $trad_var['telefono3_ospite'] = 'telephone3_guest';
 $trad_var['fax_ospite'] = 'fax_guest';
 $trad_var['email_ospite'] = 'email_guest';
+$trad_var['email2_ospite'] = 'email2_guest';
+$trad_var['email_certificata_ospite'] = 'certified_email_guest';
 $trad_var['codice_fiscale_ospite'] = 'fiscal_code_guest';
 $trad_var['partita_iva_ospite'] = 'vat_number_guest';
 $trad_var['codice_cittadinanza_ospite'] = 'nationality_code_guest';
@@ -258,6 +274,7 @@ $trad_var['ragione_sociale_struttura'] = 'structure_company_name';
 $trad_var['sito_web_struttura'] = 'structure_website';
 $trad_var['nome_contatto_struttura'] = 'structure_contact_name';
 $trad_var['nazione_struttura'] = 'structure_nation';
+$trad_var['regione_struttura'] = 'structure_region';
 $trad_var['comune_struttura'] = 'structure_city';
 $trad_var['indirizzo_struttura'] = 'structure_address';
 $trad_var['CAP_struttura'] = 'structure_postal_code';
@@ -267,6 +284,15 @@ $trad_var['codice_fiscale_struttura'] = 'structure_fiscal_code';
 $trad_var['partita_iva_struttura'] = 'structure_vat_number';
 $trad_var['numero_stelle_struttura'] = 'structure_stars_number';
 $trad_var['logo_struttura'] = 'structure_logo';
+$trad_var['codice_nazione_struttura'] = 'structure_nation_code';
+$trad_var['codice_regione_struttura'] = 'structure_region_code';
+$trad_var['codice_comune_struttura'] = 'structure_city_code';
+$trad_var['codice2_nazione_struttura'] = 'structure_nation_code2';
+$trad_var['codice2_regione_struttura'] = 'structure_region_code2';
+$trad_var['codice2_comune_struttura'] = 'structure_city_code2';
+$trad_var['codice3_nazione_struttura'] = 'structure_nation_code3';
+$trad_var['codice3_regione_struttura'] = 'structure_region_code3';
+$trad_var['codice3_comune_struttura'] = 'structure_city_code3';
 $trad_var['nome_valuta'] = 'currency_name';
 $trad_var['testo_email_richiesta'] = 'enquiry_email_text';
 $trad_var['testo_quotato_email_richiesta'] = 'enquiry_email_quoted_text';
@@ -280,6 +306,10 @@ $trad_var['codice_lingua'] = 'language_code';
 $trad_var['email_gia_inviata'] = 'email_already_sent';
 $trad_var['commento_personalizzato'] = 'custom_comment';
 $trad_var['campo_personalizzato'] = 'custom_field';
+$trad_var['nome_documento_salvato'] = 'saved_document_name';
+$trad_var['numero_progressivo_documento_salvato'] = 'saved_document_progressive_number';
+$trad_var['data_creazione_documento_salvato'] = 'saved_document_creation_date';
+$trad_var['nome_file_documento_salvato'] = 'saved_document_filename';
 
 
 ?>
\ No newline at end of file
