@@ -370,6 +370,11 @@ case "Prenotazioni cancellate":  		$messaggio = "Deleted reservations"; break;
 case "<b>non importare</b> i prezzi":  		$messaggio = "<b>do not import</b> prices"; break;
 case "Attenzione":  				$messaggio = "Notice"; break;
 case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "periods added now can't be deleted later"; break;
+case "come tipo di persona":  			$messaggio = "as person type"; break;
+case "e applica la % del tipo di persona":  	$messaggio = "and apply the % of person type"; break;
+case "escludendo":  				$messaggio = "excluding"; break;
+case "includendo solo":  			$messaggio = "including only"; break;
+case "e":  					$messaggio = "and"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
