@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Clienti":  				$messaggio = "Clientes"; break;
 case "Le date sono sbagliate":  		$messaggio = "Las fechas están equivocadas"; break;
 case "Si deve inserire il tipo di tariffa":  	$messaggio = "Hay que insertar el tipo de tarifa"; break;
 case "tariffa":  				$messaggio = "tarifa"; break;
@@ -130,6 +131,12 @@ case "Commento":  				$messaggio = "Comentario"; break;
 case "Si deve inserire almeno una persona che possa essere ospite principale":	$messaggio = "Hay que insertar por lo menos una persona que pueda ser huésped principal"; break;
 case "non si sono potuti usare":  		$messaggio = "No ha sido posible usar"; break;
 case "letti aggiuntivi perchè non c'era nessuna tipologia di persone con quel numero":	$messaggio = "camas extras porque no había ningún tipo de personas con ese número"; break;
+case "E-mail":  				$messaggio = "E-mail"; break;
+case "Seconda e-mail":  			$messaggio = "Segundo e-mail"; break;
+case "E-mail certificata (PEC) o codice destinatario":	$messaggio = "E-mail certificado"; break;
+case "email":  					$messaggio = "email"; break;
+case "2ª email":  				$messaggio = "2º email"; break;
+case "PEC/codice":  				$messaggio = "email certificado"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
