@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Backup":  				$messaggio = "Backup"; break;
 case "File creato":  				$messaggio = "Archivo creado"; break;
 case "Non ho il permesso di scrittura sul file":	$messaggio = "No tengo el permiso de escritura sobre el archivo"; break;
 case "Si è verificato un errore cancellando il file":	$messaggio = "Se ha producido un error al borrar el archivo"; break;
@@ -67,7 +68,7 @@ case "i documenti attuali verranno cancellati":	$messaggio = "los documentos act
 case "Ripristina i documenti dal file":  	$messaggio = "Restaurar los documentos desde el archivo"; break;
 case "Documenti ripristinati":  		$messaggio = "Documentos restaurados"; break;
 case "Backup completo":  			$messaggio = "Backup completo"; break;
-case "Includi i modelli internet":  		$messaggio = "Incluir los modelos para intenet"; break;
+case "Includi le pagine per il sito web":  	$messaggio = "Incluir las páginas para el sitio web"; break;
 case "creato il":  				$messaggio = "creado el"; break;
 case "alle":  					$messaggio = "a las"; break;
 case "copia":  					$messaggio = "copiar"; break;
