@@ -6,6 +6,7 @@ switch ($messaggio) {
 # translate YES and NO in upper case
 case "SI":  					$messaggio = "SI"; break;
 case "NO":  					$messaggio = "NO"; break;
+case "Crea Pagine Web":  			$messaggio = "Crear Páginas Web"; break;
 case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Crea pagine per il sito web":  		$messaggio = "Crear páginas para el sitio web"; break;
 case "Dati comuni":  				$messaggio = "Datos comunes"; break;
@@ -100,6 +101,8 @@ case "di":  					$messaggio = "de"; break;
 case "Nuovo controllo":  			$messaggio = "Nuevo control"; break;
 case "Nome":  					$messaggio = "Nombre"; break;
 case "Email":  					$messaggio = "Email"; break;
+case "Email alternativa":  			$messaggio = "Email alternativa"; break;
+case "Email certificata (PEC) o codice destinatario":	$messaggio = "Email certificada"; break;
 case "Commento":  				$messaggio = "Comentario"; break;
 case "Invia la richiesta di prenotazione":  	$messaggio = "Envía el pedido de reserva"; break;
 case "Richiesta di prenotazione inviata": 	$messaggio = "Pedido de reserva enviado"; break;
@@ -273,7 +276,7 @@ case "Data di partenza":  			$messaggio = "Fecha de salida"; break;
 case "Tipologia":  				$messaggio = "Tipologia"; break;
 case "default - frame orizzontale":  		$messaggio = "default - frame horizontál"; break;
 case "Condizioni da accettare nella form":  	$messaggio = "Condiciónes a aceptar en el formulario"; break;
-case "nomi dall'utente delle liste":		$messaggio = "nombres del usuario de las listas"; break;
+case "nomi dall'utente delle personalizzazioni":	$messaggio = "nombres del usuario de las personalizaciones"; break;
 case "Accetto":  				$messaggio = "Acepto"; break;
 case "documento":  				$messaggio = "documento"; break;
 case "larghezza":  				$messaggio = "anchura"; break;
@@ -321,6 +324,12 @@ case "Mostrare le date passate?":  		$messaggio = "Enseñar las fechas pasadas?"
 case "titolo html":  				$messaggio = "Título html"; break;
 case "titolo":  				$messaggio = "Título"; break;
 case "Si deve inserire almeno una persona che possa essere legalmente responsabile":	$messaggio = "Hay que incluir al menos una persona que pueda ser legalmente responsable"; break;
+case "Solo quando non c'è disponibilità":  	$messaggio = "Solo cuando no hay disponibilidad"; break;
+case "Sempre":  				$messaggio = "Siempre"; break;
+case "Raggruppamento":  			$messaggio = "Agrupación"; break;
+case "Valuta della caparra":  			$messaggio = "Divisa de la fianza"; break;
+case "Seconda email":  				$messaggio = "Segunda email"; break;
+case "PEC o codice destinatario":  		$messaggio = "Email certificada"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -428,6 +437,8 @@ case "var_fr_di":  				$messaggio = "var_fr_de"; break;
 case "var_fr_Nuovo_controllo":  		$messaggio = "var_fr_Nuevo_control"; break;
 case "var_fr_Nome":  				$messaggio = "var_fr_Nombre"; break;
 case "var_fr_Email":  				$messaggio = "var_fr_Email"; break;
+case "var_fr_Email_alternativa":  		$messaggio = "var_fr_Email_alternativa"; break;
+case "var_fr_Email_certificata_o_codice_destinatario":	$messaggio = "var_fr_Email_certificada"; break;
 case "var_fr_Commento":  			$messaggio = "var_fr_Comentario"; break;
 case "var_fr_Invia_la_richiesta_di_prenotazione":	$messaggio = "var_fr_Envia_el_pedido_de_reserva"; break;
 case "var_fr_Richiesta_di_prenotazione_inviata":	$messaggio = "var_fr_Pedido_de_reserva_enviado"; break;
@@ -435,6 +446,9 @@ case "var_fr_Non_e_stato_possibile_inviare_la_richiesta":	$messaggio = "var_fr_N
 case "var_fr_da":  				$messaggio = "var_fr_desde2"; break;
 case "var_fre_Email":  				$messaggio = "var_fre_Email"; break;
 case "var_fre_Nome":  				$messaggio = "var_fre_Nombre"; break;
+case "var_fre_Email_alternativa":  		$messaggio = "var_fre_Email_alternativa"; break;
+case "var_fre_Email_certificata_o_codice_destinatario":	$messaggio = "var_fre_Email_certificada"; break;
+case "var_fre_Nome":  				$messaggio = "var_fre_Nombre"; break;
 case "var_fre_Commento":  			$messaggio = "var_fre_Comentario"; break;
 case "var_fre_Periodo":  			$messaggio = "var_fre_Periodo"; break;
 case "var_fre_dal":  				$messaggio = "var_fre_desde"; break;
@@ -446,6 +460,7 @@ case "var_fre_Prezzo_totale":  			$messaggio = "var_fre_Precio_total"; break;
 case "var_fre_Riferimento":  			$messaggio = "var_fre_Referencia"; break;
 case "var_fre_Caparra":  			$messaggio = "var_fre_Fianza"; break;
 case "var_fre_Richesta_prenotazione":  		$messaggio = "var_fre_Pedido_de_reserva"; break;
+case "var_fre_Valuta_della_caparra":  		$messaggio = "var_fre_Divisa_de_la_fianza"; break;
 case "var_fr_Richesta_prenotazione":  		$messaggio = "var_fr_Pedido_de_reserva"; break;
 case "var_periodi_menu":  			$messaggio = "var_lista_periodos"; break;
 case "var_fr_appartamenti":  			$messaggio = "var_fr_apartamentos"; break;
@@ -509,6 +524,8 @@ case "var_utente_messaggio":  			$messaggio = "var_usuario_mensaje"; break;
 case "var_chiedi_cognome":  			$messaggio = "var_pedir_apellido"; break;
 case "var_chiedi_nome":  			$messaggio = "var_pedir_nombre"; break;
 case "var_chiedi_email":  			$messaggio = "var_pedir_email"; break;
+case "var_chiedi_email2":  			$messaggio = "var_pedir_email2"; break;
+case "var_chiedi_email_cert":  			$messaggio = "var_pedir_email_cert"; break;
 case "var_chiedi_sesso":  			$messaggio = "var_pedir_sexo"; break;
 case "var_chiedi_datanascita":  		$messaggio = "var_pedir_fechanacimiento"; break;
 case "var_chiedi_documento":  			$messaggio = "var_pedir_documento"; break;
@@ -526,6 +543,7 @@ case "var_chiedi_codfiscale":  			$messaggio = "var_pedir_numidfiscal"; break;
 case "var_chiedi_partitaiva":  			$messaggio = "var_pedir_certidfiscal"; break;
 case "var_chiedi_commento":  			$messaggio = "var_pedir_comentario"; break;
 case "var_chiedi_oracheckin":  			$messaggio = "var_pedir_horaentrada"; break;
+case "var_chiedi_valutapagamento":  		$messaggio = "var_pedir_divisapago"; break;
 case "var_chiedi_metodopagamento":  		$messaggio = "var_pedir_metodopago"; break;
 case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_metodos_pago_a_pedir"; break;
 case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_nombres_metodos_pago_impuestos"; break;
@@ -551,6 +569,7 @@ case "var_fr_Fax":  				$messaggio = "var_fr_Fax"; break;
 case "var_fr_Codice_fiscale":  			$messaggio = "var_fr_N_identificacion_fiscal"; break;
 case "var_fr_Partita_iva":  			$messaggio = "var_fr_Cert_identificacion_fiscal"; break;
 case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_fr_Horario_estimativo_de_llegada"; break;
+case "var_fr_Valuta_della_caparra":		$messaggio = "var_fr_Divisa_de_la_fianza"; break;
 case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_fr_Metodo_de_pago_de_la_fianza"; break;
 case "var_fre_Cognome":  			$messaggio = "var_fre_Apellido"; break;
 case "var_fre_Genere":  			$messaggio = "var_fre_Genero"; break;
