@@ -285,7 +285,7 @@ case "Periodi in cui viene applicato il costo":	$messaggio = "Períodos en los q
 case "Valore dello sconto per ogni bambino":  	$messaggio = "Valor del descuento para cada niño"; break;
 case "del prezzo di una persona":  		$messaggio = "del precio de una persona"; break;
 case "solo per tariffe con prezzi a persona":  	$messaggio = "solo para tarifas con precios por persona"; break;
-case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "con este coste hay que incluir el número de niños también en el numero de personas"; break;
+case "con questo costo si deve includere il numero di bambini anche nel numero di persone":	$messaggio = "con este coste hay que incluir el número de niños también en el número de personas"; break;
 case "Valore del letto aggiuntivo":  		$messaggio = "Valor de la cama extra"; break;
 case "Valore dello sconto":  			$messaggio = "Valor del descuento"; break;
 case "del prezzo totale":  			$messaggio = "del precio total"; break;
@@ -314,6 +314,12 @@ case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè import
 case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "límite no considerado para las personas adicionales en las interconexiones"; break;
 case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Seleccionar ahora este coste también para todos los usuarios que no tienen privilegios para usar todos los costes"; break;
 case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Añadir ahora este coste a todas las páginas creadas para el sitio web"; break;
+case "Se si moltiplica per il numero di persone":	$messaggio = "Cuando se multiplica por el número de personas"; break;
+case "escludi":  				$messaggio = "excluir"; break;
+case "includi solo":  				$messaggio = "incluir solo"; break;
+case "questi tipi":  				$messaggio = "estos tipos"; break;
+case "Mostrare come tipo di persona":  		$messaggio = "Enseñar como tipo de persona"; break;
+case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Aplicar el porcentaje del tipo de persona al coste"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
