@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Crea Regole":  				$messaggio = "Crear Reglas"; break;
 case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Insertar las reglas de asignación para las reservas del año"; break;
 case "Regola di assegnazione":  		$messaggio = "Regla de asignación"; break;
 case "nel periodo dal":  			$messaggio = "en el período desde"; break;
@@ -61,6 +62,11 @@ case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "de la
 case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "en la regla 2 de esta tarifa que puedan hospedar"; break;
 case "persone":  				$messaggio = "personas"; break;
 case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "en la regla de asignación 2 de esta tarifa"; break;
+case "Regole esistenti":  			$messaggio = "Reglas existentes"; break;
+case "Cancella o ridimensiona queste regole":  	$messaggio = "Borrar o reducir estas reglas"; break;
+case "Cancella":  				$messaggio = "Borrar"; break;
+case "Ridimensiona":  				$messaggio = "Reducir"; break;
+case "Modifica la regola":  			$messaggio = "Modificar la regla"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
