@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Modifica Cliente":  			$messaggio = "Modificar Cliente"; break;
 case "Il cognome verrà cambiato da":  		$messaggio = "El apellido será cambiado de"; break;
 case "a":  					$messaggio = "a"; break;
 case "Il nome verrà cambiato da":  		$messaggio = "El nombre será cambiado de"; break;
@@ -157,6 +158,12 @@ case "questo valore è gia stato cancellato, questa è l'ultima volta che viene
 case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "Será posible ver este valor solo una vez más"; break;
 case "Cancellalo ora":  			$messaggio = "Borrarlo ahora"; break;
 case "CVC cancellato":  			$messaggio = "CVC borrado"; break;
+case "2ª email":  				$messaggio = "2° Correo electrónico"; break;
+case "PEC o codice destinatario":  		$messaggio = "Correo electrónico certificado"; break;
+case "La seconda email verrà cambiata da":  	$messaggio = "El segundo correo electrónico será cambiado de"; break;
+case "L'email certificata (PEC) o il codice destinatario verrà cambiato da":	$messaggio = "El correo electrónico certificado será cambiado de"; break;
+case "La <b>seconda email</b> verrà cancellata":	$messaggio = "El <b>segundo correo electrónico</b> será borrado"; break;
+case "L'<b>email certificata (PEC) o il codice destinatario</b> verrà cancellato":	$messaggio = "El <b>correo electrónico certificado</b> será borrado"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
