@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Modifica Prenotazioni":  			$messaggio = "Modificar reservas"; break;
 case "Modifica o cancella la prenotazione":	$messaggio = "Modificar o borrar la reserva"; break;
 case "Prenotazione a nome di":  		$messaggio = "Reserva a nombre de"; break;
 case "nato il":  				$messaggio = "nacido el"; break;
@@ -64,7 +65,7 @@ case "visualizza":  				$messaggio = "ver"; break;
 case "visualizza il documento":  		$messaggio = "ver el documento"; break;
 case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "SI":  					$messaggio = "SI"; break;
-case "cancella anche ciò che era stato pagato":	$messaggio = "borra también lo que ya había sido pagado"; break;
+case "cancella anche ciò che era stato pagato":	$messaggio = "borrar también lo que ya había sido pagado"; break;
 case "NO":  					$messaggio = "NO"; break;
 case "La prenotazione":  			$messaggio = "La reserva"; break;
 case "era già stata cancellata":  		$messaggio = "había sido ya borrada"; break;
@@ -255,6 +256,16 @@ case "Il commento":  				$messaggio = "El comentario"; break;
 case "verrà cambiato":  			$messaggio = "será cambiado"; break;
 case "per ":  					$messaggio = "para "; break;
 case "Il numero di":  				$messaggio = "El número de"; break;
+case "Valuta":  				$messaggio = "Divisa"; break;
+case "Valuta caparra":  			$messaggio = "Divisa fianza"; break;
+case "Al cambio attuale":  			$messaggio = "Al cambio corriente"; break;
+case "email":  					$messaggio = "email"; break;
+case "2ª email":  				$messaggio = "2º email"; break;
+case "PEC/codice":  				$messaggio = "email certificado"; break;
+case "cancella in modo permanente":  		$messaggio = "borrar permanentemente"; break;
+case "in modo permanente":  			$messaggio = "permanentemente"; break;
+case "Prenotazione cancellata":  		$messaggio = "Reserva borrada"; break;
+case "Prenotazioni cancellate":  		$messaggio = "Reservas borradas"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
