@@ -437,6 +437,10 @@ case "La nuova valuta secondaria è stata aggiunta":	$messaggio = "La nueva divi
 case "La valuta secondaria":  			$messaggio = "La divisa secundaria"; break;
 case "è stata modificata":  			$messaggio = "ha sido modificada"; break;
 case "è stata eliminata":  			$messaggio = "ha sido eliminada"; break;
+case "La cartella":  				$messaggio = "El directorio"; break;
+case "è un duplicato":  			$messaggio = "es un duplicado"; break;
+case "le seguenti pagine web verranno cancellate":	$messaggio = "las siguientes páginas web serán borradas"; break;
+case "le tipologie di persone rimosse erano presenti in alcuni costi aggiuntivi, questi costi vanno aggiornati manualmente se necessario":	$messaggio = "los tipos de personas eliminados estaban presentes en algunos costes añadidos, estos costes tendrán que ser actualizados manualmente si es necesario"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
