@@ -2,6 +2,7 @@
 
 switch ($messaggio) {
 
+case "Privilegi Utenti":  			$messaggio = "Privilegos Usuarios"; break;
 case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Privilegi dell'utente":  			$messaggio = "Privilegos del usuario"; break;
 case "Privilegi <b>globali</b>":  		$messaggio = "Privilegos <b>globales</b>"; break;
@@ -366,8 +367,34 @@ case "non potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel"
 case "senza mostrarla":  			$messaggio = "sin mostrarla"; break;
 case "senza mostrarli":  			$messaggio = "sin mostrarlos"; break;
 case "Modifica delle tipologie di persone":  	$messaggio = "Modificar los tipos de personas"; break;
-case "potrà modificare le sue <b>tipologie di persone</b>":	$messaggio = "podrá modificar sus <b>tipos de personas</b>"; break;
-case "non potrà più modificare le sue <b>tipologie di persone</b>":	$messaggio = "ya no podrá modificar sus <b>tipos de personas</b>"; break;
+case "potrà modificare le sue <b>tipologie di persone</b>":	$messaggio = "podrá modificar sus <b>tipologías de personas</b>"; break;
+case "non potrà più modificare le sue <b>tipologie di persone</b>":	$messaggio = "ya no podrá modificar sus <b>tipologías de personas</b>"; break;
+case "Modifica delle valute":  			$messaggio = "Modificar las divisas"; break;
+case "potrà modificare le sue <b>valute</b>":  	$messaggio = "podrá modificar sus <b>divisas</b>"; break;
+case "non potrà più modificare le sue <b>valute</b>":	$messaggio = "ya no podrá modificar sus <b>divisas</b>"; break;
+case "solo per lui":  				$messaggio = "solo para él"; break;
+case "anche per i suoi gruppi":  		$messaggio = "también para sus grupos"; break;
+case "anche per tutti gli utenti":  		$messaggio = "también para todos los usuarios"; break;
+case "e quelle di utenti appartenenti ai suoi gruppi":	$messaggio = "y las de usuarios que pertenecen a sus grupos"; break;
+case "e quelle di tutti gli altri utenti":  	$messaggio = "y las de todos los usuarios"; break;
+case "Cancellare le prenotazioni in modo permanente":	$messaggio = "Borrar las reservas permanentemente"; break;
+case "non <b>cancellerà mai in modo permanente</b> le prenotazioni nel":	$messaggio = "no <b>borrará nunca permanentemente</b> las reservas en el"; break;
+case "potrà scegliere se <b>cancellare in modo permanente</b> le prenotazioni nel":	$messaggio = "podrá escoger si <b>borrar permanentemente</b> las reservas en el"; break;
+case "<b>cancellerà sempre in modo permanete</b> le prenotazioni nel":	$messaggio = "<b>borrará siempre permanentemente</b> las reservas en el"; break;
+case "Possibilità di modificare le <i>regole di assegnazione</i>":	$messaggio = "Posibilidad de modificar las <i>reglas de asignación</i>"; break;
+case "non potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "no podrá modificar las <b>reglas de asignación 1</b> en el"; break;
+case "potrà modifcare le <b>regole di assegnazione 1</b> nel":	$messaggio = "podrá modificar las <b>reglas de asignación 1</b> en el"; break;
+case "non potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "no podrá modificar las <b>reglas de asignación 2 y 3</b> en el"; break;
+case "potrà modifcare le <b>regole di assegnazione 2 e 3</b> nel":	$messaggio = "podrá modificar las <b>reglas de asignación 2 y 3</b> en el"; break;
+case "e":  					$messaggio = "y"; break;
+case "assegnazione persone":  			$messaggio = "asignación personas"; break;
+case "Creazione e modifica delle pagine per il sito web":	$messaggio = "Creación y modificación de las páginas para el sitio web"; break;
+case "Solo con i costi aggiuntivi":  		$messaggio = "Solo con los costes añadidos"; break;
+case "potrà creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "podrá crear y modificar las <b>páginas para el sitio web</b>"; break;
+case "potrà modificare le <b>pagine per il sito web</b> solo quando crea e modifica i costi aggiuntivi":	$messaggio = "podrá modificar las <b>páginas para el sitio web</b> solo cuando crea y modifica los costes añadidos"; break;
+case "non potrà più creare e modificare le <b>pagine per il sito web</b>":	$messaggio = "ya no podrá crear y modificar las <b>páginas para el sitio web</b>"; break;
+case "solo per tariffe":  			$messaggio = "solo para tarifas"; break;
+case "per entrambi":  				$messaggio = "para ambos"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
