@@ -3,7 +3,7 @@
 switch ($messaggio) {
 
 case "via":  				$messaggio = "calle"; break;
-case "Torna indietro":  		$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  		$messaggio = "Volver atrás"; break;
 case "Da":  				$messaggio = "Desde"; break;
 case "A":  				$messaggio = "Para"; break;
 case "Oggetto":  			$messaggio = "Asunto"; break;
