@@ -32,6 +32,8 @@ $trad_var['telefono2'] = 'telefono2';
 $trad_var['telefono3'] = 'telefono3';
 $trad_var['fax'] = 'fax';
 $trad_var['email'] = 'email';
+$trad_var['email2'] = 'email2';
+$trad_var['email_certificata'] = 'email_certificada';
 $trad_var['codice_fiscale'] = 'num_identificacion_fiscal';
 $trad_var['partita_iva'] = 'certificado_identificacion_fiscal';
 $trad_var['num_persone'] = 'num_personas';
@@ -51,6 +53,15 @@ $trad_var['costo_tariffa_p'] = 'precio_tarifa_p';
 $trad_var['costo_tariffa_giorno_array'] = 'precio_tarifa_dia_array';
 $trad_var['costo_tariffa_giorno_array_p'] = 'precio_tarifa_dia_array_p';
 $trad_var['sconto'] = 'descuento';
+$trad_var['valuta_tariffa'] = 'divisa_tarifa';
+$trad_var['tasso_cambio_tariffa'] = 'tipo_cambio_tarifa';
+$trad_var['costo_valuta_tariffa'] = 'precio_divisa_tarifa';
+$trad_var['costo_valuta_tot'] = 'coste_divisa_tot';
+$trad_var['valore_valuta_sconto'] = 'valor_divisa_descuento';
+$trad_var['valuta_caparra'] = 'divisa_fianza';
+$trad_var['valore_valuta_caparra'] = 'valor_divisa_fianza';
+$trad_var['tasso_cambio_caparra'] = 'tipo_cambio_fianza';
+$trad_var['metodo_pagamento_caparra'] = 'metodo_pago_fianza';
 $trad_var['commento'] = 'comentario';
 $trad_var['promemoria_entrata'] = 'recordatorio_entrada';
 $trad_var['promemoria_uscita'] = 'recordatorio_salida';
@@ -110,6 +121,9 @@ $trad_var['sconto_p'] = 'descuento_p';
 $trad_var['num_costi_aggiuntivi'] = 'num_costes_agnadidos';
 $trad_var['valore_pagamento'] = 'valor_pago';
 $trad_var['valore_pagamento_p'] = 'valor_pago_p';
+$trad_var['valuta_pagamento'] = 'divisa_pago';
+$trad_var['valore_valuta_pagamento'] = 'valor_divisa_pago';
+$trad_var['tasso_cambio_pagamento'] = 'tipo_cambio_pago';
 $trad_var['data_pagamento'] = 'fecha_pago';
 $trad_var['utente_pagamento'] = 'usuario_pago';
 $trad_var['metodo_pagamento'] = 'metodo_pago';
@@ -191,6 +205,8 @@ $trad_var['telefono2_ospite'] = 'telefono2_huesped';
 $trad_var['telefono3_ospite'] = 'telefono3_huesped';
 $trad_var['fax_ospite'] = 'fax_huesped';
 $trad_var['email_ospite'] = 'email_huesped';
+$trad_var['email2_ospite'] = 'email2_huesped';
+$trad_var['email_certificata_ospite'] = 'email_certificada_huesped';
 $trad_var['codice_fiscale_ospite'] = 'codigo_fiscal_huesped';
 $trad_var['partita_iva_ospite'] = 'num_identificacion_fiscal_huesped';
 $trad_var['codice_cittadinanza_ospite'] = 'codigo_nacionalidad_huesped';
@@ -256,6 +272,7 @@ $trad_var['ragione_sociale_struttura'] = 'razon_social_estructura';
 $trad_var['sito_web_struttura'] = 'sitio_web_estructura';
 $trad_var['nome_contatto_struttura'] = 'nombre_contacto_estructura';
 $trad_var['nazione_struttura'] = 'nacion_estructura';
+$trad_var['regione_struttura'] = 'region_estructura';
 $trad_var['comune_struttura'] = 'ciudad_estructura';
 $trad_var['indirizzo_struttura'] = 'direccion_estructura';
 $trad_var['CAP_struttura'] = 'codigo_postal_estructura';
@@ -265,6 +282,15 @@ $trad_var['codice_fiscale_struttura'] = 'num_identificacion_fiscal_estructura';
 $trad_var['partita_iva_struttura'] = 'certificado_identificacion_fiscal_estructura';
 $trad_var['numero_stelle_struttura'] = 'numero_estrellas_estructura';
 $trad_var['logo_struttura'] = 'logo_estructura';
+$trad_var['codice_nazione_struttura'] = 'codigo_nacion_estructura';
+$trad_var['codice_regione_struttura'] = 'codigo_region_estructura';
+$trad_var['codice_comune_struttura'] = 'codigo_ciudad_estructura';
+$trad_var['codice2_nazione_struttura'] = 'codigo2_nacion_estructura';
+$trad_var['codice2_regione_struttura'] = 'codigo2_region_estructura';
+$trad_var['codice2_comune_struttura'] = 'codigo2_ciudad_estructura';
+$trad_var['codice3_nazione_struttura'] = 'codigo3_nacion_estructura';
+$trad_var['codice3_regione_struttura'] = 'codigo3_region_estructura';
+$trad_var['codice3_comune_struttura'] = 'codigo3_ciudad_estructura';
 $trad_var['nome_valuta'] = 'nombre_divisa';
 $trad_var['testo_email_richiesta'] = 'texto_email_pedido';
 $trad_var['testo_quotato_email_richiesta'] = 'texto_citado_email_pedido';
@@ -278,6 +304,10 @@ $trad_var['codice_lingua'] = 'codigo_idioma';
 $trad_var['email_gia_inviata'] = 'email_ya_enviada';
 $trad_var['commento_personalizzato'] = 'comentario_personalizado';
 $trad_var['campo_personalizzato'] = 'campo_personalizado';
+$trad_var['nome_documento_salvato'] = 'nombre_documento_salvado';
+$trad_var['numero_progressivo_documento_salvato'] = 'numero_progresivo_documento_salvado';
+$trad_var['data_creazione_documento_salvato'] = 'fecha_creacion_documento_salvado';
+$trad_var['nome_file_documento_salvato'] = 'nombre_archivo_documento_salvado';
 
 
 ?>
\ No newline at end of file
