@@ -371,6 +371,11 @@ case "Prenotazioni cancellate":  		$messaggio = "Reservas borradas"; break;
 case "<b>non importare</b> i prezzi":  		$messaggio = "<b>sin importar</b> los precios"; break;
 case "Attenzione":  				$messaggio = "Aviso"; break;
 case "i periodi aggiunti non potranno più essere eliminati":	$messaggio = "los períodos añadidos ya no podrán ser eliminados"; break;
+case "come tipo di persona":  			$messaggio = "como tipo de persona"; break;
+case "e applica la % del tipo di persona":  	$messaggio = "y aplicar el % del tipo de persona"; break;
+case "escludendo":  				$messaggio = "excluyendo"; break;
+case "includendo solo":  			$messaggio = "incluyendo solo"; break;
+case "e":  					$messaggio = "y"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
