@@ -23,7 +23,7 @@
 
 
 $debug = "off";
-$sec_limite_libsett = "";
+$sec_limite_libsett = 0;
 #apd_set_pprof_trace();
 #if (function_exists('ini_set')) @ini_set('xdebug.max_nesting_level',1000000);
 
@@ -31,6 +31,7 @@ $sec_limite_libsett = "";
 # Function per passare dalla tabella prenota alle variabili
 function tab_a_var (&$limiti_var,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_app_sett,$anno,&$dati_app,$profondita,$nome_tab_prenota = "prenota") {
 global $PHPR_TAB_PRE,$sec_limite_libsett,$debug;
+if ($nome_tab_prenota == "prenota") $nome_tab_prenota = $PHPR_TAB_PRE.$nome_tab_prenota;
 $tableprenota = $nome_tab_prenota . $anno . $profondita['iniziale'];
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
@@ -662,7 +663,7 @@ if ($fatto != "SI") {
 
 # allargo il periodo passato dalla tabella alle variabili se necessario
 $lista_prenota_periodo = array();
-$pren_pres_in_lista = "";
+$pren_pres_in_lista = array();
 $num_lista_pren_per = 0;
 if (!$limiti_var['s_ini']) {
 lista_prenota_periodo($idinizio,$idfine,$dati_app,$prenota_in_app_sett,$pren_pres_in_lista,$lista_prenota_periodo,$num_lista_pren_per);
