@@ -60,7 +60,7 @@ $nuova_profondita = $profondita;
 $nuova_profondita['attuale'] = $profondita['attuale'] + 1;
 $app_prenota_id2 = $app_prenota_id;
 $prenota_in_app_sett2 = $prenota_in_app_sett;
-$ap_ric = "";
+$ap_ric = array();
 $ap_ric[$numapp] = "SI";
 $n_tronchi2 = $n_tronchi;
 $vet_appartamenti2 = $vet_appartamenti;
