@@ -95,8 +95,8 @@ return $messaggio;
 
 
 
-$fr_frase = "";
-$frase = "";
+$fr_frase = array();
+$frase = array();
 
 $fr_frase[0] = "fr_tariffa";
 $fr_frase[1] = "fr_persona";
