@@ -177,7 +177,14 @@ inserisci_prenota_fittizie($info_periodi_ag,$profondita,$app_prenota_id,$inizio_
 $app_orig_prenota_id = $app_prenota_id;
 } # fine if ($info_periodi_ag['numero'])
 
-$app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' and (motivazione2 != 'x' or motivazione2 is NULL) ");
+if (is_array($motivazioni_regola1)) {
+foreach ($motivazioni_regola1 as $key => $val) if ($val == "SI") $condizioni_regole1_consentite .= "motivazione = '".aggslashdb($key)."' or ";
+if (!$condizioni_regole1_consentite) $condizioni_regole1_consentite = "idregole < '0'";
+else $condizioni_regole1_consentite = "(".str_replace("motivazione = ' '","motivazione = '' or motivazione is null",substr($condizioni_regole1_consentite,0,-4)).")";
+} # fine if (is_array($motivazioni_regola1))
+else $condizioni_regole1_consentite = "idregole < '0'";
+$app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' and $condizioni_regole1_consentite ");
+
 $regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
 unset($dati_r2);
@@ -209,11 +216,8 @@ $nome_mese["09"] = $fr_Settembre;
 $nome_mese["10"] = $fr_Ottobre;
 $nome_mese["11"] = $fr_Novembre;
 $nome_mese["12"] = $fr_Dicembre;
-unset($app_consentito);
-unset($app_consentito_sett);
 
-# Calcolo gli appartamenti consentiti dalla regola 2 e i nomi delle tariffe
-$tutti_consentiti = "NO";
+# Calcolo i nomi delle tariffe
 for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
 if ($tariffe_mostra[$numtariffa] == "SI") {
 if ($mostra_quadro_disp == "reg2") {
@@ -223,39 +227,12 @@ $nome_tariffa[$numtariffa] = $dati_tariffe["tariffa$numtariffa"]['nome'];
 if ($nome_tariffa[$numtariffa] == "") $nome_tariffa[$numtariffa] = $fr_tariffa.$numtariffa;
 } # fine else if ($n_tariffe_imposte[$numtariffa])
 } # fine if ($mostra_quadro_disp == "reg2")
-if (!$app_regola2_orig[$numtariffa]) $tutti_consentiti = "SI";
-if ($tutti_consentiti != "SI") {
-$appartamenti_regola2 = explode(",",$app_regola2_orig[$numtariffa]);
-for ($num1 = 0 ; $num1 < count($appartamenti_regola2) ; $num1++) $app_consentito[$appartamenti_regola2[$num1]] = "SI";
-} # fine if ($tutti_consentiti != "SI")
 } # fine if ($tariffe_mostra[$numtariffa] == "SI")
 } # fine for $numtariffa
-if ($tutti_consentiti == "SI") for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) $app_consentito[$dati_app['posizione'][$num1]] = "SI";
 
-# Calcolo gli appartamenti consentiti dalla regola 1
-$num_app_agenzia = numlin_query($app_agenzia);
-if ($num_app_agenzia != 0 and is_array($motivazioni_regola1)) {
-for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1 = $num1 + 1) {
-$id_app_agenzia[$num1] = risul_query($app_agenzia,$num1,'app_agenzia');
-$idinizio_app_agenzia[$num1] = risul_query($app_agenzia,$num1,'iddatainizio');
-$idfine_app_agenzia[$num1] = risul_query($app_agenzia,$num1,'iddatafine');
-$motivazione_app_agenzia[$num1] = risul_query($app_agenzia,$num1,'motivazione');
-if ($motivazione_app_agenzia[$num1] == "") $motivazione_app_agenzia[$num1] = " ";
-} # fine for $num1
-$app_consentito_sett[",attivo,"] = "SI";
-for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
-for ($num2 = $id_data_inizio_tab_disp ; $num2 <= ($id_data_inizio_tab_disp + $num_colonne_tab_disp - 1) ; $num2++) {
-$app_consentito_sett[$dati_app['posizione'][$num1]][$num2] = "SI";
-} # fine for $num2
-} # fine for $num1
-for ($num1 = 0 ; $num1 < $num_app_agenzia ; $num1++) {
-if ($motivazioni_regola1[$motivazione_app_agenzia[$num1]] == "SI") {
-for ($num2 = $idinizio_app_agenzia[$num1] ; $num2 <= $idfine_app_agenzia[$num1] ; $num2++) {
-$app_consentito_sett[$id_app_agenzia[$num1]][$num2] = "NO";
-} # fine for $num2
-} # fine if ($motivazioni_regola1[$motivazione_app_agenzia[$num1]] == "SI")
-} # fine for $num1
-} # fine if ($num_app_agenzia != 0 and is_array($motivazioni_regola1))
+if ($mostra_quadro_disp == "reg2") $tar_cons = "";
+else $tar_cons = $tariffe_mostra;
+trova_app_consentiti_per_tab_disp($app_consentito,$app_consentito_sett,$quadro_non_preciso,$dati_app,$dati_tariffe,$id_data_inizio_tab_disp,$num_colonne_tab_disp,$dati_r2,'s','1',$app_agenzia,"",$tar_cons,"","","","","","",$tableregole);
 
 $righe_tab_disp = crea_quadro_disp($id_data_inizio_tab_disp,$num_colonne_tab_disp,$mostra_quadro_disp,$mostra_num_liberi,$app_consentito,$app_consentito_sett,$app_regola2_orig,$tipo_periodi,$dati_tariffe['num'],$nome_tariffa,$dati_app,$prenota_in_app_sett,$app_orig_prenota_id,$tableperiodi,$allinea_disponibilita_con_arrivo,$dati_tariffe);
 
