@@ -79,7 +79,7 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
 $template_theme_html_post[1] = "
 ";
 if (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI") $template_theme_html_post[1] .= "<small><small>Powered by 
-<a href=\"http://www.hoteldruid.com\" style=\"color: [theme_color_1];\">
+<a href=\"https://www.hoteldruid.com\" style=\"color: [theme_color_1];\">
 HotelDruid management software</a></small></small>";
 $template_theme_html_post[1] .= "</div>
 
