@@ -39,9 +39,8 @@ else {
 $nome_file = mext_rat($template_file_name['ita'],$pag,$lingua_modello);
 if ($nome_file == $template_file_name['en'] or $nome_file == $template_file_name['ita']) $nome_file = $lingua_modello."_".$template_file_name['en'];
 } # fine else if ($template_file_name[$lingua_modello])
-$SI = mex2("SI",$pag,$lingua_mex_1);
-$NO = mex2("NO",$pag,$lingua_mex_1);
 $modello_esistente = "NO";
+$lingua_mod_esist = $lingua_mex_1;
 unset($id_transazione);
 if (@is_file("$percorso_cartella_modello/$nome_file")) {
 $modello_esistente = "SI";
@@ -66,6 +65,8 @@ esegui_query("insert into $tabletransazioni (idtransazioni,idsessione,tipo_trans
 values ('$id_transazione','$id_sessione','cpweb','$anno','$modello_ext','$dati_tr2','$dati_tr3','$ultimo_accesso')");
 unlock_tabelle($tabelle_lock);
 } # fine if (@is_file("$percorso_cartella_modello/$nome_file"))
+$SI = mex2("SI",$pag,$lingua_mod_esist);
+$NO = mex2("NO",$pag,$lingua_mod_esist);
 
 
 echo "<form method=\"post\" action=\"crea_modelli.php\" enctype=\"multipart/form-data\"><div>
@@ -307,7 +308,7 @@ for ($num2 = 1 ; $num2 <= $num_valori ; $num2++) {
 $valore_corr = $valori_tema[$num2]['default'];
 if ($sel and $modello_esistente == "SI") $valore_corr = ${"valore_tema_".$num2};
 $js_opz_tema .= "".mex("Valore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
- <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"$valore_corr\">";
+ <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"".addslashes($valore_corr)."\">";
 if ($valori_tema[$num2]['img']) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
 $js_opz_tema .= "<br>";
 } # fine for $num2
