@@ -54,6 +54,65 @@ $linee_file = file("$percorso_cartella_modello/$nome_file");
 $num_linee_file = count($linee_file);
 if (substr($linee_file[0],0,70) == "<?php if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed']) { ?>") $linee_file[0] = substr($linee_file[0],70);
 if (substr($linee_file[($num_linee_file - 1)],-31) == "<?php } # fine if (!\$framed) ?>") $linee_file[($num_linee_file - 1)] = substr($linee_file[($num_linee_file - 1)],0,-31);
+
+global $prima_parte_html,$ultima_parte_html,$lingua_mex,$lingua_mod_esist;
+$lingua_mex_orig = $lingua_mex;
+$prima_parte_html = "";
+$ultima_parte_html = "";
+$linee_file_int = implode("",$linee_file);
+if (strstr($linee_file_int,"<!-- END1 ")) {
+$lingua_mod = explode("<!-- END1 ",$linee_file_int);
+if (substr($lingua_mod[1],2,1) == ":" or substr($lingua_mod[1],3,1) == ":") {
+$lingua_mod = explode(":",$lingua_mod[1]);
+$lingua_mod = strtolower($lingua_mod[0]);
+if ($lingua_mex != $lingua_mod and ($lingua_mod == "ita" or (preg_match("/[a-z]{2,2}/i",$lingua_mod) and @is_dir("./includes/lang/$lingua_mod")))) {
+$lingua_mex = $lingua_mod;
+$lingua_mod_esist = $lingua_mod;
+} # fine if ($lingua_mex != $lingua_mod and ($lingua_mod == "ita" or...
+} # fine if (substr($lingua_mod[1],2,1) == ":" or substr($lingua_mod[1],3,1) == ":")
+for ($num1 = 0 ; $num1 < $num_linee_file ; $num1++) {
+if (strstr($linee_file[$num1],"<!-- END1 ")) {
+$prima_parte_html = explode(trim($linee_file[$num1]),$linee_file_int);
+$prima_parte_html = $prima_parte_html[0];
+break;
+} # fine if (strstr($linee_file[$num1],"<!-- END1 "))
+} # fine for $num1
+} # fine if (strstr($linee_file_int,"<!-- END1 "))
+elseif (strstr($linee_file_int,"<!-- ".mex("FINE DELLA PRIMA PARTE DELL'HTML PERSONALE",$pag)."  -->")) {
+$prima_parte_html = explode("<!-- ".mex("FINE DELLA PRIMA PARTE DELL'HTML PERSONALE",$pag)."  -->",$linee_file_int);
+$prima_parte_html = $prima_parte_html[0];
+} # fine elseif (strstr($linee_file_int,"<!-- ".mex("FINE DELLA PRIMA PARTE DELL'HTML PERSONALE",$pag)."  -->"))
+if (strcmp(togli_acapo($prima_parte_html),"")) {
+while (!strcmp(togli_acapo(substr($prima_parte_html,0,1)),"")) $prima_parte_html = substr($prima_parte_html,1);
+while (!strcmp(togli_acapo(substr($prima_parte_html,-1)),"")) $prima_parte_html = substr($prima_parte_html,0,-1);
+} # fine if (togli_acapo($prima_parte_html) != "")
+if (strstr($linee_file_int,"<!-- START2:") and strstr($linee_file_int,"<!-- END2:")) {
+for ($num1 = 0 ; $num1 < $num_linee_file ; $num1++) {
+if (strstr($linee_file[$num1],"<!-- START2:")) {
+$ultima_parte_html = explode(trim($linee_file[$num1]),$linee_file_int);
+$ultima_parte_html = $ultima_parte_html[1];
+} # fine if (strstr($linee_file[$num1],"<!-- START2:"))
+if (strstr($linee_file[$num1],"<!-- END2:")) {
+if ($ultima_parte_html) {
+$ultima_parte_html = explode(trim($linee_file[$num1]),$ultima_parte_html);
+$ultima_parte_html = $ultima_parte_html[0];
+} # fine if ($ultima_parte_html)
+break;
+} # fine if (strstr($linee_file[$num1],"<!-- END2:"))
+} # fine for $num1
+} # fine if (strstr($linee_file_int,"<!-- START2:") and strstr($linee_file_int,"<!-- END2:"))
+elseif (strstr($linee_file_int,"<!-- ".mex("INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->") and strstr($linee_file_int,"<!-- ".mex("FINE DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->")) {
+$ultima_parte_html = explode("<!-- ".mex("INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->",$linee_file_int);
+$ultima_parte_html = explode("<!-- ".mex("FINE DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->",$ultima_parte_html[1]);
+$ultima_parte_html = $ultima_parte_html[0];
+} # fine elseif (strstr($linee_file_int,"<!-- ".mex("INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->") and...
+if (togli_acapo($ultima_parte_html) != "") {
+while (togli_acapo(substr($ultima_parte_html,0,1)) == "") $ultima_parte_html = substr($ultima_parte_html,1);
+while (togli_acapo(substr($ultima_parte_html,-1)) == "") $ultima_parte_html = substr($ultima_parte_html,0,-1);
+} # fine if (togli_acapo($ultima_parte_html) != "")
+unset($linee_file_int);
+unset($lingua_mod);
+
 $var_anno = "\$".mex("var_anno",$pag);
 for ($num_va = 0 ; $num_va < $num_var_mod ; $num_va++) ${"var_".$var_mod[$num_va]} = "\$".mex("var_".$var_mod[$num_va],$pag);
 $var_colore_tema = "\$".mex("var_colore_tema",$pag);
@@ -206,22 +265,6 @@ else $$variabile = str_replace("\\\"","\"",$$variabile);
 
 } # fine for $num1
 
-$linee_file = implode("",$linee_file);
-global $prima_parte_html,$ultima_parte_html;
-$prima_parte_html = explode("<!-- ".mex("FINE DELLA PRIMA PARTE DELL'HTML PERSONALE",$pag)."  -->",$linee_file);
-$prima_parte_html = $prima_parte_html[0];
-if (togli_acapo($prima_parte_html) != "") {
-while (togli_acapo(substr($prima_parte_html,0,1)) == "") $prima_parte_html = substr($prima_parte_html,1);
-while (togli_acapo(substr($prima_parte_html,-1)) == "") $prima_parte_html = substr($prima_parte_html,0,-1);
-} # fine if (togli_acapo($prima_parte_html) != "")
-$ultima_parte_html = explode("<!-- ".mex("INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->",$linee_file);
-$ultima_parte_html = explode("<!-- ".mex("FINE DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->",$ultima_parte_html[1]);
-$ultima_parte_html = $ultima_parte_html[0];
-if (togli_acapo($ultima_parte_html) != "") {
-while (togli_acapo(substr($ultima_parte_html,0,1)) == "") $ultima_parte_html = substr($ultima_parte_html,1);
-while (togli_acapo(substr($ultima_parte_html,-1)) == "") $ultima_parte_html = substr($ultima_parte_html,0,-1);
-} # fine if (togli_acapo($ultima_parte_html) != "")
-
 
 if ($var_per_crea_mod == "SI") {
 if (!$anno_modello) $anno_modello = $anno_modello_presente;
@@ -290,6 +333,7 @@ $ultima_parte_html = addslashes($ultima_parte_html);
 } # fine if ($var_per_crea_mod == "SI")
 
 
+$lingua_mex = $lingua_mex_orig;
 } # fine function recupera_var_modello_rat
 
 
@@ -300,7 +344,7 @@ $ultima_parte_html = addslashes($ultima_parte_html);
 
 function crea_modello_rat ($percorso_cartella_modello,$anno_modello,$PHPR_TAB_PRE,$pag,$lingua_modello,$silenzio,$fr_frase,$frase,$num_frasi,$tipo_periodi,$lingua_orig="") {
 global $num_periodi_date,$M_PHPR_DB_TYPE,$M_PHPR_DB_NAME,$M_PHPR_DB_HOST,$M_PHPR_DB_PORT,$M_PHPR_DB_USER,$M_PHPR_DB_PASS,$M_PHPR_LOAD_EXT,$M_PHPR_TAB_PRE,$estendi_ultima_data,$mostra_date_passate;
-global $m_stile_soldi,$m_stile_data,$anteponi_nome_valuta,$mostra_caparra,$modello_esistente,$cambia_frasi,$template_data_dir,$template_file_name,$parola_settimane,$id_utente;
+global $m_stile_soldi,$m_stile_data,$anteponi_nome_valuta,$mostra_caparra,$modello_esistente,$cambia_frasi,$template_data_dir,$template_file_name,$parola_settimane,$id_utente,$lingua_mex;
 global $apertura_tag_font,$chiusura_tag_font,$stile_tabella_tariffe,$m_valuta_sing,$m_valuta_plur,$prima_parte_html,$ultima_parte_html,$file_css_frame,$tema_modello,$id_transazione;
 $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $tableperiodi_modello = $PHPR_TAB_PRE."periodi".$anno_modello;
@@ -316,10 +360,7 @@ if (numlin_query($anno_esistente) != 1) $continua = "NO";
 } # fine else if (controlla_anno($anno_modello) != "SI")
 if ($continua != "NO") {
 
-if (!$lingua_orig) {
-global $lingua_mex;
-$lingua_orig = $lingua_mex;
-} # fine if (!$lingua_orig)
+if (!$lingua_orig) $lingua_orig = $lingua_mex;
 $SI = mex("SI",$pag);
 $NO = mex("NO",$pag);
 
@@ -509,7 +550,6 @@ $prima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$prima_parte_
 $ultima_parte_html = str_replace("[theme_value_$num1]",$valore_sost,$ultima_parte_html);
 $extra_head_frame = str_replace("[theme_value_$num1]",$valore_sost,$extra_head_frame);
 if ($valori_tema[$num1]['img'] and function_exists('upload_hd_img')) {
-global $lingua_mex;
 $lingua_mex_orig = $lingua_mex;
 $lingua_mex = $lingua_orig;
 upload_hd_img(${"valore_tema_".$num1},$num1);
@@ -572,12 +612,18 @@ $prima_parte_html = str_replace("?>","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("<%","ERROR",$prima_parte_html);
 $prima_parte_html = str_replace("%>","ERROR",$prima_parte_html);
 $prima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$prima_parte_html);
+$prima_parte_html = str_replace("<!-- END1 ","<!-- ED1 ",$prima_parte_html);
+$prima_parte_html = str_replace("<!-- START2:","<!-- ST2:",$prima_parte_html);
+$prima_parte_html = str_replace("<!-- END2:","<!-- ED2:",$prima_parte_html);
 if (@get_magic_quotes_gpc()) $ultima_parte_html = stripslashes($ultima_parte_html);
 $ultima_parte_html = str_replace("<?","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("?>","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("<%","ERROR",$ultima_parte_html);
 $ultima_parte_html = str_replace("%>","ERROR",$ultima_parte_html);
 $ultima_parte_html = preg_replace("/<script[^>]*php.*>/i","ERROR",$ultima_parte_html);
+$ultima_parte_html = str_replace("<!-- END1 ","<!-- ED1 ",$ultima_parte_html);
+$ultima_parte_html = str_replace("<!-- START2:","<!-- ST2:",$ultima_parte_html);
+$ultima_parte_html = str_replace("<!-- END2:","<!-- ED2:",$ultima_parte_html);
 # FRASI
 if ($cambia_frasi == "SI" or $modello_esistente == "SI") {
 for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) {
@@ -624,7 +670,7 @@ fwrite($file,"<?php if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed'
 
 
 
-<!-- ".mex("FINE DELLA PRIMA PARTE DELL'HTML PERSONALE",$pag)."  -->
+<!-- END1 ".strtoupper($lingua_mex).": ".mex("FINE DELLA PRIMA PARTE DELL'HTML PERSONALE",$pag)."  -->
 
 
 <?php
@@ -830,13 +876,13 @@ if (!\$framed) {
 ?>
 
 
-<!-- ".mex("INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->
+<!-- START2: ".mex("INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  -->
 
 
 
 
 $ultima_parte_html
-<!-- ".mex("FINE DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  --><?php } # fine if (!\$framed) ?>");
+<!-- END2: ".mex("FINE DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  --><?php } # fine if (!\$framed) ?>");
 flock($file,3);
 fclose($file);
 $exec_crea_mod = substr(decoct(@fileperms('./crea_modelli.php')),-3,1);
@@ -857,29 +903,7 @@ if ($silenzio == "NO") {
 if (defined("C_CARTELLA_CREA_MODELLI")) echo mex2("Si può creare un link verso questa pagina dal proprio sito internet",$pag,$lingua_orig).".<br>";
 else echo mex2("Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"",$pag,$lingua_orig).".<br>";
 
-if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI")) {
-$altri_domini = @file(C_FILE_DOMINIO);
-if ($altri_domini) {
-if (defined("C_CARTELLA_CREA_MODELLI") and C_CARTELLA_CREA_MODELLI != "") $percorso_cartella_dominio = substr($percorso_cartella_modello,strlen(C_CARTELLA_CREA_MODELLI));
-else $percorso_cartella_dominio = $percorso_cartella_modello;
-if (substr($percorso_cartella_dominio,0,1) == "/") $percorso_cartella_dominio = substr($percorso_cartella_dominio,1);
-if (strcmp($percorso_cartella_dominio,"") and substr($percorso_cartella_dominio,-1) != "/") $percorso_cartella_dominio .= "/";
-if (substr($percorso_cartella_dominio,0,2) == "./") $percorso_cartella_dominio = substr($percorso_cartella_dominio,2);
-$lista_altri_domini = "";
-$num_altri_domini = count($altri_domini);
-for ($num1 = 0 ; $num1 < $num_altri_domini ; $num1++) {
-if ($num1 == 0) $altro_dominio = "https://";
-else $altro_dominio = "http://";
-$altro_dominio .= trim($altri_domini[$num1])."/$percorso_cartella_dominio$nome_file";
-if ($altro_dominio != $url_pagina_link) {
-$lista_altri_domini .= "<b><a href=\"$altro_dominio\" target=\"_blank\">$altro_dominio</a></b>";
-if ($num1 == 0) $lista_altri_domini .= " (".mex2("sicuro",$pag,$lingua_orig).")";
-$lista_altri_domini .= "<br>";
-} # fine if ($altro_dominio != $url_pagina_link)
-} # fine for $num1
-if ($lista_altri_domini) echo "<br><br>".mex2("Indirizzi alternativi da cui la pagina è raggiungibile",$pag,$lingua_orig).":<br><div class=\"linhbox\">$lista_altri_domini</div>";
-} # fine if ($altri_domini)
-} # fine if (defined("C_FILE_DOMINIO") and C_FILE_DOMINIO != "" and (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI"))
+mostra_indirizzi_alernativi($percorso_cartella_modello,$nome_file,$url_pagina,$url_pagina_link,$pag,$lingua_orig);
 
 echo "<br>";
 } # fine if ($silenzio == "NO")
@@ -908,12 +932,12 @@ $fineperiodo = aggslashdb(${"fineperiodo".$num1});
 $idinizioperiodo = esegui_query("select idperiodi from $tableperiodi_prec where datainizio = '$inizioperiodo' ");
 $num_idinizioperiodo = numlin_query($idinizioperiodo);
 if ($num_idinizioperiodo == 0) { $idinizioperiodo = 10000; }
-else { $idinizioperiodo = risul_query($idinizioperiodo,0,idperiodi); }
+else { $idinizioperiodo = risul_query($idinizioperiodo,0,'idperiodi'); }
 $inizioperiodo = $idinizioperiodo;
 $idfineperiodo = esegui_query("select idperiodi from $tableperiodi_prec where datafine = '$fineperiodo' ");
 $num_idfineperiodo = numlin_query($idfineperiodo);
 if ($num_idfineperiodo == 0) { $idfineperiodo = -1; }
-else { $idfineperiodo = risul_query($idfineperiodo,0,idperiodi); }
+else { $idfineperiodo = risul_query($idfineperiodo,0,'idperiodi'); }
 $fineperiodo = $idfineperiodo;
 $intervalloperiodo = aggslashdb(${"intervalloperiodo".$num1});
 if ($estendi_ultima_data == "SI" and $num1 == ($num_periodi_date - 1)) $fineperiodo = $id_data_ini_periodi_prec + $intervalloperiodo;
@@ -949,7 +973,7 @@ for ($num1 = 0 ; $num1 < 2000 ; $num1++) {
 $datainizio = date("Y-m-d",mktime(0,0,0,$mese_inizio,$giorno_inizio,$anno_inizio));
 $datainizio = esegui_query("select * from $tableperiodi where datainizio = '$datainizio'");
 if (numlin_query($datainizio) == 1) {
-$n_inizioperiodo[0] = risul_query($datainizio,0,idperiodi);
+$n_inizioperiodo[0] = risul_query($datainizio,0,'idperiodi');
 break;
 } # fine if (numlin_query($datainizio) == 1)
 $giorno_inizio = $giorno_inizio + ($n_intervalloperiodo[0] * $aggiungi_giorni);
