@@ -127,8 +127,8 @@ return $messaggio;
 
 
 
-$fr_frase = "";
-$frase = "";
+$fr_frase = array();
+$frase = array();
 
 $fr_frase[0] = "fr_dal";
 $fr_frase[1] = "fr_al";
