@@ -189,7 +189,7 @@ $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($pe
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]."p");
 if ($dati_r2['napp'][$tariffa[$num1]] > 1) {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = $tariffa_colonna_periodo[$num1][$num_colonne_periodi] * (double) $dati_r2['napp'][$tariffa[$num1]];
-$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = $tariffap_colonna_periodo[$num1][$num_colonne_periodi] * (double) $dati_r2['napp'][$tariffa[$num1]];
+#$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = $tariffap_colonna_periodo[$num1][$num_colonne_periodi] * (double) $dati_r2['napp'][$tariffa[$num1]];
 } # fine if ($dati_r2['napp'][$tariffa[$num1]] > 1)
 if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)]) {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = "c";
@@ -201,7 +201,7 @@ $tar_corr = (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$
 $tarp_corr = (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]."p");
 if ($dati_r2['napp'][$tariffa[$num1]] > 1) {
 $tar_corr = $tar_corr * (double) $dati_r2['napp'][$tariffa[$num1]];
-$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num1]];
+#$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num1]];
 } # fine if ($dati_r2['napp'][$tariffa[$num1]] > 1)
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] += $tar_corr;
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] += $tarp_corr;
@@ -221,7 +221,7 @@ ${$tariffa[$num2]} = (double) risul_query($periodi,$num1,$tariffa[$num2]);
 ${$tariffa[$num2]."p"} = (double) risul_query($periodi,$num1,$tariffa[$num2]."p");
 if ($dati_r2['napp'][$tariffa[$num2]] > 1) {
 ${$tariffa[$num2]} = ${$tariffa[$num2]} * (double) $dati_r2['napp'][$tariffa[$num2]];
-${$tariffa[$num2]."p"} = ${$tariffa[$num2]."p"} * (double) $dati_r2['napp'][$tariffa[$num2]];
+#${$tariffa[$num2]."p"} = ${$tariffa[$num2]."p"} * (double) $dati_r2['napp'][$tariffa[$num2]];
 } # fine if ($dati_r2['napp'][$tariffa[$num2]] > 1)
 if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)]) {
 ${$tariffa[$num2]} = "c";
@@ -233,7 +233,7 @@ $tar_corr = (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]);
 $tarp_corr = (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]."p");
 if ($dati_r2['napp'][$tariffa[$num2]] > 1) {
 $tar_corr = $tar_corr * (double) $dati_r2['napp'][$tariffa[$num2]];
-$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num2]];
+#$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num2]];
 } # fine if ($dati_r2['napp'][$tariffa[$num2]] > 1)
 ${$tariffa[$num2]} += $tar_corr;
 ${$tariffa[$num2]."p"} += $tarp_corr;
