@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -31,14 +31,14 @@ include("./includes/funzioni.php");
 
 unset($numconnessione);
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
-if ($id_utente and $numconnessione and $logout == "SI") {
+if ($id_utente and $numconnessione and isset($logout)) {
 $tabelle_lock = array($PHPR_TAB_PRE."sessioni");
 $tabelle_lock = lock_tabelle($tabelle_lock);
 esegui_query("delete from $PHPR_TAB_PRE"."sessioni where idsessioni = '$id_sessione'");
 unlock_tabelle($tabelle_lock);
 unset($id_sessione);
 $id_utente = controlla_login($numconnessione,$PHPR_TAB_PRE,$id_sessione,$nome_utente_phpr,$password_phpr,$anno);
-} # fine if ($id_utente and $numconnessione and $logout == "SI")
+} # fine if ($id_utente and $numconnessione and isset($logout))
 if ($id_utente) {
 
 
@@ -68,7 +68,7 @@ break;
 if (@is_file("./COPYING")) $file_copying = "file <a href=\"COPYING\">COPYING</a>";
 else $file_copying = "<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\">AGPLv3</a> License";
 echo "<div style=\"text-align: center;\"><h3>".mex("Benvenuto a HOTELDRUID",$pag).".</h3><br><br>
-HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2019 Marco M. F. De Santis<br>
+HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2020 Marco M. F. De Santis<br>
 HotelDruid comes with ABSOLUTELY NO WARRANTY; <br>for details see the $file_copying.<br>
 This is free software, and you are welcome to redistribute it<br>
  under certain conditions; see the $file_copying for details.<br>
@@ -330,7 +330,7 @@ echo "<div class=\"logout\">".mex("Utente",$pag).": $nome_utente_login".".
 
 $anno_succ = $anno + 1;
 echo "<br><div style=\"text-align: center;\"><h3 id=\"h_mm\"><span>".mex("Menù principale dell'anno",$pag)." $anno";
-if ($commento_subordinazione) echo " ($commento_subordinazione)";
+if (isset($commento_subordinazione)) echo " ($commento_subordinazione)";
 echo "</span></h3><div id=\"mm_sub0\"></div>";
 if ($priv_ins_nuove_prenota == "s") {
 echo "<table class=\"ires\" cellspacing=0 cellpadding=0>
@@ -505,16 +505,16 @@ $tableclienti = $PHPR_TAB_PRE."clienti";
 $tableanni = $PHPR_TAB_PRE."anni";
 
 if ($id_utente == 1) {
-if ($canc_mess_periodi) {
+if (isset($canc_mess_periodi)) {
 $tabelle_lock = array($tablepersonalizza);
 $altre_tab_lock = array($tableanni,$tableperiodi);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
-} # fine if ($canc_mess_periodi)
+} # fine if (isset($canc_mess_periodi))
 else {
 $tabelle_lock = "";
 $altre_tab_lock = array($tableanni,$tableperiodi,$tablepersonalizza);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
-} # fine else if ($canc_mess_periodi)
+} # fine else if (isset($canc_mess_periodi))
 $mesi_avviso = 4;
 $limite_avviso_date = date("Y-m-d",mktime(0,0,0,((int) date("m") + $mesi_avviso),date("d"),date("Y")));
 $limite_avviso_date = esegui_query("select * from $tableperiodi where datafine > '$limite_avviso_date' limit 1 ");
@@ -523,7 +523,7 @@ $anni_succ = esegui_query("select * from $tableanni where idanni > '$anno' ");
 if (!numlin_query($anni_succ)) {
 $visto = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'visto_messaggio_periodi' and idutente = '$id_utente' ");
 if (!numlin_query($visto)) {
-if ($canc_mess_periodi) esegui_query("insert into $tablepersonalizza (idpersonalizza,valpersonalizza,idutente) values ('visto_messaggio_periodi','1','$id_utente')");
+if (isset($canc_mess_periodi)) esegui_query("insert into $tablepersonalizza (idpersonalizza,valpersonalizza,idutente) values ('visto_messaggio_periodi','1','$id_utente')");
 else {
 echo "<b class=\"colwarn\">".mex("Avviso",$pag)."</b>: ".mex("nel database sono ancora disponibili periodi solo per meno di",$pag)." $mesi_avviso ".mex("mesi",$pag).".
 <table style=\"margin-left: auto; margin-right: auto; margin-top: 6px;\"><tr><td>
@@ -542,7 +542,7 @@ echo "<b class=\"colwarn\">".mex("Avviso",$pag)."</b>: ".mex("nel database sono
 <button class=\"amon\" type=\"submit\"><div>".mex("Aggiungi periodi","visualizza_tabelle.php")."</div></button>
 </div></form></td></tr></table>
 <div class=\"mm_sub7\"></div><hr style=\"width: 95%;\">";
-} # fine else if ($canc_mess_periodi) 
+} # fine else if (isset($canc_mess_periodi))
 } # fine if (!numlin_query($visto))
 } # fine if (!numlin_query($anni_succ))
 } # fine if (!numlin_query($limite_avviso_date))
@@ -667,12 +667,12 @@ if ($priv_mod_prenotazioni == "n") $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "p" and $utente_inserimento_prenota != $id_utente) $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "g" and !$utenti_gruppi[$utente_inserimento_prenota]) $link_modifica = "NO";
 if ($priv_mod_prenota_iniziate != "s" and $id_periodo_corrente >= $id_data_inizio) $link_modifica = "NO";
-if ($priv_mod_prenota_ore != "000") {
+if ($priv_mod_prenota_ore != "000" and controlla_num_pos($priv_mod_prenota_ore) == "SI") {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
 $data_ins = risul_query($prenotazioni,$num1,'datainserimento');
 $limite = date("YmdHis",mktime((substr($data_ins,11,2) + $priv_mod_prenota_ore),substr($data_ins,14,2),substr($data_ins,17,2),substr($data_ins,5,2),substr($data_ins,8,2),substr($data_ins,0,4)));
 if ($adesso > $limite) $link_modifica = "NO";
-} # fine if ($priv_mod_prenota_ore != "000")
+} # fine if ($priv_mod_prenota_ore != "000" and controlla_num_pos($priv_mod_prenota_ore) == "SI")
 $checkin = risul_query($prenotazioni,$num1,'checkin');
 $checkout = risul_query($prenotazioni,$num1,'checkout');
 if ($checkout and !$checkin) {
@@ -703,7 +703,7 @@ else echo "&nbsp;/&nbsp;<span class=\"smlscr\"> </span>";
 echo "$data_fine_f</td>
 <td$class_opt>$costo_tot_p</td>
 <td";
-if ($colore) echo " style=\"background-color: $colore;\"";
+if ($colore) echo " style=\"background-color: $colore; background-image: none;\"";
 echo ">$da_pagare_p</td>";
 if (strlen($appartamento) > 6) echo "<td><small>$appartamento</small></td>";
 else echo "<td>$appartamento</td>";
