@@ -307,6 +307,17 @@ echo $testo;
 } # fine if ($modello_ext != "." and $modello_ext != ".." and...
 } # fine while ($mod_ext = readdir($interconn_dir))
 closedir($interconn_dir);
+
+if ($agg_disp or $agg_tar) {
+$lock = 1;
+if ($agg_disp) $aggiorna_disp = 1;
+else $aggiorna_disp = 0;
+if ($agg_tar) $aggiorna_tar = 1;
+else $aggiorna_tar = 0;
+if (@function_exists('pcntl_fork')) include("./includes/interconnect/aggiorna_ic_fork.php");
+else include("./includes/interconnect/aggiorna_ic.php");
+} # fine if ($agg_disp or $agg_tar)
+
 } # fine if (@is_array($ic_present))
 } # fine if (@is_file($file_interconnessioni))
 } # fine if ($id_utente_azione_ic)
