@@ -682,7 +682,20 @@ unlock_tabelle($tabelle_lock);
 
 # Form per modificare l'inventario.
 if ($mostra_form_inventario != "NO") {
-if ($tipoid == "idappartamento") echo "<h3 id=\"h_stkr\"></span>".mex("Inventario dell'appartamento",'unit.php')." <b>$nome_mag</b>.</span></h3><br>";
+
+$ordine_inventario = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'ordine_inventario' and idutente = '$id_utente' ");
+$ordine_inventario = risul_query($ordine_inventario,0,'valpersonalizza');
+if ($ordine_inventario == "ins") $ordine_inventario = "idbeniinventario";
+else $ordine_inventario = "nome_bene";
+
+if ($ordine_inventario == "idbeniinventario") $beni_in_mag = esegui_query("select * from $tablerelinventario where $tipoid = '$idmag' order by idbeneinventario ");
+else $beni_in_mag = esegui_query("select * from $tablerelinventario left outer join $tablebeniinventario on $tablerelinventario.idbeneinventario = $tablebeniinventario.idbeniinventario where $tablerelinventario.$tipoid = '$idmag' order by $tablebeniinventario.nome_bene ");
+$num_beni_in_mag = numlin_query($beni_in_mag);
+$beni_inv = esegui_query("select * from $tablebeniinventario $condizione_beni_propri order by $ordine_inventario");
+$num_beni_inv = numlin_query($beni_inv);
+if ($priv_vedi_beni_inv == "n") $num_beni_inv = 0;
+
+if ($tipoid == "idappartamento") echo "<h3 id=\"h_stkr\"><span>".mex("Inventario dell'appartamento",'unit.php')." <b>$nome_mag</b>.</span></h3><br>";
 else echo "<h3 id=\"h_stkr\"><span>".mex("Inventario del magazzino",$pag)." $nome_mag.</span></h3><br>";
 if ($frase_modifica) echo "$frase_modifica<div style=\"height: 5px;\"></div>";
 
@@ -712,39 +725,29 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#tab_inventari
 <input type=\"hidden\" name=\"idmag\" value=\"$idmag_orig\">
 <input type=\"hidden\" name=\"aggiorna_inventario\" value=\"SI\">
 <input type=\"hidden\" name=\"manda_form_tab\" value=\"SI\">
-<table class=\"t1\" style=\"background-color: $t1color; margin-left: auto; margin-right: auto;\" width=3 border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
+<div class=\"tab_cont\">
+<table class=\"t1 t1color\" style=\"margin-left: auto; margin-right: auto;\" width=3 border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
 <tr><td>".mex("Nome bene",$pag)."</td>
-<td style=\"line-height: 70%\"><small><small>".mex("Quantità minima predefinita",$pag)."</small></small></td>
-<td><small>".mex("Quantità attuale",$pag)."</small></td>";
+<td class=\"t1top\" style=\"line-height: 70%\"><small><small>".mex("Quantità minima predefinita",$pag)."</small></small></td>
+<td class=\"t1top\"><small>".mex("Quantità attuale",$pag)."</small></td>";
 if ($priv_mod_beni != "n") {
-echo "<td><select id=\"ti_nq\" class=\"smallsel85\" name=\"tipo_nuova_quantita\" onchange=\"simb_tipo_quant();\">
+echo "<td class=\"t1top\"><select id=\"ti_nq\" class=\"smallsel85\" name=\"tipo_nuova_quantita\" onchange=\"simb_tipo_quant();\">
 <option value=\"nq\" selected>".mex("Nuova quantità",$pag)."</option>
 <option value=\"piu\">".mex("Aggiungi",$pag)."</option>
 <option value=\"meno\">".mex("Sottrai",$pag)."</option>
 </select></td>";
 } # fine if ($priv_mod_beni != "n")
+$attiva_checkin = "";
 if ($priv_ins_beni != "n" or $priv_mod_beni != "n") {
 if ($tipoid == "idappartamento" or $priv_mod_checkin != "s") {
 $attiva_checkin = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'attiva_checkin' and idutente = '$id_utente'");
 $attiva_checkin = risul_query($attiva_checkin,0,'valpersonalizza');
-if ($attiva_checkin == "SI") echo "<td style=\"line-height: 70%\"><small><small>".str_replace("_","&nbsp;",mex("richiesto_per registrare entrata",$pag))."</small></small></td>";
+if ($attiva_checkin == "SI") echo "<td class=\"t1top\" style=\"line-height: 70%\"><small><small>".str_replace("_","&nbsp;",mex("richiesto_per registrare entrata",$pag))."</small></small></td>";
 } # fine if ($tipoid == "idappartamento" or $priv_mod_checkin != "s")
-echo "<td>".mex("Modifica",$pag)."</td>";
+echo "<td class=\"t1top\">".mex("Modifica",$pag)."</td>";
 } # fine if ($priv_ins_beni != "n" or $priv_mod_beni != "n")
 echo "</tr>";
 
-$ordine_inventario = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'ordine_inventario' and idutente = '$id_utente' ");
-$ordine_inventario = risul_query($ordine_inventario,0,'valpersonalizza');
-if ($ordine_inventario == "ins") $ordine_inventario = "idbeniinventario";
-else $ordine_inventario = "nome_bene";
-
-if ($ordine_inventario == "idbeniinventario") $beni_in_mag = esegui_query("select * from $tablerelinventario where $tipoid = '$idmag' order by idbeneinventario ");
-else $beni_in_mag = esegui_query("select * from $tablerelinventario left outer join $tablebeniinventario on $tablerelinventario.idbeneinventario = $tablebeniinventario.idbeniinventario where $tablerelinventario.$tipoid = '$idmag' order by $tablebeniinventario.nome_bene ");
-$num_beni_in_mag = numlin_query($beni_in_mag);
-$beni_inv = esegui_query("select * from $tablebeniinventario $condizione_beni_propri order by $ordine_inventario");
-$num_beni_inv = numlin_query($beni_inv);
-if ($priv_vedi_beni_inv == "n") $num_beni_inv = 0;
-
 unset($nomi_beni);
 unset($codici_beni);
 unset($bene_permesso);
@@ -779,7 +782,7 @@ $diff = "<small><small> ($diff)</small></small>";
 } # fine else if (!$diff)
 if ($aggiungi_bene and ($num1 == ($num_beni_inv - 12) or ($num1 == 0 and ($num_beni_inv - 12) < 0))) $anchor = "<a name=\"tab_inventario\"></a>";
 else $anchor = "";
-echo "<tr><td>$anchor$nome_bene</td>
+echo "<tr><td class=\"t1left\">$anchor$nome_bene</td>
 <td>$quantita_min_predef</td>
 <td$colore>$quantita$diff</td>";
 if ($priv_mod_beni != "n") echo "<td><span class=\"simb_nq\"></span><input type=\"text\" name=\"n_quantita$id_bene_in_mag\" size=\"5\"></td>";
@@ -817,7 +820,7 @@ echo "<tr><td><select name=\"n_id\">$opt_beni</select></td>
 <td><input type=\"text\" name=\"n_quantita\" size=\"5\"$autofocus></td>";
 if ($priv_ins_costi_agg != "n") {
 echo "<td><small style=\"white-space: nowrap;\"><label><input type=\"checkbox\" name=\"crea_ca\" value=\"1\" style=\"width: 14px; height: 12px;\">";
-echo "".mex("crea un <em>costo aggiuntivo</em>",$pag)."<br> ".mex("per il punto vendita",$pag).".</label></td>";
+echo "".mex("crea un <em>costo aggiuntivo</em>",$pag)."<br> ".mex("per il punto vendita",$pag).".</label></small></td>";
 } # fine if ($priv_ins_costi_agg != "n")
 else echo "<td>&nbsp;</td>";
 if ($attiva_checkin == "SI") {
@@ -829,15 +832,15 @@ echo "<td><select name=\"ric_checkin\">
 echo "<td><button class=\"plum\" type=\"submit\" name=\"aggiungi_bene\" value=\"1\"><div>".mex("aggiungi",$pag)."</div></button></td></tr>";
 } # fine if ($opt_beni and $priv_ins_beni != "n")
 
-if ($num_beni_in_mag > 15) {
+if ($num_beni_in_mag > 40 or ($mobile_device and $num_beni_in_mag > 20)) {
 $id_modi = " id=\"modi\"";
-$id_indi = " id=\"indi\"";
-} # fine if ($num_beni_in_mag > 15)
+$a_bottom = "<a id=\"bott\" name=\"bottom\"><span style=\"display: none;\">".mex("Vai a fondo pagina",$pag)."</span></a>";
+} # fine if ($num_beni_in_mag > 40 or ($mobile_device and $num_beni_in_mag > 20))
 else {
 $id_modi = "";
-$id_indi = "";
+$a_bottom = "";
 } # fine else if ($num_beni_in_mag > 15)
-echo "</table><br><div style=\"text-align: center;\">";
+echo "</table></div><br><div style=\"text-align: center;\">";
 if ($priv_mod_beni != "n") echo "<button$id_modi class=\"ainv\" type=\"submit\" name=\"modifica_quantita\" value=\"".mex("Modifica le quantità attuali",$pag)."\"><div>".mex("Modifica le quantità attuali",$pag)."</div></button>";
 echo "</div></div></form>
 $frase_modifica<br>";
@@ -849,8 +852,8 @@ echo "<hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"tipo_tabella\" value=\"$tipo_tabella\">";
 if ($origine_vecchia) echo "<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine_vecchia)."\">";
-echo "<button$id_indi class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
-</div></form><br></div>";
+echo "<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
+</div></form><br>$a_bottom</div>";
 
 } # fine if ($mostra_form_inventario != "NO")
 
