@@ -138,7 +138,7 @@ $prenota_presenti = esegui_query("select * from $tableprenota_controlla where id
 $num_prenota_presenti = numlin_query($prenota_presenti);
 if ($num_prenota_presenti != 0) {
 $cancellare = "NO";
-echo mex("L'appartamento",'unit.php')." $idappartamenti ".mex("contiene prenotazione future, non si può cancellare",$pag).".<br>";
+echo "<br>".mex("L'appartamento",'unit.php')." $idappartamenti ".mex("contiene prenotazione future, non si può cancellare",$pag).".<br><br>";
 break;
 } # fine if ($num_prenota_presenti != 0)
 } # fine for $num1
@@ -146,10 +146,17 @@ break;
 $app_esiste = esegui_query("select * from $tableappartamenti where idappartamenti = '".aggslashdb($idappartamenti)."'");
 $num_app_esiste = numlin_query($app_esiste);
 if ($num_app_esiste != 1) {
-echo mex("L'appartamento",'unit.php')." $idappartamenti ".mex("è già stato cancellato",'unit.php').".<br>";
+echo "<br>".mex("L'appartamento",'unit.php')." $idappartamenti ".mex("è già stato cancellato",'unit.php').".<br><br>";
 $cancellare = "NO";
 } # fine if ($num_app_esiste != 1)
 
+$ultimo_app = esegui_query("select idappartamenti from $tableappartamenti ");
+$num_app_esiste = numlin_query($app_esiste);
+if ($num_app_esiste == 1) {
+echo "<br>".mex("Rimane solo",$pag)." ".mex("un appartamento",'unit.php').".<br><br>";
+$cancellare = "NO";
+} # fine if ($num_app_esiste == 1)
+
 if ($cancellare != "NO") {
 if ($cancella_sicuro != "SI") {
 echo mex("Sei sicuro di voler <b>cancellare</b> l'appartamento",'unit.php')." <b>$idappartamenti</b>?<br>
