@@ -1421,7 +1421,7 @@ if ($multilingua) echo "<input type=\"hidden\" name=\"lingua_contr\" value=\"".$
 echo "<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
 <input type=\"hidden\" name=\"pos_curs\" value=\"\" id=\"pos_curs$num_lingua\">
 <input type=\"hidden\" name=\"pos_fine_sel\" value=\"\" id=\"pos_fine_sel$num_lingua\">
-<table style=\"margin-left: auto; margin-right: auto;\">";
+<table class=\"nomob\" style=\"margin-left: auto; margin-right: auto;\">";
 $linea_mod = "<tr><td><a name=\"contr_txtbox".$lingue[$num_lingua]."\"></a>
 ".mex("Variabili",$pag).":
  <select name=\"var_agg\">";
@@ -1495,8 +1495,10 @@ $option_array
 if ($tipo_contratto == "rtf" or $tipo_contratto == "txt") $wrap = "wrap=\"off\"";
 else $wrap = "style=\"white-space: pre; overflow: auto;\"";
 # htmlspecialchars su $testo_contratto necessario perchè altrimenti per esempio &nbsp; diventa uno spazio all'interno della textarea
+if (!$mobile_device) $rows = "120";
+else $rows = "70";
 echo "$linea_mod<tr><td colspan=\"5\" align=\"center\">
-<textarea id=\"contr_txta$num_lingua\" name=\"n_contratto\" rows=120 cols=135 $wrap>".htmlspecialchars($testo_contratto)."</textarea></td></tr>";
+<textarea id=\"contr_txta$num_lingua\" name=\"n_contratto\" rows=$rows cols=135 $wrap>".htmlspecialchars($testo_contratto)."</textarea></td></tr>";
 $linea_mod = str_replace("<a name=\"contr_txtbox".$lingue[$num_lingua]."\"></a>","",$linea_mod);
 $linea_mod = str_replace("<select name=\"var_agg\">","<select name=\"var_agg2\">",$linea_mod);
 $linea_mod = str_replace("type=\"submit\" name=\"aggiungi_var\"","type=\"submit\" name=\"aggiungi_var2\"",$linea_mod);
@@ -1526,8 +1528,10 @@ var width = Math.round(document.body.clientWidth - 60);
 if (height < 300) height = 300;
 if (width < 300) width = 300;
 for (n1 = 0 ; n1 < $num_lingua ; n1++) {
-document.getElementById('contr_txta'+n1).style.height = height + 'px';
-document.getElementById('contr_txta'+n1).style.width = width + 'px';
+";
+if (!$mobile_device) echo "document.getElementById('contr_txta'+n1).style.height = height + 'px';
+";
+echo "document.getElementById('contr_txta'+n1).style.width = width + 'px';
 }
 ";
 if ($contr_head) {
