@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,7 @@
 ##################################################################################
 
 $pag = "modifica_ospiti.php";
-$titolo = "HotelDruid: Modifica Ospiti Prenotazione";
+$titolo = "HotelDruid: Modifica Ospiti";
 
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
@@ -186,6 +186,7 @@ $idclienti_idpr[$id_prenota] = $idclienti;
 if ($modifica_clienti != "NO" and $vedi_clienti != "NO") {
 
 
+$titolo = "HotelDruid: ".mex("Modifica Ospiti",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 
@@ -347,7 +348,9 @@ $telefono2__aux = ${"telefono2_".$id_prenota."_".$num1};
 $telefono3__aux = ${"telefono3_".$id_prenota."_".$num1};
 $fax_aux = ${"fax".$id_prenota."_".$num1};
 $email_aux = ${"email".$id_prenota."_".$num1};
-$id_clienti_ins = inserisci_dati_cliente($cognome_aux,$nome_aux,"",$titolo_cli_aux,$sesso_aux,$mesenascita_aux,$giornonascita_aux,$annonascita_aux,$nazionenascita_aux,$cittanascita_aux,$regionenascita_aux,$documento_aux,$tipodoc_aux,$mesescaddoc_aux,$giornoscaddoc_aux,$annoscaddoc_aux,$cittadoc_aux,$regionedoc_aux,$nazionedoc_aux,$nazionalita_aux,$lingua_cli_aux,$nazione_aux,$citta_aux,$regione_aux,$via_aux,$nomevia_aux,$numcivico_aux,$cap_aux,$telefono__aux,$telefono2__aux,$telefono3__aux,$fax_aux,$email_aux,"","",($num_ospiti_inviati + 1),$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti);
+$email2_aux = ${"email2".$id_prenota."_".$num1};
+$email_cert_aux = ${"email_cert".$id_prenota."_".$num1};
+$id_clienti_ins = inserisci_dati_cliente($cognome_aux,$nome_aux,"",$titolo_cli_aux,$sesso_aux,$mesenascita_aux,$giornonascita_aux,$annonascita_aux,$nazionenascita_aux,$cittanascita_aux,$regionenascita_aux,$documento_aux,$tipodoc_aux,$mesescaddoc_aux,$giornoscaddoc_aux,$annoscaddoc_aux,$cittadoc_aux,$regionedoc_aux,$nazionedoc_aux,$nazionalita_aux,$lingua_cli_aux,$nazione_aux,$citta_aux,$regione_aux,$via_aux,$nomevia_aux,$numcivico_aux,$cap_aux,$telefono__aux,$telefono2__aux,$telefono3__aux,$fax_aux,$email_aux,$email2_aux,$email_cert_aux,"","",($num_ospiti_inviati + 1),$id_utente_ins,$attiva_prefisso_clienti,$prefisso_clienti);
 $num_ospiti++;
 $lista_ospiti[$num_ospiti] = $id_clienti_ins;
 $n_parentela[$num_ospiti] = ${"parentela".$id_prenota."_".$num1};
@@ -455,7 +458,7 @@ $dati_cliente = esegui_query("select * from $tableclienti where idclienti = '$id
 echo "".mex("Cliente titolare",$pag);
 if ($num_id_prenota > 1) echo " ".mex("della prenotazione",$pag)." <b>$id_prenota</b>";
 echo ":<br>";
-mostra_dati_cliente($dati_cliente,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dnazione,$dlingua_cli,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti);
+mostra_dati_cliente($dati_cliente,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dnazione,$dlingua_cli,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$demail2,$demail_cert,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti);
 $cognome_def = $dcognome;
 if ($dnazionalita) $nazione_def = $dnazionalita;
 elseif ($dnazione) $nazione_def = $dnazione;
@@ -503,7 +506,7 @@ if (($modifica_clienti == "PROPRI" and $utente_ospite != $id_utente) or ($modifi
 else echo "<br><a$stile href=\"$url_mod_cli\">".($num1 + $agg_num).".</a>";
 echo " <label><input name=\"ospite$id_prenota"."_".$id_clienti_osp."\" value=\"SI\" type=\"checkbox\" checked>";
 if (($vedi_clienti == "PROPRI" and $utente_ospite != $id_utente) or ($vedi_clienti == "GRUPPI" and !$utenti_gruppi[$utente_ospite])) echo "".mex("Cliente",$pag)." $id_clienti_osp";
-else mostra_dati_cliente($dati_ospite,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dlingua_cli,$dnazione,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti);
+else mostra_dati_cliente($dati_ospite,$dcognome,$dnome,$dsoprannome,$dtitolo_cli,$dsesso,$ddatanascita,$ddatanascita_f,$dnazionenascita,$dcittanascita,$dregionenascita,$ddocumento,$dscadenzadoc,$dscadenzadoc_f,$dtipodoc,$dnazionedoc,$dregionedoc,$dcittadoc,$dnazionalita,$dlingua_cli,$dnazione,$dregione,$dcitta,$dvia,$dnumcivico,$dtelefono,$dtelefono2,$dtelefono3,$dfax,$dcap,$demail,$demail2,$demail_cert,$dcod_fiscale,$dpartita_iva,"",$priv_ins_clienti);
 echo "</label>";
 if ($num1 == 0) {
 $checked = " checked";
