@@ -170,6 +170,7 @@ $n_arr_pers_el = $n_arr_pers_el[0]."(".$n_arr_pers_el[1].")";
 $arr_pers_el = "a".$arr_pers_elimina;
 $condizioni = esegui_query("select * from $tablecontratti where tipo $LIKE 'cond%' order by numero");
 $num_condizioni = numlin_query($condizioni);
+$num_cond_canc = 0;
 for ($num1 = 0 ; $num1 < $num_condizioni ; $num1++) {
 $condizione = risul_query($condizioni,$num1,'testo');
 $condizione = explode("#@?",$condizione);
@@ -195,10 +196,12 @@ if ($elimina_cond_corr == "SI") {
 $num_cond = risul_query($condizioni,$num1,'numero');
 $tipo_cond = risul_query($condizioni,$num1,'tipo');
 esegui_query("delete from $tablecontratti where numero = '$num_cond' and tipo = '$tipo_cond' ");
+$num_cond_canc++;
 } # fine ($elimina_cond_corr == "SI")
 } # fine for $num1
 esegui_query("delete from $tablecontratti where numero = '$arr_pers_elimina' and tipo $LIKE 'vett%'");
-echo mex("Array personalizzato eliminato",$pag).".<br>";
+if ($num_cond_canc) echo mex("Condizioni eliminate",$pag).": <em>$num_cond_canc</em>.<br><br>";
+echo mex("Array personalizzato eliminato",$pag).".<br><br>";
 } # fine else if (numlin_query($n_var_pers_el) != 1)
 } # fine if ($continua == "SI")
 return $continua;
@@ -259,7 +262,7 @@ $var_pers_elimina = aggslashdb($var_pers_elimina);
 $continua = "SI";
 if (controlla_num_pos($var_pers_elimina) != "SI") $continua = "NO";
 if ($continua == "SI") {
-$tabelle_lock = array("$tablecontratti");
+$tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $n_var_pers_el = esegui_query("select * from $tablecontratti where numero = '$var_pers_elimina' and tipo $LIKE 'var%'");
 if (numlin_query($n_var_pers_el) != 1) $continua = "NO";
@@ -267,6 +270,7 @@ else {
 $n_var_pers_el = risul_query($n_var_pers_el,0,"testo");
 $condizioni = esegui_query("select * from $tablecontratti where tipo $LIKE 'cond%' order by numero");
 $num_condizioni = numlin_query($condizioni);
+$num_cond_canc = 0;
 for ($num1 = 0 ; $num1 < $num_condizioni ; $num1++) {
 $condizione = risul_query($condizioni,$num1,'testo');
 $condizione = explode("#@?",$condizione);
@@ -291,9 +295,10 @@ if ($elimina_cond_corr == "SI") {
 $num_cond = risul_query($condizioni,$num1,'numero');
 $tipo_cond = risul_query($condizioni,$num1,'tipo');
 esegui_query("delete from $tablecontratti where numero = '$num_cond' and tipo = '$tipo_cond' ");
+$num_cond_canc++;
 } # fine ($elimina_cond_corr == "SI")
 } # fine for $num1
-$array = esegui_query("select * from $tablecontratti where tipo $LIKE 'vett%' and testo $LIKE '%;$n_var_pers_el;%' ");
+$array = esegui_query("select * from $tablecontratti where tipo $LIKE 'vett%' and testo $LIKE '%;$n_var_pers_el%' ");
 $num_array = numlin_query($array);
 for ($num1 = 0 ; $num1 < $num_array ; $num1++) {
 $var_arr = explode(";",risul_query($array,$num1,'testo'));
@@ -304,6 +309,7 @@ elimina_array_pers("a".$num_arr);
 } # fine if ($var_arr == $n_var_pers_el)
 } # fine for $num1
 esegui_query("delete from $tablecontratti where numero = '$var_pers_elimina' and tipo $LIKE 'var%'");
+if ($num_cond_canc) echo mex("Condizioni eliminate",$pag).": <em>$num_cond_canc</em>.<br><br>";
 echo mex("Variabile personalizzata eliminata",$pag).".<br>";
 } # fine else if (numlin_query($n_var_pers_el) != 1)
 unlock_tabelle($tabelle_lock);
