@@ -168,7 +168,8 @@ else $ordine_costi = "nomecostoagg";
 
 
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
-$dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO",$ordine_costi,$tableappartamenti);
+$dati_cat_pers = dati_cat_pers($id_utente,$tablepersonalizza,$lingua_mex,"v",1,1);
+$dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO",$ordine_costi,$tableappartamenti,$dati_cat_pers);
 $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 $attiva_checkin = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'attiva_checkin' and idutente = '$id_utente'");
 $attiva_checkin = risul_query($attiva_checkin,0,'valpersonalizza');
@@ -241,13 +242,14 @@ if (!$d_costo_tot) $d_costo_tot = (double) 0;
 $d_caparra = risul_query($dati_prenota,0,'caparra');
 $d_num_persone = risul_query($dati_prenota,0,'num_persone');
 if (!$d_num_persone) $d_num_persone = 0;
+$d_cat_persone = dati_cat_pers_p($dati_prenota,0,$dati_cat_pers,$d_num_persone);
 $d_tariffesettimanali = risul_query($dati_prenota,0,'tariffesettimanali');
 unset($num_letti_agg);
-$dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prenota);
+$dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prenota,$dati_cat_pers);
 $d_costo_agg_tot = (double) 0;
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
-aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","");
-$d_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$d_costo_tariffa,$d_tariffesettimanali,($d_costo_tariffa + $d_costo_agg_tot - $d_sconto),$d_caparra,$d_num_persone);
+aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","",$dati_cap[$numca]['cat_pers'],"0");
+$d_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$d_costo_tariffa,$d_tariffesettimanali,($d_costo_tariffa + $d_costo_agg_tot - $d_sconto),$d_caparra,$d_num_persone,$dati_cap[$numca]['cat_pers'],0);
 $d_costo_agg_tot = (double) $d_costo_agg_tot + $d_prezzo_costo_agg[$numca];
 } # fine for $numca
 $d_pagato = risul_query($dati_prenota,0,'pagato');
@@ -436,7 +438,7 @@ break;
 else {
 $id_periodi_costo_aux = $$id_periodi_costo;
 $settimane_costo[$num_costo] = calcola_settimane_costo($tableperiodi,$dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$id_periodi_costo_aux,"1");
-aggiorna_letti_agg_in_periodi($dati_ca,$numca,$num_letti_agg,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num_costo],"",$molt_costo,$d_num_persone);
+aggiorna_letti_agg_in_periodi($dati_ca,$numca,$num_letti_agg,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num_costo],"",$molt_costo,$d_num_persone,$dati_cat_pers,"0");
 } # fine else if ($dati_ca[$numca]['numsett'] == "c" and $dati_ca[$numca]['associasett'] == "s" and...
 
 if (($dati_ca[$numca]['moltiplica'] == "p" or $dati_ca[$numca]['moltiplica'] == "t") and !$d_num_persone) {
@@ -452,7 +454,7 @@ else {
 $idinizioperiodo = $id_periodo_corrente;
 $idfineperiodo = $id_periodo_corrente;
 $settimane_costo[$num_costo] = calcola_settimane_costo($tableperiodi,$dati_ca,$numca,$idinizioperiodo,$idfineperiodo,",$id_periodo_corrente,","1");
-calcola_moltiplica_costo($dati_ca,$numca,$moltiplica_costo[$num_costo],$idinizioperiodo,$idfineperiodo,$settimane_costo[$num_costo],$molt_costo,"1","");
+calcola_moltiplica_costo($dati_ca,$numca,$moltiplica_costo[$num_costo],$idinizioperiodo,$idfineperiodo,$settimane_costo[$num_costo],$molt_costo,"1","","");
 if (trova_periodo_permesso_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,"1") == "NO") {
 if ($dati_ca[$numca]['combina'] == "s") continue;
 $errori_costi[$num_costo] .= ", ".mex("periodo non permesso",$pag);
@@ -524,7 +526,7 @@ unset($num_ripetizioni_costo);
 
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 if ($dati_cap[$numca]['moltiplica'] == "t") {
-calcola_moltiplica_costo($dati_cap,$numca,$n_moltiplica_costo[$numca],$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],"",$d_num_persone,$num_letti_agg);
+calcola_moltiplica_costo($dati_cap,$numca,$n_moltiplica_costo[$numca],$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],"",$d_num_persone,$d_cat_persone,$num_letti_agg);
 $num_costo = $dati_ca['id'][$dati_cap[$numca]['idntariffe']];
 if ($dati_ca[$num_costo]['id'] == $dati_cap[$numca]['idntariffe'] and $dati_cap[$numca]['nome'] == $dati_ca[$num_costo]['nome'] and $dati_ca[$num_costo]['numlimite']) $num_limite = (string) $dati_ca[$num_costo]['numlimite'];
 else $num_limite = (string) 0;
@@ -550,13 +552,13 @@ $molt_costo = $id_costo[1];
 if (!$molt_costo) $molt_costo = 1;
 $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
-$moltiplica_max[$num1] = calcola_moltiplica_costo($dati_ca,$numca,$moltiplica_costo[$num1],$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$molt_costo,$d_num_persone,$num_letti_agg);
+$moltiplica_max[$num1] = calcola_moltiplica_costo($dati_ca,$numca,$moltiplica_costo[$num1],$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$molt_costo,$d_num_persone,$d_cat_persone,$num_letti_agg);
 if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_ca,$numca,$num_costi_presenti,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],"","") == "NO") {
 $errori_costi[$num1] .= ", ".mex("numero massimo raggiunto",$pag);
 $errore_prenota = 1;
 } # fine if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_ca,$numca,$num_costi_presenti,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],"","") == "NO")
 if ($dati_ca[$numca]['tipo_beniinv']) {
-$risul = controlla_beni_inventario_costo($tablerelinventario,$dati_ca,$numca,$beniinv_presenti,$num_ripetizioni_costo[$num1],"SI",$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],"");
+$risul = controlla_beni_inventario_costo($tablerelinventario,$dati_ca,$numca,$beniinv_presenti,$num_ripetizioni_costo[$num1],"SI",$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$app_prenota);
 if ($risul != "SI") {
 $errori_costi[$num1] .= ", ".mex("bene non presente in inventario",$pag);
 $errore_prenota = 1;
@@ -565,17 +567,51 @@ if ($dati_ca[$numca]['tipo_beniinv'] != "app") $errore_cassa = 1;
 } # fine if ($dati_ca[$numca]['tipo_beniinv'])
 if ($dati_ca[$numca]['moltiplica'] == "c" and $dati_ca[$numca]['molt_max'] != "x") {
 $num_max = 0;
+$num_max_check = 0;
 if ($dati_ca[$numca]['molt_max'] == "n") $num_max = $dati_ca[$numca]['molt_max_num'];
-if ($dati_ca[$numca]['molt_max'] != "n" and $d_num_persone) $num_max = $d_num_persone;
-if ($dati_ca[$numca]['molt_max'] == "t" and $num_letti_agg['max']) $num_max += $num_letti_agg['max'];
-if ($num_max) {
+if ($dati_ca[$numca]['molt_max'] != "n" and $d_num_persone) {
+$num_max = $d_num_persone;
+if ($num_max) $num_max_check = 1;
+if ($dati_ca[$numca]['modo_cp_molt']) {
+$cat_persone_corr = $d_cat_persone;
+if (empty($cat_persone_corr)) {
+$cat_persone_corr = array(0 => array());
+$cat_persone_corr[0]['molt'] = $d_num_persone;
+$cat_persone_corr[0]['ord'] = 0;
+$cat_persone_corr['ord'][0] = 0;
+$cat_persone_corr['num'] = 1;
+} # fine if (empty($cat_persone_corr))
+if ($dati_ca[$numca]['modo_cp_molt'] == "i") $num_max = 0;
+for ($num2 = 0 ; $num2 < $dati_ca[$numca]['cp_molt']['num'] ; $num2++) {
+$cp = $dati_ca[$numca]['cp_molt']['ord'][$num2];
+if ($dati_ca[$numca]['cp_molt'][$cp]['esist'] and $cat_persone_corr[$cat_persone_corr['ord'][$cp]]['molt']) {
+if ($dati_ca[$numca]['modo_cp_molt'] == "i") $num_max += $cat_persone_corr[$cat_persone_corr['ord'][$cp]]['molt'];
+else $num_max = $num_max - $cat_persone_corr[$cat_persone_corr['ord'][$cp]]['molt'];
+} # fine if ($dati_ca[$numca]['cp_molt'][$cp]['esist'] and $cat_persone_corr[$cat_persone_corr['ord'][$cp]]['molt'])
+} # fine for $num2
+} # fine if ($dati_ca[$numca]['modo_cp_molt'])
+} # fine if ($dati_ca[$numca]['molt_max'] != "n" and $d_num_persone)
+if ($dati_ca[$numca]['molt_max'] == "t" and $num_letti_agg['max']) {
+$num_letti_agg_corr = $num_letti_agg['max'];
+if ($num_letti_agg_corr) $num_max_check = 1;
+if ($dati_ca[$numca]['modo_cp_molt'] == "i") $num_letti_agg_corr = 0;
+for ($num2 = 0 ; $num2 < $dati_ca[$numca]['cp_molt']['num'] ; $num2++) {
+$cp = $dati_ca[$numca]['cp_molt']['ord'][$num2];
+if ($dati_ca[$numca]['cp_molt'][$cp]['esist'] and $num_letti_agg['catp_tot_max'][$cp]) {
+if ($dati_ca[$numca]['modo_cp_molt'] == "i") $num_letti_agg_corr += $num_letti_agg['catp_tot_max'][$cp];
+else $num_letti_agg_corr = $num_letti_agg_corr - $num_letti_agg['catp_tot_max'][$cp];
+} # fine if ($dati_ca[$numca]['cp_molt'][$cp]['esist'] and $num_letti_agg['catp_tot_max'][$cp])
+} # fine for $num2
+$num_max += $num_letti_agg_corr;
+} # fine if ($dati_ca[$numca]['molt_max'] == "t" and $num_letti_agg['max'])
+if ($num_max or $num_max_check) {
 if ($dati_ca[$numca]['molt_max'] != "n" and $dati_ca[$numca]['molt_max_num']) $num_max = $num_max - $dati_ca[$numca]['molt_max_num'];
 if ($molt_costo > $num_max) {
 $errori_costi[$num_costo] .= ", ".mex("moltiplicato per più di",$pag)." $num_max";
 $errore_prenota = 1;
 if ($dati_ca[$numca]['molt_max'] == "n") $errore_cassa = 1;
 } # fine if ($molt_costo > $num_max)
-} # fine if ($num_max)
+} # fine if ($num_max or $num_max_check)
 } # fine if ($dati_ca[$numca]['moltiplica'] == "c" and $dati_ca[$num1]['molt_max'] != "x")
 } # fine for $num1
 
@@ -583,7 +619,7 @@ if ($dati_ca[$numca]['molt_max'] == "n") $errore_cassa = 1;
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 if ($dati_cap[$numca]['tipo_val'] != "t" and $dati_cap[$numca]['tipo_val'] != "r") {
 if ($dati_cap[$numca]['moltiplica'] == "t") {
-$n_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,1,$d_caparra,$d_num_persone);
+$n_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,1,$d_caparra,$d_num_persone,$dati_cap[$numca]['cat_pers'],0);
 if ($n_prezzo_costo_agg[$numca] != $d_prezzo_costo_agg[$numca]) $val_costo[-1] += $n_prezzo_costo_agg[$numca] - $d_prezzo_costo_agg[$numca];
 } # fine if ($dati_cap[$numca]['moltiplica'] == "t")
 else $n_prezzo_costo_agg[$numca] = $d_prezzo_costo_agg[$numca];
@@ -598,7 +634,7 @@ $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
 if ($dati_ca[$numca]['tipo_val'] != "f" or $dati_ca[$numca]['tipo'] != "u" or $dati_ca[$numca]['moltiplica'] == "p" or $dati_ca[$numca]['moltiplica'] == "t") {
 if ($dati_ca[$numca]['tipo_val'] != "t" and $dati_ca[$numca]['tipo_val'] != "r") {
-$val_costo[$num1] = (double) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,1,$d_caparra,$d_num_persone);
+$val_costo[$num1] = (double) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,1,$d_caparra,$d_num_persone,$dati_cat_pers,0);
 $n_costo_agg_tot = $n_costo_agg_tot + $val_costo[$num1];
 $val_tot += $val_costo[$num1];
 } # fine if ($dati_ca[$numca]['tipo_val'] != "t" and $dati_ca[$numca]['tipo_val'] != "r")
@@ -611,7 +647,7 @@ for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 if ($dati_cap[$numca]['tipo_val'] == "r") {
 $calcolabile_js['nessuno'] = 1;
 $costo_totale_provvisorio = $d_costo_tariffa + $n_costo_agg_tot - $d_sconto;
-$n_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone);
+$n_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
 if ($d_prezzo_costo_agg[$numca] != $n_prezzo_costo_agg[$numca]) $val_costo[-1] += $n_prezzo_costo_agg[$numca] - $d_prezzo_costo_agg[$numca];
 $n_costo_agg_tot = $n_costo_agg_tot + $n_prezzo_costo_agg[$numca];
 } # fine if ($dati_cap[$numca][tipo_val] == "r")
@@ -623,7 +659,7 @@ $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
 if ($dati_ca[$numca]['tipo_val'] == "r") {
 $costo_totale_provvisorio = $d_costo_tariffa + $n_costo_agg_tot - $d_sconto;
-$val_costo[$num1] = (double) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone);
+$val_costo[$num1] = (double) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
 $n_costo_agg_tot = $n_costo_agg_tot + $val_costo[$num1];
 $val_tot += $val_costo[$num1];
 } # fine if ($dati_ca[$numca][tipo_val] == "r")
@@ -634,7 +670,7 @@ for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
 if ($dati_cap[$numca]['tipo_val'] == "t") {
 $calcolabile_js['nessuno'] = 1;
 $costo_totale_provvisorio = $d_costo_tariffa + $n_costo_agg_tot - $d_sconto;
-$n_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone);
+$n_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
 if ($d_prezzo_costo_agg[$numca] != $n_prezzo_costo_agg[$numca]) $val_costo[-1] += $n_prezzo_costo_agg[$numca] - $d_prezzo_costo_agg[$numca];
 $n_costo_agg_tot = $n_costo_agg_tot + $n_prezzo_costo_agg[$numca];
 } # fine if ($dati_cap[$numca][tipo_val] == "t")
@@ -646,7 +682,7 @@ $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
 if ($dati_ca[$numca]['tipo_val'] == "t") {
 $costo_totale_provvisorio = $d_costo_tariffa + $n_costo_agg_tot - $d_sconto;
-$val_costo[$num1] = (double) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone);
+$val_costo[$num1] = (double) calcola_prezzo_totale_costo($dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$d_costo_tariffa,$d_tariffesettimanali,$costo_totale_provvisorio,$d_caparra,$d_num_persone,"","");
 $n_costo_agg_tot = $n_costo_agg_tot + $val_costo[$num1];
 $val_tot += $val_costo[$num1];
 } # fine if ($dati_ca[$numca][tipo_val] == "t")
@@ -901,6 +937,7 @@ $tipo_ca = $dati_ca[$numca]['tipo'].$dati_ca[$numca]['tipo_val'];
 $valore_ca = $dati_ca[$numca]['valore'];
 $valore_perc_ca = $dati_ca[$numca]['valore_perc'];
 $associasett_ca = $dati_ca[$numca]['associasett'];
+$letto_ca = $dati_ca[$numca]['letto'];
 if ($dati_ca[$numca]['var_percentuale'] != "s" and $dati_ca[$numca]['tipo_val'] != "f") {
 $tipo_ca = $dati_ca[$numca]['tipo']."f";
 $moltiplica = 1;
@@ -911,7 +948,8 @@ $associasett_ca = "n";
 $valore_ca = $val_costo[$num1];
 $valore_perc_ca = 0;
 } # fine if ($dati_ca[$numca][var_percentuale] != "s" and...
-if ($dati_ca[$numca]['var_moltiplica'] == "s") $varmoltiplica_ca = $dati_ca[$numca]['moltiplica'].$dati_ca[$numca]['molt_max'].$dati_ca[$numca]['molt_agg'].",".$dati_ca[$numca]['molt_max_num'];
+elseif ($dati_ca[$numca]['perc_catpers'] == "s") $letto_ca = "p";
+if ($dati_ca[$numca]['var_moltiplica'] == "s") $varmoltiplica_ca = $dati_ca[$numca]['moltiplica'].$dati_ca[$numca]['molt_max'].$dati_ca[$numca]['molt_agg'].",".$dati_ca[$numca]['molt_max_num'].$dati_ca[$numca]['cp_molt_int'];
 else $varmoltiplica_ca = "cx0,";
 if ($dati_ca[$numca]['var_numsett'] == "s") $varnumsett_ca = $dati_ca[$numca]['numsett_orig'];
 else $varnumsett_ca = "c";
@@ -930,7 +968,7 @@ if ($dati_ca[$numca]["incomp_tariffa".$numtariffa] == "i") $vartariffeincomp_ca
 } # fine for $numtariffa
 if ($vartariffeincomp_ca) $vartariffeincomp_ca = substr($vartariffeincomp_ca,1);
 } # fine if ($dati_ca[$num_costo][var_tariffei] == "s")
-esegui_query("insert into $tablecostiprenota (idcostiprenota,idprenota,tipo,nome,valore,associasett,settimane,moltiplica,letto,idntariffe,varmoltiplica,varnumsett,varperiodipermessi,varbeniinv,varappincompatibili,vartariffeassociate,vartariffeincomp,datainserimento,hostinserimento,utente_inserimento) values ('$idcostiprenota','$id_prenota','$tipo_ca','".aggslashdb($dati_ca[$numca]['nome'])."','$valore_ca','$associasett_ca','$sett_costo','$moltiplica','".$dati_ca[$numca]['letto']."','$id_costo','$varmoltiplica_ca','$varnumsett_ca','$varperiodipermessi_ca','$varbeniinv_ca','$varappincompatibili_ca','$vartariffeassociate_ca','$vartariffeincomp_ca','$datainserimento','$HOSTNAME','$id_utente')");
+esegui_query("insert into $tablecostiprenota (idcostiprenota,idprenota,tipo,nome,valore,associasett,settimane,moltiplica,letto,idntariffe,varmoltiplica,varnumsett,varperiodipermessi,varbeniinv,varappincompatibili,vartariffeassociate,vartariffeincomp,datainserimento,hostinserimento,utente_inserimento) values ('$idcostiprenota','$id_prenota','$tipo_ca','".aggslashdb($dati_ca[$numca]['nome'])."','$valore_ca','$associasett_ca','$sett_costo','$moltiplica','$letto_ca','$id_costo','$varmoltiplica_ca','$varnumsett_ca','$varperiodipermessi_ca','$varbeniinv_ca','$varappincompatibili_ca','$vartariffeassociate_ca','$vartariffeincomp_ca','$datainserimento','$HOSTNAME','$id_utente')");
 if (substr($tipo_ca,1,1) != "f") esegui_query("update $tablecostiprenota set valore_perc = '$valore_perc_ca', arrotonda = '".$dati_ca[$numca]['arrotonda']."' where idcostiprenota = '$idcostiprenota'");
 if ($dati_ca[$numca]['tasseperc']) esegui_query("update $tablecostiprenota set tasseperc = '".$dati_ca[$numca]['tasseperc']."' where idcostiprenota = '$idcostiprenota'");
 } # fine for $num1
