@@ -279,8 +279,8 @@ $frase_periodo .= " ".mex("fino al",$pag)." $cerca_fineperiodo_f";
 
 $saldo_prenota_TOT = 0;
 $saldo_valuta_TOT = array();
-if (!$senza_colori) $colore = "$t1color";
-else $colore = "#ffffff";
+if (!isset($senza_colori)) $class = "t1 t1color";
+else $class = "t1wc";
 
 $tutti_utenti = esegui_query("select * from $tableutenti order by idutenti");
 $num_tutti_utenti = numlin_query($tutti_utenti);
@@ -341,19 +341,19 @@ else $pagina_prenota = 1;
 } # fine if (!$cerca_prenota)
 
 echo "<div class=\"tab_cont\">
-<table class=\"t1\" style=\"background-color: $colore; margin-left: auto; margin-right: auto;\" width=200 border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
+<table class=\"$class\" style=\"margin-left: auto; margin-right: auto;\" width=200 border=\"$t1border\" cellspacing=\"$t1cellspacing\" cellpadding=\"$t1cellpadding\">
 <tr><td colspan=4>".mex("Dati della prenotazione",$pag)."</td>
-<td rowspan=2>".mex("Pagato prima",$pag)."</td>
-<td rowspan=2>".mex("Pagato dopo",$pag)."</td>
-<td rowspan=2>".mex("Saldo",$pag)."</td>
-<td rowspan=2>".mex("Id",$pag)."</td>
-<td rowspan=2>".mex("Metodo",$pag)."</td>";
-if ($num_tutti_utenti > 1) echo "<td rowspan=2>".mex("Utente",$pag)."</td>";
-echo "<td rowspan=2>".mex("Data_della modifica",$pag)."</td></tr>
+<td class=\"t1top\" rowspan=2>".mex("Pagato prima",$pag)."</td>
+<td class=\"t1top\" rowspan=2>".mex("Pagato dopo",$pag)."</td>
+<td class=\"t1top\" rowspan=2>".mex("Saldo",$pag)."</td>
+<td class=\"t1top\" rowspan=2>".mex("Id",$pag)."</td>
+<td class=\"t1top\" rowspan=2>".mex("Metodo",$pag)."</td>";
+if ($num_tutti_utenti > 1) echo "<td class=\"t1top\" rowspan=2>".mex("Utente",$pag)."</td>";
+echo "<td class=\"t1top\" rowspan=2>".mex("Data_della modifica",$pag)."</td></tr>
 <tr><td>".mex("N°",$pag)."</td>
 <td>".str_replace("_","&nbsp;",mex("Cognome_cliente",$pag))."</td>
-<td>".str_replace("_","&nbsp;",mex("Data_iniziale",$pag))."</td>
-<td>".str_replace("_","&nbsp;",mex("Data_finale",$pag))."</td></tr>";
+<td class=\"t1top\">".str_replace("_","&nbsp;",mex("Data_iniziale",$pag))."</td>
+<td class=\"t1top\">".str_replace("_","&nbsp;",mex("Data_finale",$pag))."</td></tr>";
 
 if (!$cerca_prenota and $num_storia_soldi_prenota > $num_vedi_in_tab and $pagina_prenota != 1) echo $stringa_puntini_tab;
 
@@ -448,7 +448,7 @@ else $saldo_valuta_TOT[$Euro] += $saldo_prenota;
 if ($cerca_prenota or (($num1+1) > (($pagina_prenota - 1)*$num_vedi_in_tab) and ($num1+1) <= (($pagina_prenota)*$num_vedi_in_tab)) ) {
 
 echo "<tr><td>$num_prenota</td>
-<td>$cognome</td>
+<td class=\"t1left\">$cognome</td>
 <td>$data_inizio_f</td>
 <td>$data_fine_f</td>
 <td>$soldi_prima_p</td>
