@@ -532,10 +532,12 @@ $num_for = 1;
 $ini_for[1] = 1;
 $fine_for[1] = $max_periodo;
 if ($dati_ca[$num2]["tipo_associa_".$tariffa[$num1]] == "r" and $dati_ca[$num2]['periodipermessi']) {
+$num_for = 0;
 for ($num3 = 0 ; $num3 < count($dati_ca[$num2]['sett_periodipermessi_ini']) ; $num3++) {
 $num_for = $num3 + 1;
 $ini_for[$num_for] = $dati_ca[$num2]['sett_periodipermessi_ini'][$num3];
 $fine_for[$num_for] = $dati_ca[$num2]['sett_periodipermessi_fine'][$num3];
+echo "$num2 - ".$dati_ca[$num2]['nome']." - $num_for - ".$ini_for[$num_for]." - ".$fine_for[$num_for]." - $p_min QUI<br>";
 } # fine for $num3
 } # fine if ($dati_ca[$num2]["tipo_associa_".$tariffa[$num1]] == "r" and...
 for ($num3 = 1 ; $num3 <= $num_for ; $num3++) {
