@@ -318,7 +318,7 @@ return $colore;
 $manda_xml = 0;
 $dati_xml = "";
 
-if ($idg_agg and controlla_num_pos(substr($idg_agg,2)) == "SI") {
+if (isset($idg_agg) and controlla_num_pos(substr($idg_agg,2)) == "SI") {
 $manda_xml = 1;
 $tabelle_lock = "";
 if ($priv_vedi_tab_mesi != "p") $altre_tab_lock = array($tableprenota,$tableperiodi,$tableappartamenti,$tableclienti,$tableregole,$tablepersonalizza);
@@ -424,7 +424,7 @@ if ($ln1) $dati_prenota_extra .= "<ln>1</ln>";
 if ($prenota_consentita) {
 $idclienti = risul_query($prenota_ini_fine,$num1,'idclienti');
 $cognome = esegui_query("select cognome from $tableclienti where idclienti = '$idclienti' ");
-$cognome = risul_query($cognome,0,'cognome');
+$cognome = str_replace("&gt;","",str_replace("&lt;","",risul_query($cognome,0,'cognome')));
 $colore = colore_prenotazione($prenota_ini_fine,$num1);
 $assegnazioneapp = substr(risul_query($prenota_ini_fine,$num1,'assegnazioneapp'),0,1);
 if ($assegnazioneapp == "c") $app_ass_js = risul_query($prenota_ini_fine,$num1,'app_assegnabili');
@@ -510,9 +510,9 @@ $dati_prenota
 } # fine if ($d_inizio_settimana)
 } # fine for $ncol
 unlock_tabelle($tabelle_lock);
-} # fine if ($idg_agg and controlla_num_pos(substr($idg_agg,2)) == "SI")
+} # fine if (isset($idg_agg) and controlla_num_pos(substr($idg_agg,2)) == "SI")
 
-if ($dati_prn and substr($dati_prn,0,3) == "prn" and controlla_num_pos(substr($dati_prn,3)) == "SI" and !$manda_xml) {
+if (isset($dati_prn) and substr($dati_prn,0,3) == "prn" and controlla_num_pos(substr($dati_prn,3)) == "SI" and !$manda_xml) {
 $manda_xml = 1;
 $id_prn = substr($dati_prn,3);
 $tabelle_lock = array();
@@ -585,14 +585,14 @@ $origine = risul_query($dati_prn,0,'origine');
 if ($origine) $dati_xml .= "\n-".mex("Origine",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$origine))))." ";
 $data_inserimento = formatta_data(substr($data_ins,0,-3),$stile_data);
 $dati_xml .= "\n-".mex("Data inserimento",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$data_inserimento))))." ";
-if ($priv_vedi_commento == "s") {
+if ($priv_vedi_commento == "s" and $iddatainizio != 0) {
 $commento = risul_query($dati_prn,0,'commento');
 if (strstr($commento,">")) {
 $commento = explode(">",$commento);
 $commento = $commento[0];
 } # fine if (strstr($commento,">"))
 if ($commento) $dati_xml .= "\n-".mex("Commento",$pag).": ".str_replace("\"","&quot;",str_replace(">","&gt;",str_replace("<","&lt;",str_replace("&","&amp;",$commento))))." ";
-} # fine if ($priv_vedi_commento == "s")
+} # fine if ($priv_vedi_commento == "s" and $iddatainizio != 0)
 if ($priv_mod_pagato != "n" and $priv_mod_pagato != "i") {
 $Euro = nome_valuta();
 $stile_soldi = stile_soldi();
@@ -645,7 +645,7 @@ $pag = $pag_orig;
 } # fine if ($link_modifica)
 } # fine if (numlin_query($dati_prn))
 unlock_tabelle($tabelle_lock);
-} # fine if ($dati_prn and substr($dati_prn,0,3) == "prn" and controlla_num_pos(substr($dati_prn,3)) == "SI" and...
+} # fine if (isset($dati_prn) and substr($dati_prn,0,3) == "prn" and controlla_num_pos(substr($dati_prn,3)) == "SI" and...
 
 if ($manda_xml) {
 header('Content-type: text/xml');
@@ -886,7 +886,7 @@ $allinea_tab_mesi = esegui_query("select valpersonalizza from $tablepersonalizza
 if (numlin_query($allinea_tab_mesi) == 1) $allinea_tab_mesi = risul_query($allinea_tab_mesi,0,'valpersonalizza');
 else $allinea_tab_mesi = "NO";
 
-$linea_date = "<tr class=\"rd_r\" style=\"background-color: $t1dates;\"><td style=\"background-color: $t1color; padding: 0 2px 0 2px\">";
+$linea_date = "<tr class=\"rd_r\"><td style=\"padding: 0 2px 0 2px\">";
 if ($inserire != "NO") $linea_date .= "<a name=\"\"></a>";
 $linea_date .= "<button type=\"button\" onclick=\"scorri_date('sx')\">
 <img src=\"./img/dir1_sin.png\" alt=\"&lt;\"></button><br>
@@ -895,17 +895,19 @@ $linea_date .= "<button type=\"button\" onclick=\"scorri_date('sx')\">
 for ($num1 = 0 ; $num1 < $num_colonne ; $num1 = $num1 + 1) {
 $id_settimana = $id_data_inizio_tab + $num1;
 crea_data_per_linea($num1,$num_colonne,$id_settimana,$d_inizio_settimana,$d_fine_settimana,$m_inizio_settimana,$m_fine_settimana,$array_date_col_js,$tipo_periodi,$mostra_giorni_tab_mesi,$giorno_vedi_ini_sett);
-$linea_date .= "<td class=\"rd_$num1\"";
+$linea_date .= "<td";
 if ($num1 != 0 or $allinea_tab_mesi == "SI") $linea_date .= " colspan=\"2\"";
 if ($m_inizio_settimana != $mese_mostra) $linea_date .= " style=\"background-color: $t1datesout;\"";
-$linea_date .= ">$d_inizio_settimana</td>";
+else $linea_date .= " style=\"background-color: $t1dates;\"";
+$linea_date .= " class=\"rd_$num1 m1top\">$d_inizio_settimana</td>";
 } # fine for $num1
 if ($allinea_tab_mesi != "SI") {
-$linea_date .= "<td class=\"rd_$num1\"";
+$linea_date .= "<td";
 if ($m_fine_settimana != $mese_mostra) $linea_date .= " style=\"background-color: $t1datesout;\"";
-$linea_date .= ">$d_fine_settimana</td>";
+else $linea_date .= " style=\"background-color: $t1dates;\"";
+$linea_date .= " class=\"rd_$num1 m1top\">$d_fine_settimana</td>";
 } # fine if ($allinea_tab_mesi != "SI")
-$linea_date .= "<td style=\"background-color: $t1color; padding: 0 2px 0 2px\">
+$linea_date .= "<td style=\"padding: 0 2px 0 2px\">
 <button type=\"button\" onclick=\"scorri_date('dx')\">
 <img src=\"./img/dir1_des.png\" alt=\"&gt;\"></button><br>
 <button type=\"button\" onclick=\"scorri_date('7dx')\">
@@ -938,9 +940,10 @@ var curr_sel_row = 0;
 <div class=\"tab_cont\">
 <div style=\"position: relative;\" ondragstart=\"drg(event)\">
 <table class=\"m1ext\" cellspacing=0 cellpadding=0><tr><td>
-<table class=\"m1\" style=\"background-color: $t1color;\" cellpadding=\"$cellpadding\" ><tbody>";
+<table class=\"m1 t1color\" cellpadding=\"$cellpadding\" ><tbody>";
 
 echo str_replace("<a name=\"\"></a>","<a name=\"rd_n$num_linea_date\"></a>",$linea_date);
+$linea_date = str_replace(" m1top\">","\">",$linea_date);
 
 
 $linee_ripeti_date_tab_mesi = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'linee_ripeti_date_tab_mesi' and idutente = '$id_utente'");
@@ -985,7 +988,7 @@ $prenota_succ = 0;
 } # fine else if ($num1 < $num_appartamenti)
 if ($priv_vedi_tab_mesi != "p" or $appartamenti_consentiti[$id_appartamento] != "NO" or $num1 >= $num_appartamenti) {
 
-$casella_app = "<td>";
+$casella_app = "";
 if (num_caratteri_testo($id_appartamento) > 2) $casella_app .= "<small><small>";
 if ($num1 >= $num_appartamenti) $casella_app .= "<div style=\"display: inline; color: red;\">";
 if (strcmp($id_appartamento,"")) $casella_app .= "$id_appartamento";
@@ -993,7 +996,8 @@ else $casella_app .= mex("ERRORE",$pag);
 if ($num1 >= $num_appartamenti) $casella_app .= "</div>";
 if (num_caratteri_testo($id_appartamento) > 2) $casella_app .= "</small></small>";
 $casella_app .= "</td>";
-echo "<tr id=\"app$num_app_js\">$casella_app";
+echo "<tr id=\"app$num_app_js\"><td class=\"t1left\">$casella_app";
+$casella_app = "<td>$casella_app";
 $array_app_js .= "\"$id_appartamento\",";
 $num_app_js++;
 
@@ -1162,7 +1166,12 @@ else { $id_inizio = $id_data_inizio_tab; }
 if ($id_fine_prenota < $id_data_fine_tab) { $id_fine = $id_fine_prenota; }
 else { $id_fine = $id_data_fine_tab; }
 $colonne = $id_fine - $id_inizio + 1;
-if ($id_utente == 1 and $ini_prenota_succ <= $id_fine_prenota) $cognome = mex("ERRORE",$pag);
+if ($ini_prenota_succ <= $id_fine_prenota) {
+if (defined('C_NUM_HOSTING') and C_NUM_HOSTING != "") {
+error_log("OVERBOOKING IN TAB $mese_mostra-$anno_mostra ".C_NUM_HOSTING." ".$_SERVER['PHP_SELF']." ERROR: $id_prenota ($cognome)");
+} # fine if (defined('C_NUM_HOSTING') and C_NUM_HOSTING != "")
+if ($cognome != "?") $cognome = mex("ERRORE",$pag);
+} # fine if ($ini_prenota_succ <= $id_fine_prenota)
 
 if ($priv_mod_prenotazioni == "n") $link_modifica = "NO";
 if ($priv_mod_prenotazioni == "p" and $utente_inserimento != $id_utente) $link_modifica = "NO";
@@ -1230,7 +1239,7 @@ echo "</td><td></td></tr></table></td>";
 $num2 = $num2 + $colonne - 1;
 } # fine if ($esiste == 1)
 else {
-if ($reg1_chiuso and $reg1_chiuso[$id_appartamento][$id_settimana]) echo "<td style=\"background-color: #777777;\" colspan=\"2\">&nbsp;</td>";
+if (isset($reg1_chiuso) and isset($reg1_chiuso[$id_appartamento][$id_settimana])) echo "<td style=\"background-color: #777777;\" colspan=\"2\">&nbsp;</td>";
 else echo "<td colspan=\"2\">&nbsp;</td>";
 } # fine else if ($esiste == 1)
 
