@@ -40,8 +40,10 @@ $t1dropout = "#297929";
 
 # head
 $body_bgcolor = "#dddddd";
-if (!$tema_corr) $tema_corr = $tema[$id_utente];
-if ($senza_colori == "SI" or ($pag == "visualizza_contratto.php" and $show_bar == "NO")) $body_bgcolor = "#ffffff";
+global $vers_hinc,$mobile_device;
+if (!isset($show_bar)) $show_bar = "";
+if (!isset($tema_corr)) $tema_corr = $tema[$id_utente];
+if (isset($senza_colori) or ($pag == "visualizza_contratto.php" and $show_bar == "NO")) $body_bgcolor = "#ffffff";
 if ($pag == "punto_vendita.php") $iscale = "0.8";
 else $iscale = "1.0";
 if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") $titolo = "";
@@ -58,7 +60,11 @@ if (defined('C_URL_FAVICON') and C_URL_FAVICON != "" and @is_file(C_URL_FAVICON)
 ";
 elseif (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA != "SI") echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
 ";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\" media=\"all\">
+echo "<style type=\"text/css\">
+:root { --t1color: $t1color; }
+.t1color { background-color: $t1color; }
+</style>
+<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\" media=\"all\">
 <link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/stylesheet.css$vers_hinc\" media=\"all\">
 ";
 if (!$mobile_device) echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/screen.css$vers_hinc\" media=\"screen\">
@@ -69,29 +75,31 @@ echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/
 <script type=\"text/javascript\" src=\"./themes/$tema_corr/inc/functions.js$vers_hinc\">
 </script>
 ";
-if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
+if (isset($base_js)) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
 </script>
 ";
-if ($show_bar == "NO") echo "<style type=\"text/css\">
-html { overflow-y: auto; }
+$hstyle = "";
+if ($show_bar == "NO") $hstyle .=  "html { overflow-y: auto; }
 #contentbox { overflow: visible; width:99%; height: 98%; margin-right: auto; margin-left: auto; padding-top: 4px; }
-</style>
 ";
-if ($start_time) echo "<style type=\"text/css\">#contentbox { height: 95%; }</style>
+if (isset($start_time)) $hstyle .=  "#contentbox { height: 95%; }
 ";
-if (mex("insert-ddw","head.php") != "100px") echo "<style type=\"text/css\">.nb_ins ul ul a, .nb_ins ul ul a:visited, .nb_ins ul ul a:hover { min-width: ".mex("insert-ddw","head.php")."; }</style>
+if (mex("insert-ddw","head.php") != "100px") $hstyle .=  ".nb_ins ul ul a, .nb_ins ul ul a:visited, .nb_ins ul ul a:hover { min-width: ".mex("insert-ddw","head.php")."; }
 ";
-if (mex("tables-ddw","head.php") != "100px") echo "<style type=\"text/css\">.nb_tab ul ul a, .nb_tab ul ul a:visited, .nb_tab ul ul a:hover { min-width: ".mex("tables-ddw","head.php")."; }</style>
+if (mex("tables-ddw","head.php") != "100px") $hstyle .=  ".nb_tab ul ul a, .nb_tab ul ul a:visited, .nb_tab ul ul a:hover { min-width: ".mex("tables-ddw","head.php")."; }
 ";
-if (mex("months-ddw","head.php") != "86px") echo "<style type=\"text/css\">.nb_m0 ul ul a, .nb_m0 ul ul a:visited, .nb_m0 ul ul a:hover { min-width: ".mex("months-ddw","head.php")."; }</style>
+if (mex("months-ddw","head.php") != "86px") $hstyle .=  ".nb_m0 ul ul a, .nb_m0 ul ul a:visited, .nb_m0 ul ul a:hover { min-width: ".mex("months-ddw","head.php")."; }
 ";
-if (mex("reservations-ddw","head.php") != "150px") echo "<style type=\"text/css\">.nb_res ul ul a, .nb_res ul ul a:visited, .nb_res ul ul a:hover, .nb_res ul ul div { min-width: ".mex("reservations-ddw","head.php")."; }</style>
+if (mex("reservations-ddw","head.php") != "150px") $hstyle .=  ".nb_res ul ul a, .nb_res ul ul a:visited, .nb_res ul ul a:hover, .nb_res ul ul div { min-width: ".mex("reservations-ddw","head.php")."; }
 ";
-if (mex("clients-ddw","head.php") != "15em") echo "<style type=\"text/css\">.fdrop { min-width: ".mex("clients-ddw","head.php")."; }</style>
+if (mex("clients-ddw","head.php") != "15em") $hstyle .=  ".fdrop { min-width: ".mex("clients-ddw","head.php")."; }
 ";
-if (mex("rates-ddw","head.php") != "150px") echo "<style type=\"text/css\">.nb_rat ul ul a, .nb_rat ul ul a:visited, .nb_rat ul ul a:hover { min-width: ".mex("rates-ddw","head.php")."; }</style>
+if (mex("rates-ddw","head.php") != "150px") $hstyle .=  ".nb_rat ul ul a, .nb_rat ul ul a:visited, .nb_rat ul ul a:hover { min-width: ".mex("rates-ddw","head.php")."; }
 ";
-if (mex("configure-ddw","head.php") != "86px") echo "<style type=\"text/css\">.nb_con ul ul a, .nb_con ul ul a:visited, .nb_con ul ul a:hover { min-width: ".mex("configure-ddw","head.php")."; }</style>
+if (mex("configure-ddw","head.php") != "86px") $hstyle .=  ".nb_con ul ul a, .nb_con ul ul a:visited, .nb_con ul ul a:hover { min-width: ".mex("configure-ddw","head.php")."; }
+";
+if ($hstyle) echo "<style type=\"text/css\">
+$hstyle</style>
 ";
 if (defined('C_FILE_CSS_PERS') and C_FILE_CSS_PERS != "" and @is_file(C_FILE_CSS_PERS)) echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"".C_FILE_CSS_PERS."\" media=\"all\">
 ";
@@ -99,7 +107,7 @@ if ($mobile_device and defined('C_FILE_MOB_CSS_PERS') and C_FILE_MOB_CSS_PERS !=
 ";
 echo "</head>
 <body";
-if ($drag_drop) echo " ondragover=\"event.preventDefault();\" ondragenter=\"event.preventDefault();\" ondrop=\"event.preventDefault();drp_out();\"";
+if (isset($drag_drop)) echo " ondragover=\"event.preventDefault();\" ondragenter=\"event.preventDefault();\" ondrop=\"event.preventDefault();drp_out();\"";
 echo " style=\"background-color: $body_bgcolor;\">";
 
 if ($pag != "visualizza_contratto.php" or $show_bar != "NO") echo "<div id=\"menubox\">";
@@ -133,65 +141,65 @@ if (!$priv_vedi_messaggi) {
 $priv_messaggi = risul_query($privilegi_globali_utente,0,'priv_messaggi');
 $priv_vedi_messaggi = substr($priv_messaggi,0,1);
 } # fine if (!$priv_vedi_messaggi)
-if (!$priv_inventario) $priv_inventario = risul_query($privilegi_globali_utente,0,'priv_inventario');
-if (!$priv_vedi_beni_inv) $priv_vedi_beni_inv = substr($priv_inventario,0,1);
-if (!$priv_vedi_inv_mag) $priv_vedi_inv_mag = substr($priv_inventario,2,1);
-if (!$priv_vedi_inv_app) $priv_vedi_inv_app = substr($priv_inventario,6,1);
-if (!$priv_ins_prenota) $priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
-if (!$priv_ins_nuove_prenota) $priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
-if (!$priv_ins_costi) $priv_ins_costi = risul_query($privilegi_annuali_utente,0,'priv_ins_costi');
-if (!$priv_ins_spese) $priv_ins_spese = substr($priv_ins_costi,0,1);
-if (!$priv_ins_entrate) $priv_ins_entrate = substr($priv_ins_costi,1,1);
-if (!$priv_mod_prenota) $priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
-if (!$priv_mod_prenotazioni) $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
-if (!$priv_mod_costi_agg) $priv_mod_costi_agg = substr($priv_mod_prenota,8,1);
-if (!$priv_vedi_tab) $priv_vedi_tab = risul_query($privilegi_annuali_utente,0,'priv_vedi_tab');
-if (!$priv_vedi_tab_mesi) $priv_vedi_tab_mesi = substr($priv_vedi_tab,0,1);
-if (!$priv_vedi_tab_prenotazioni) $priv_vedi_tab_prenotazioni = substr($priv_vedi_tab,1,1);
-if (!$priv_vedi_tab_costi) $priv_vedi_tab_costi = substr($priv_vedi_tab,2,1);
-if (!$priv_vedi_tab_periodi) $priv_vedi_tab_periodi = substr($priv_vedi_tab,3,1);
-if (!$priv_vedi_tab_regole) $priv_vedi_tab_regole = substr($priv_vedi_tab,4,1);
-if (!$priv_vedi_tab_appartamenti) $priv_vedi_tab_appartamenti = substr($priv_vedi_tab,5,1);
-if (!$priv_vedi_tab_stat) $priv_vedi_tab_stat = substr($priv_vedi_tab,6,1);
-if (!$priv_vedi_tab_doc) $priv_vedi_tab_doc = substr($priv_vedi_tab,7,1);
-if (!$priv_ins_tariffe) $priv_ins_tariffe = risul_query($privilegi_annuali_utente,0,'priv_ins_tariffe');
-if (!$priv_mod_tariffe) $priv_mod_tariffe = substr($priv_ins_tariffe,0,1);
-if (!$priv_mod_reg1) $priv_mod_reg1 = substr($priv_ins_tariffe,4,1);
-if (!$priv_mod_reg2) $priv_mod_reg2 = substr($priv_ins_tariffe,5,1);
-if (!$priv_ins_costi_agg) $priv_ins_costi_agg = substr($priv_ins_tariffe,1,1);
+if (!isset($priv_inventario)) $priv_inventario = risul_query($privilegi_globali_utente,0,'priv_inventario');
+if (!isset($priv_vedi_beni_inv)) $priv_vedi_beni_inv = substr($priv_inventario,0,1);
+if (!isset($priv_vedi_inv_mag)) $priv_vedi_inv_mag = substr($priv_inventario,2,1);
+if (!isset($priv_vedi_inv_app)) $priv_vedi_inv_app = substr($priv_inventario,6,1);
+if (!isset($priv_ins_prenota)) $priv_ins_prenota = risul_query($privilegi_annuali_utente,0,'priv_ins_prenota');
+if (!isset($priv_ins_nuove_prenota)) $priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
+if (!isset($priv_ins_costi)) $priv_ins_costi = risul_query($privilegi_annuali_utente,0,'priv_ins_costi');
+if (!isset($priv_ins_spese)) $priv_ins_spese = substr($priv_ins_costi,0,1);
+if (!isset($priv_ins_entrate)) $priv_ins_entrate = substr($priv_ins_costi,1,1);
+if (!isset($priv_mod_prenota)) $priv_mod_prenota = risul_query($privilegi_annuali_utente,0,'priv_mod_prenota');
+if (!isset($priv_mod_prenotazioni)) $priv_mod_prenotazioni = substr($priv_mod_prenota,0,1);
+if (!isset($priv_mod_costi_agg)) $priv_mod_costi_agg = substr($priv_mod_prenota,8,1);
+if (!isset($priv_vedi_tab)) $priv_vedi_tab = risul_query($privilegi_annuali_utente,0,'priv_vedi_tab');
+if (!isset($priv_vedi_tab_mesi)) $priv_vedi_tab_mesi = substr($priv_vedi_tab,0,1);
+if (!isset($priv_vedi_tab_prenotazioni)) $priv_vedi_tab_prenotazioni = substr($priv_vedi_tab,1,1);
+if (!isset($priv_vedi_tab_costi)) $priv_vedi_tab_costi = substr($priv_vedi_tab,2,1);
+if (!isset($priv_vedi_tab_periodi)) $priv_vedi_tab_periodi = substr($priv_vedi_tab,3,1);
+if (!isset($priv_vedi_tab_regole)) $priv_vedi_tab_regole = substr($priv_vedi_tab,4,1);
+if (!isset($priv_vedi_tab_appartamenti)) $priv_vedi_tab_appartamenti = substr($priv_vedi_tab,5,1);
+if (!isset($priv_vedi_tab_stat)) $priv_vedi_tab_stat = substr($priv_vedi_tab,6,1);
+if (!isset($priv_vedi_tab_doc)) $priv_vedi_tab_doc = substr($priv_vedi_tab,7,1);
+if (!isset($priv_ins_tariffe)) $priv_ins_tariffe = risul_query($privilegi_annuali_utente,0,'priv_ins_tariffe');
+if (!isset($priv_mod_tariffe)) $priv_mod_tariffe = substr($priv_ins_tariffe,0,1);
+if (!isset($priv_mod_reg1)) $priv_mod_reg1 = substr($priv_ins_tariffe,4,1);
+if (!isset($priv_mod_reg2)) $priv_mod_reg2 = substr($priv_ins_tariffe,5,1);
+if (!isset($priv_ins_costi_agg)) $priv_ins_costi_agg = substr($priv_ins_tariffe,1,1);
 } # fine if ($anno_utente_attivato == "SI")
 } # fine if ($id_utente != 1)
 else {
-if (!$anno_utente_attivato) $anno_utente_attivato = "SI";
-if (!$modifica_pers) $modifica_pers = "SI";
-if (!$priv_crea_backup) $priv_crea_backup = "s";
-if (!$priv_crea_interconnessioni) $priv_crea_interconnessioni = "s";
-if (!$priv_crea_pagineweb) $priv_crea_pagineweb = "s";
-if (!$priv_gest_pass_cc) $priv_gest_pass_cc = "s";
-if (!$inserimento_nuovi_clienti) $inserimento_nuovi_clienti = "SI";
-if (!$modifica_clienti) $modifica_clienti = "SI";
-if (!$vedi_clienti) $vedi_clienti = "SI";
-if (!$priv_vedi_messaggi) $priv_vedi_messaggi = "s";
-if (!$priv_vedi_beni_inv) $priv_vedi_beni_inv = "s";
-if (!$priv_vedi_inv_mag) $priv_vedi_inv_mag = "s";
-if (!$priv_vedi_inv_app) $priv_vedi_inv_app = "s";
-if (!$priv_ins_nuove_prenota) $priv_ins_nuove_prenota = "s";
-if (!$priv_ins_spese) $priv_ins_spese = "s";
-if (!$priv_ins_entrate) $priv_ins_entrate = "s";
-if (!$priv_mod_prenotazioni) $priv_mod_prenotazioni = "s";
-if (!$priv_mod_costi_agg) $priv_mod_costi_agg = "s";
-if (!$priv_vedi_tab_mesi) $priv_vedi_tab_mesi = "s";
-if (!$priv_vedi_tab_prenotazioni) $priv_vedi_tab_prenotazioni = "s";
-if (!$priv_vedi_tab_costi) $priv_vedi_tab_costi = "s";
-if (!$priv_vedi_tab_periodi) $priv_vedi_tab_periodi = "s";
-if (!$priv_vedi_tab_regole) $priv_vedi_tab_regole = "s";
-if (!$priv_vedi_tab_appartamenti) $priv_vedi_tab_appartamenti = "s";
-if (!$priv_vedi_tab_stat) $priv_vedi_tab_stat = "s";
-if (!$priv_vedi_tab_doc) $priv_vedi_tab_doc = "s";
-if (!$priv_mod_tariffe) $priv_mod_tariffe = "s";
-if (!$priv_mod_reg1) $priv_mod_reg1 = "s";
-if (!$priv_mod_reg2) $priv_mod_reg2 = "s";
-if (!$priv_ins_costi_agg) $priv_ins_costi_agg = "s";
+if (!isset($anno_utente_attivato)) $anno_utente_attivato = "SI";
+if (!isset($modifica_pers)) $modifica_pers = "SI";
+if (!isset($priv_crea_backup)) $priv_crea_backup = "s";
+if (!isset($priv_crea_interconnessioni)) $priv_crea_interconnessioni = "s";
+if (!isset($priv_crea_pagineweb)) $priv_crea_pagineweb = "s";
+if (!isset($priv_gest_pass_cc)) $priv_gest_pass_cc = "s";
+if (!isset($inserimento_nuovi_clienti)) $inserimento_nuovi_clienti = "SI";
+if (!isset($modifica_clienti)) $modifica_clienti = "SI";
+if (!isset($vedi_clienti)) $vedi_clienti = "SI";
+if (!isset($priv_vedi_messaggi)) $priv_vedi_messaggi = "s";
+if (!isset($priv_vedi_beni_inv)) $priv_vedi_beni_inv = "s";
+if (!isset($priv_vedi_inv_mag)) $priv_vedi_inv_mag = "s";
+if (!isset($priv_vedi_inv_app)) $priv_vedi_inv_app = "s";
+if (!isset($priv_ins_nuove_prenota)) $priv_ins_nuove_prenota = "s";
+if (!isset($priv_ins_spese)) $priv_ins_spese = "s";
+if (!isset($priv_ins_entrate)) $priv_ins_entrate = "s";
+if (!isset($priv_mod_prenotazioni)) $priv_mod_prenotazioni = "s";
+if (!isset($priv_mod_costi_agg)) $priv_mod_costi_agg = "s";
+if (!isset($priv_vedi_tab_mesi)) $priv_vedi_tab_mesi = "s";
+if (!isset($priv_vedi_tab_prenotazioni)) $priv_vedi_tab_prenotazioni = "s";
+if (!isset($priv_vedi_tab_costi)) $priv_vedi_tab_costi = "s";
+if (!isset($priv_vedi_tab_periodi)) $priv_vedi_tab_periodi = "s";
+if (!isset($priv_vedi_tab_regole)) $priv_vedi_tab_regole = "s";
+if (!isset($priv_vedi_tab_appartamenti)) $priv_vedi_tab_appartamenti = "s";
+if (!isset($priv_vedi_tab_stat)) $priv_vedi_tab_stat = "s";
+if (!isset($priv_vedi_tab_doc)) $priv_vedi_tab_doc = "s";
+if (!isset($priv_mod_tariffe)) $priv_mod_tariffe = "s";
+if (!isset($priv_mod_reg1)) $priv_mod_reg1 = "s";
+if (!isset($priv_mod_reg2)) $priv_mod_reg2 = "s";
+if (!isset($priv_ins_costi_agg)) $priv_ins_costi_agg = "s";
 } # fine else if ($id_utente != 1)
 
 if ($anno_utente_attivato == "SI") {
@@ -221,14 +229,14 @@ return $mese_attuale;
 
 
 
-if (($pag == "tabella.php" or $pag == "tabella2.php" or $pag == "tabella3.php" or $pag == "visualizza_tabelle.php" or $pag == "storia_soldi.php") and !$mobile_device) $mostra_X = "SI";
+if (($pag == "tabella.php" or $pag == "tabella2.php" or $pag == "tabella3.php" or $pag == "visualizza_tabelle.php" or $pag == "storia_soldi.php") and !$mobile_device) $mostra_X = 1;
 
 
-echo "<table class=\"nav_bar\" style=\"background-color: $t1color;\" width=\"100%\" cellpadding=\"0\" cellspacing=\"0\">
+echo "<table class=\"nav_bar t1color\" width=\"100%\" cellpadding=\"0\" cellspacing=\"0\">
 <tr>";
 
-if ($mostra_X == "SI") echo "<td style=\"width: 10px;\"></td>";
-if ($idprenota_origine) $anno = $anno + 1;
+if (isset($mostra_X)) echo "<td style=\"width: 10px;\"></td>";
+if (fixset($idprenota_origine)) $anno = $anno + 1;
 if ($id_sessione) {
 $sessione_anno_var = "id_sessione=$id_sessione";
 if (substr($id_sessione,0,4) != $anno) $sessione_anno_var .= "&amp;anno=$anno";
@@ -243,7 +251,7 @@ echo "<td>
 if ($priv_ins_nuove_prenota == "s" or $priv_ins_spese == "s" or $priv_ins_entrate == "s" or $inserimento_nuovi_clienti != "NO" or ($modifica_clienti != "NO" and $vedi_clienti != "NO")) {
 echo "|</td><td><div class=\"drop nb_ins\"><ul>
 <li><a class=\"nonav\" id=\"nb_ins\"$selfref>&nbsp;<b>".mex("INSERIRE","head.php").":</b>&nbsp;</a>";
-if ($priv_ins_spese == "s" or $priv_ins_entrate == "s" or $priv_mod_tariffe != "n" or $priv_ins_costi_agg != "n" or ($id_utente == 1 and $installazione_subordinata != "SI") or ($priv_mod_prenotazioni != "n" and $priv_mod_costi_agg == "s") or $inserimento_nuovi_clienti != "NO" or ($modifica_clienti != "NO" and $vedi_clienti != "NO") or ($mobile_device and $priv_ins_nuove_prenota == "s")) {
+if ($priv_ins_spese == "s" or $priv_ins_entrate == "s" or $priv_mod_tariffe != "n" or $priv_ins_costi_agg != "n" or ($id_utente == 1 and !isset($installazione_subordinata)) or ($priv_mod_prenotazioni != "n" and $priv_mod_costi_agg == "s") or $inserimento_nuovi_clienti != "NO" or ($modifica_clienti != "NO" and $vedi_clienti != "NO") or ($mobile_device and $priv_ins_nuove_prenota == "s")) {
 echo "<ul>";
 if ($mobile_device and $priv_ins_nuove_prenota == "s") echo "<li><a id=\"nb_ires\" href=\"./prenota.php?$sessione_anno_var\">&nbsp;<b>".mex("PRENOTAZIONE","head.php")."</b>&nbsp;</a></li>";
 if ($inserimento_nuovi_clienti != "NO" or ($modifica_clienti != "NO" and $vedi_clienti != "NO")) echo "<li><a id=\"nb_icli\" href=\"./clienti.php?$sessione_anno_var\">&nbsp;<b>".mex("CLIENTE","head.php")."</b>&nbsp;</a></li>";
@@ -271,10 +279,16 @@ $star = "<b style=\"color: red;\">*</b>";
 $gt = "<b style=\"color: red; text-decoration: none;\">&gt;</b>";
 $lt = "<b style=\"color: red; text-decoration: none;\">&lt;</b>";
 } # fine if (numlin_query($messaggi) > 0)
+else {
+$star = "";
+$gt = "";
+$lt = "";
+} # fine else if (numlin_query($messaggi) > 0)
 } # fine if ($priv_vedi_messaggi == "s" and $numconnessione)
 echo "|</td><td><div class=\"drop nb_tab\"><ul>
 <li><a class=\"nonav\" id=\"nb_tab\"$selfref>&nbsp;<b>".mex("TABELLE","head.php")."$star:</b>&nbsp;</a>";
 if ($priv_vedi_beni_inv == "n" and $priv_vedi_inv_mag == "n" and $priv_vedi_inv_app == "n") $priv_vedi_tab_inventario = "n";
+else $priv_vedi_tab_inventario = "s";
 if ($priv_vedi_tab_costi != "n" or $priv_vedi_tab_regole != "n" or $priv_vedi_tab_doc != "n" or $priv_vedi_tab_stat != "n" or $priv_vedi_tab_inventario != "n" or $priv_vedi_messaggi == "s" or $priv_vedi_tab_appartamenti != "n" or ($mobile_device and ($priv_vedi_tab_mesi != "n" or $vedi_clienti != "NO"))) {
 echo "<ul>";
 if ($mobile_device) {
@@ -345,25 +359,26 @@ echo "<div class=\"drop nb_rat\"><div class=\"nb_rat\"><ul>
 </ul></li></ul></div></div></td><td>";
 } # fine if ($priv_vedi_tab_periodi != "n" and !$mobile_device)
 } # fine if ($priv_vedi_tab_mesi != "n" or $priv_vedi_tab_prenotazioni != "n" or...
-if (($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI") or $priv_crea_pagineweb == "s" or ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO")) or $priv_gest_pass_cc == "s") and !$mobile_device) {
+if (($modifica_pers != "NO" or ($priv_crea_backup == "s" and !isset($installazione_subordinata)) or $priv_crea_pagineweb == "s" or ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO")) or $priv_gest_pass_cc == "s") and !$mobile_device) {
 echo "|</td><td><div class=\"drop nb_con\"><ul>
 <li><a class=\"nav\" id=\"nb_con\" href=\"./personalizza.php?$sessione_anno_var\">&nbsp;<b>".mex("CONFIGURA","head.php")."</b>&nbsp;</a>";
-if ($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI") or $priv_crea_pagineweb == "s" or ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO"))) {
+if ($modifica_pers != "NO" or ($priv_crea_backup == "s" and !isset($installazione_subordinata)) or $priv_crea_pagineweb == "s" or ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO"))) {
 echo "<ul>";
-if ($id_utente == 1 and $installazione_subordinata != "SI") echo "<li><a id=\"nb_use\" href=\"./gestione_utenti.php?$sessione_anno_var\">&nbsp;<b>".mex("UTENTI","head.php")."</b>&nbsp;</a></li>";
+if ($id_utente == 1 and !isset($installazione_subordinata)) echo "<li><a id=\"nb_use\" href=\"./gestione_utenti.php?$sessione_anno_var\">&nbsp;<b>".mex("UTENTI","head.php")."</b>&nbsp;</a></li>";
 if ($priv_crea_pagineweb == "s") echo "<li><a id=\"nb_web\" href=\"./crea_modelli.php?$sessione_anno_var\">&nbsp;<b>".mex("SITO WEB","head.php")."</b>&nbsp;</a></li>";
 if ($priv_crea_interconnessioni == "s" and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO")) echo "<li><a id=\"nb_int\" href=\"./interconnessioni.php?$sessione_anno_var\">&nbsp;<b>".mex("INTERCONN.","head.php")."</b>&nbsp;</a></li>";
-if ($priv_crea_backup == "s" and $installazione_subordinata != "SI") echo "<li><a id=\"nb_bac\" href=\"./crea_backup.php?$sessione_anno_var\">&nbsp;<b>".mex("BACKUP","head.php")."</b>&nbsp;</a></li>";
+if ($priv_crea_backup == "s" and !isset($installazione_subordinata)) echo "<li><a id=\"nb_bac\" href=\"./crea_backup.php?$sessione_anno_var\">&nbsp;<b>".mex("BACKUP","head.php")."</b>&nbsp;</a></li>";
 if ($modifica_pers != "NO") echo "<li><a id=\"nb_cdoc\" href=\"./personalizza.php?$sessione_anno_var#contratti\">&nbsp;<b>".mex("DOCUMENTI","head.php")."</b>&nbsp;</a></li>";
 echo "</ul>";
-} # fine if ($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI") or
+} # fine if ($modifica_pers != "NO" or ($priv_crea_backup == "s" and !isset($installazione_subordinata)) or
 echo "</li></ul></div></td><td>";
-} # fine if (($modifica_pers != "NO" or ($priv_crea_backup == "s" and $installazione_subordinata != "SI") or...
+} # fine if (($modifica_pers != "NO" or ($priv_crea_backup == "s" and !isset($installazione_subordinata)) or...
 echo "</td></tr></table></td>";
 
-if ($idprenota_origine) $anno = $anno - 1;
+if (fixset($idprenota_origine)) $anno = $anno - 1;
 
-if ($mostra_X == "SI") {
+if (isset($mostra_X)) {
+$lista_var_X = "";
 if (@is_array($_POST)) reset($_POST);
 for ($num1 = 0 ; $num1 < count($_POST) ; $num1++) {
 $lista_var_X .= "&amp;".key($_POST)."=".urlencode($_POST[key($_POST)]);
@@ -380,7 +395,7 @@ echo "<td style=\"width: 10px;\">
 <b><a class=\"nav\" style=\"color: #666666;\" href=\"$pag$lista_var_X\"><b>X</b></a></b></td>";
 } # fine if ($lista_var_X)
 else echo "<td style=\"width: 10px;\"></td>";
-} # fine if ($mostra_X == "SI")
+} # fine if (isset($mostra_X))
 
 echo "</tr>
 </table>
