@@ -59,7 +59,11 @@ elseif (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI") echo "<link re
 if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
 </script>
 ";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\">
+echo "<style type=\"text/css\">
+:root { --t1color: $t1color; }
+.t1color { background-color: $t1color; }
+</style>
+<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\">
 <link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/snj/inc/stylesheet.css$vers_hinc\" media=\"all\">
 ";
 if (defined('C_FILE_CSS_PERS') and C_FILE_CSS_PERS != "" and @is_file(C_FILE_CSS_PERS)) echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"".C_FILE_CSS_PERS."\" media=\"all\">
